@@ -2,36 +2,39 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef BASE_ALLOCATOR_PARTITION_ALLOCATOR_SRC_PARTITION_ALLOC_POINTERS_RAW_REF_H_
-#define BASE_ALLOCATOR_PARTITION_ALLOCATOR_SRC_PARTITION_ALLOC_POINTERS_RAW_REF_H_
+#ifdef UNSAFE_BUFFERS_BUILD
+// TODO(crbug.com/40284755): Remove this and spanify to fix the errors.
+#pragma allow_unsafe_buffers
+#endif
+
+// IWYU pragma: private, include "base/memory/raw_ref.h"
+
+#ifndef PARTITION_ALLOC_POINTERS_RAW_REF_H_
+#define PARTITION_ALLOC_POINTERS_RAW_REF_H_
 
 #include <memory>
 #include <type_traits>
 #include <utility>
 
+#include "partition_alloc/buildflags.h"
 #include "partition_alloc/partition_alloc_base/augmentations/compiler_specific.h"
 #include "partition_alloc/partition_alloc_base/compiler_specific.h"
-#include "partition_alloc/partition_alloc_buildflags.h"
 #include "partition_alloc/partition_alloc_config.h"
 #include "partition_alloc/pointers/raw_ptr.h"
 
+#if PA_HAVE_SPACESHIP_OPERATOR
+#include <compare>
+#endif
+
 namespace base {
 
 template <class T, RawPtrTraits Traits>
 class raw_ref;
 
-namespace internal {
-
 template <class T>
-struct is_raw_ref : std::false_type {};
-
+inline constexpr bool IsRawRef = false;
 template <class T, RawPtrTraits Traits>
-struct is_raw_ref<::base::raw_ref<T, Traits>> : std::true_type {};
-
-template <class T>
-constexpr inline bool is_raw_ref_v = is_raw_ref<T>::value;
-
-}  // namespace internal
+inline constexpr bool IsRawRef<::base::raw_ref<T, Traits>> = true;
 
 // A smart pointer for a pointer which can not be null, and which provides
 // Use-after-Free protection in the same ways as raw_ptr. This class acts like a
@@ -222,86 +225,122 @@ class PA_TRIVIAL_ABI PA_GSL_POINTER raw_ref {
     swap(lhs.inner_, rhs.inner_);
   }
 
+  // See comments in raw_ptr.h for why these are declared with both arguments
+  // templated and defined out of line. Here the private access is to `inner_`
+  // rather than a method, but the issue is the same.
   template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-  friend bool operator==(const raw_ref<U, Traits1>& lhs,
-                         const raw_ref<V, Traits2>& rhs);
+  friend constexpr bool operator==(const raw_ref<U, Traits1>& lhs,
+                                   const raw_ref<V, Traits2>& rhs);
   template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-  friend bool operator!=(const raw_ref<U, Traits1>& lhs,
-                         const raw_ref<V, Traits2>& rhs);
+  friend constexpr bool operator!=(const raw_ref<U, Traits1>& lhs,
+                                   const raw_ref<V, Traits2>& rhs);
+#if PA_HAVE_SPACESHIP_OPERATOR
   template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-  friend bool operator<(const raw_ref<U, Traits1>& lhs,
-                        const raw_ref<V, Traits2>& rhs);
+  friend constexpr auto operator<=>(const raw_ref<U, Traits1>& lhs,
+                                    const raw_ref<V, Traits2>& rhs);
+#else
   template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-  friend bool operator>(const raw_ref<U, Traits1>& lhs,
-                        const raw_ref<V, Traits2>& rhs);
+  friend constexpr bool operator<(const raw_ref<U, Traits1>& lhs,
+                                  const raw_ref<V, Traits2>& rhs);
   template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-  friend bool operator<=(const raw_ref<U, Traits1>& lhs,
-                         const raw_ref<V, Traits2>& rhs);
+  friend constexpr bool operator>(const raw_ref<U, Traits1>& lhs,
+                                  const raw_ref<V, Traits2>& rhs);
   template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-  friend bool operator>=(const raw_ref<U, Traits1>& lhs,
-                         const raw_ref<V, Traits2>& rhs);
+  friend constexpr bool operator<=(const raw_ref<U, Traits1>& lhs,
+                                   const raw_ref<V, Traits2>& rhs);
+  template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
+  friend constexpr bool operator>=(const raw_ref<U, Traits1>& lhs,
+                                   const raw_ref<V, Traits2>& rhs);
+#endif
 
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator==(const raw_ref& lhs, const U& rhs) {
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator==(const raw_ref& lhs,
+                                                    const U& rhs) {
     PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
     return lhs.inner_ == &rhs;
   }
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator!=(const raw_ref& lhs, const U& rhs) {
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator!=(const raw_ref& lhs,
+                                                    const U& rhs) {
     PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
     return lhs.inner_ != &rhs;
   }
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator<(const raw_ref& lhs, const U& rhs) {
-    PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
-    return lhs.inner_ < &rhs;
-  }
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator>(const raw_ref& lhs, const U& rhs) {
-    PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
-    return lhs.inner_ > &rhs;
-  }
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator<=(const raw_ref& lhs, const U& rhs) {
-    PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
-    return lhs.inner_ <= &rhs;
-  }
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator>=(const raw_ref& lhs, const U& rhs) {
-    PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
-    return lhs.inner_ >= &rhs;
-  }
-
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator==(const U& lhs, const raw_ref& rhs) {
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator==(const U& lhs,
+                                                    const raw_ref& rhs) {
     PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
     return &lhs == rhs.inner_;
   }
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator!=(const U& lhs, const raw_ref& rhs) {
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator!=(const U& lhs,
+                                                    const raw_ref& rhs) {
     PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
     return &lhs != rhs.inner_;
   }
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator<(const U& lhs, const raw_ref& rhs) {
+
+#if PA_HAVE_SPACESHIP_OPERATOR
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr auto operator<=>(const raw_ref& lhs,
+                                                     const U& rhs) {
+    PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
+    return lhs.inner_ <=> &rhs;
+  }
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr auto operator<=>(const U& lhs,
+                                                     const raw_ref& rhs) {
+    PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
+    return &lhs <=> rhs.inner_;
+  }
+#else
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator<(const raw_ref& lhs,
+                                                   const U& rhs) {
+    PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
+    return lhs.inner_ < &rhs;
+  }
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator>(const raw_ref& lhs,
+                                                   const U& rhs) {
+    PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
+    return lhs.inner_ > &rhs;
+  }
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator<=(const raw_ref& lhs,
+                                                    const U& rhs) {
+    PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
+    return lhs.inner_ <= &rhs;
+  }
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator>=(const raw_ref& lhs,
+                                                    const U& rhs) {
+    PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
+    return lhs.inner_ >= &rhs;
+  }
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator<(const U& lhs,
+                                                   const raw_ref& rhs) {
     PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
     return &lhs < rhs.inner_;
   }
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator>(const U& lhs, const raw_ref& rhs) {
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator>(const U& lhs,
+                                                   const raw_ref& rhs) {
     PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
     return &lhs > rhs.inner_;
   }
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator<=(const U& lhs, const raw_ref& rhs) {
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator<=(const U& lhs,
+                                                    const raw_ref& rhs) {
     PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
     return &lhs <= rhs.inner_;
   }
-  template <class U, class = std::enable_if_t<!internal::is_raw_ref_v<U>, void>>
-  PA_ALWAYS_INLINE friend bool operator>=(const U& lhs, const raw_ref& rhs) {
+  template <class U, class = std::enable_if_t<!IsRawRef<U>, void>>
+  PA_ALWAYS_INLINE friend constexpr bool operator>=(const U& lhs,
+                                                    const raw_ref& rhs) {
     PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
     return &lhs >= rhs.inner_;
   }
+#endif
 
  private:
   template <class U, RawPtrTraits R>
@@ -311,47 +350,57 @@ class PA_TRIVIAL_ABI PA_GSL_POINTER raw_ref {
 };
 
 template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-PA_ALWAYS_INLINE bool operator==(const raw_ref<U, Traits1>& lhs,
-                                 const raw_ref<V, Traits2>& rhs) {
+PA_ALWAYS_INLINE constexpr bool operator==(const raw_ref<U, Traits1>& lhs,
+                                           const raw_ref<V, Traits2>& rhs) {
   PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
   PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
   return lhs.inner_ == rhs.inner_;
 }
 template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-PA_ALWAYS_INLINE bool operator!=(const raw_ref<U, Traits1>& lhs,
-                                 const raw_ref<V, Traits2>& rhs) {
+PA_ALWAYS_INLINE constexpr bool operator!=(const raw_ref<U, Traits1>& lhs,
+                                           const raw_ref<V, Traits2>& rhs) {
   PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
   PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
   return lhs.inner_ != rhs.inner_;
 }
+#if PA_HAVE_SPACESHIP_OPERATOR
 template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-PA_ALWAYS_INLINE bool operator<(const raw_ref<U, Traits1>& lhs,
-                                const raw_ref<V, Traits2>& rhs) {
+PA_ALWAYS_INLINE constexpr auto operator<=>(const raw_ref<U, Traits1>& lhs,
+                                            const raw_ref<V, Traits2>& rhs) {
+  PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
+  PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
+  return lhs.inner_ <=> rhs.inner_;
+}
+#else
+template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
+PA_ALWAYS_INLINE constexpr bool operator<(const raw_ref<U, Traits1>& lhs,
+                                          const raw_ref<V, Traits2>& rhs) {
   PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
   PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
   return lhs.inner_ < rhs.inner_;
 }
 template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-PA_ALWAYS_INLINE bool operator>(const raw_ref<U, Traits1>& lhs,
-                                const raw_ref<V, Traits2>& rhs) {
+PA_ALWAYS_INLINE constexpr bool operator>(const raw_ref<U, Traits1>& lhs,
+                                          const raw_ref<V, Traits2>& rhs) {
   PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
   PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
   return lhs.inner_ > rhs.inner_;
 }
 template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-PA_ALWAYS_INLINE bool operator<=(const raw_ref<U, Traits1>& lhs,
-                                 const raw_ref<V, Traits2>& rhs) {
+PA_ALWAYS_INLINE constexpr bool operator<=(const raw_ref<U, Traits1>& lhs,
+                                           const raw_ref<V, Traits2>& rhs) {
   PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
   PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
   return lhs.inner_ <= rhs.inner_;
 }
 template <typename U, typename V, RawPtrTraits Traits1, RawPtrTraits Traits2>
-PA_ALWAYS_INLINE bool operator>=(const raw_ref<U, Traits1>& lhs,
-                                 const raw_ref<V, Traits2>& rhs) {
+PA_ALWAYS_INLINE constexpr bool operator>=(const raw_ref<U, Traits1>& lhs,
+                                           const raw_ref<V, Traits2>& rhs) {
   PA_RAW_PTR_CHECK(lhs.inner_);  // Catch use-after-move.
   PA_RAW_PTR_CHECK(rhs.inner_);  // Catch use-after-move.
   return lhs.inner_ >= rhs.inner_;
 }
+#endif
 
 // CTAD deduction guide.
 template <class T>
@@ -359,26 +408,15 @@ raw_ref(T&) -> raw_ref<T>;
 template <class T>
 raw_ref(const T&) -> raw_ref<const T>;
 
-// Template helpers for working with raw_ref<T>.
-template <typename T>
-struct IsRawRef : std::false_type {};
-
-template <typename T, RawPtrTraits Traits>
-struct IsRawRef<raw_ref<T, Traits>> : std::true_type {};
-
-template <typename T>
-inline constexpr bool IsRawRefV = IsRawRef<T>::value;
-
+// Converts `raw_ref<T>` => `T`; leaves l/rvalue refs alone.
 template <typename T>
 struct RemoveRawRef {
   using type = T;
 };
-
 template <typename T, RawPtrTraits Traits>
 struct RemoveRawRef<raw_ref<T, Traits>> {
   using type = T;
 };
-
 template <typename T>
 using RemoveRawRefT = typename RemoveRawRef<T>::type;
 
@@ -448,4 +486,4 @@ struct pointer_traits<::raw_ref<T, Traits>> {
 
 }  // namespace std
 
-#endif  // BASE_ALLOCATOR_PARTITION_ALLOCATOR_SRC_PARTITION_ALLOC_POINTERS_RAW_REF_H_
+#endif  // PARTITION_ALLOC_POINTERS_RAW_REF_H_
