@@ -25,6 +25,7 @@
 
 #include "base/check.h"
 #include "base/clang_profiling_buildflags.h"
+#include "base/compiler_specific.h"
 #include "base/feature_list.h"
 #include "base/features.h"
 #include "base/files/file_enumerator.h"
@@ -43,6 +44,7 @@
 #include "base/strings/string_split_win.h"
 #include "base/strings/string_util.h"
 #include "base/strings/string_util_win.h"
+#include "base/strings/string_view_util.h"
 #include "base/strings/utf_string_conversions.h"
 #include "base/task/bind_post_task.h"
 #include "base/task/sequenced_task_runner.h"
@@ -383,6 +385,60 @@ OnceClosure GetDeleteFileCallbackInternal(
                   std::move(bound_callback));
 }
 
+// This function checks if the user is an administrator and whether they have a
+// default elevation type. This corresponds to a full administrator such as the
+// SYSTEM user or built in administrator. It will return false for split-token
+// administrators used in UAC and any non-administrator caller. It checks the
+// effective token in case the caller is impersonating an administrator.
+bool IsUserDefaultAdmin() {
+  base::win::Sid admin_sid(base::win::WellKnownSid::kBuiltinAdministrators);
+  BOOL is_member = FALSE;
+  if (!::CheckTokenMembership(nullptr, admin_sid.GetPSID(), &is_member)) {
+    DPLOG(WARNING) << "Error checking token membership";
+    return false;
+  }
+
+  if (!is_member) {
+    return false;
+  }
+
+  TOKEN_ELEVATION_TYPE elevation_type;
+  DWORD ret_length;
+  if (!::GetTokenInformation(::GetCurrentThreadEffectiveToken(),
+                             TokenElevationType, &elevation_type,
+                             sizeof(elevation_type), &ret_length)) {
+    DPLOG(WARNING) << "Cannot get token elevation type";
+    return false;
+  }
+  return elevation_type == TokenElevationTypeDefault;
+}
+
+// This function removes the Windows extended-length path prefix from a prefixed
+// path. It supports both the native UNC prefix and the native local path
+// prefix. If the prefix is not recognized, it logs a warning and returns an
+// empty FilePath.
+//
+// Examples:
+// \\?\UNC\server\share\path -> \\server\share\path
+// \\?\C:\path\to\file -> C:\path\to\file
+FilePath RemoveWindowsExtendedPathPrefix(std::wstring_view prefixed_path) {
+  constexpr std::wstring_view kPrefixNativeUNC = L"\\\\?\\UNC\\";
+  if (prefixed_path.starts_with(kPrefixNativeUNC)) {
+    std::wstring normalized_path = L"\\\\";
+    normalized_path.append(prefixed_path.substr(kPrefixNativeUNC.length()));
+    return FilePath(normalized_path);
+  }
+
+  constexpr std::wstring_view kPrefixNativeLocalPath = L"\\\\?\\";
+  if (prefixed_path.starts_with(kPrefixNativeLocalPath)) {
+    return FilePath(prefixed_path.substr(kPrefixNativeLocalPath.length()));
+  }
+
+  // Other prefixes are not supported.
+  DLOG(WARNING) << "Unsupported prefix for path " << prefixed_path;
+  return FilePath();
+}
+
 // This function verifies that no code is attempting to set an ACL on a file
 // that is outside of 'safe' paths. A 'safe' path is defined as one that is
 // within the user data dir, or the temporary directory. This is explicitly to
@@ -423,7 +479,7 @@ bool IsPathSafeToSetAclOn(const FilePath& path) {
   // Admin users create temporary files in SystemTemp; see
   // `CreateNewTempDirectory` below.
   FilePath secure_system_temp;
-  if (::IsUserAnAdmin() &&
+  if (IsUserDefaultAdmin() &&
       PathService::Get(DIR_SYSTEM_TEMP, &secure_system_temp)) {
     valid_paths.push_back(secure_system_temp);
   }
@@ -651,7 +707,7 @@ File CreateAndOpenTemporaryFileInDir(const FilePath& dir, FilePath* temp_file) {
       GetLongPathName(temp_name.value().c_str(), long_temp_name, MAX_PATH);
   if (long_name_len != 0 && long_name_len <= MAX_PATH) {
     *temp_file =
-        FilePath(FilePath::StringPieceType(long_temp_name, long_name_len));
+        FilePath(FilePath::StringViewType(long_temp_name, long_name_len));
   } else {
     // GetLongPathName() failed, but we still have a temporary file.
     *temp_file = std::move(temp_name);
@@ -664,7 +720,7 @@ bool CreateTemporaryFileInDir(const FilePath& dir, FilePath* temp_file) {
   return CreateAndOpenTemporaryFileInDir(dir, temp_file).IsValid();
 }
 
-FilePath FormatTemporaryFileName(FilePath::StringPieceType identifier) {
+FilePath FormatTemporaryFileName(FilePath::StringViewType identifier) {
   return FilePath(StrCat({identifier, FILE_PATH_LITERAL(".tmp")}));
 }
 
@@ -678,7 +734,7 @@ ScopedFILE CreateAndOpenTemporaryStreamInDir(const FilePath& dir,
 }
 
 bool CreateTemporaryDirInDir(const FilePath& base_dir,
-                             FilePath::StringPieceType prefix,
+                             FilePath::StringViewType prefix,
                              FilePath* new_dir) {
   ScopedBlockingCall scoped_blocking_call(FROM_HERE, BlockingType::MAY_BLOCK);
 
@@ -720,7 +776,7 @@ bool CreateNewTempDirectory(const FilePath::StringType& prefix,
   DCHECK(new_temp_path);
 
   FilePath parent_dir;
-  if (::IsUserAnAdmin() && PathService::Get(DIR_SYSTEM_TEMP, &parent_dir) &&
+  if (IsUserDefaultAdmin() && PathService::Get(DIR_SYSTEM_TEMP, &parent_dir) &&
       CreateTemporaryDirInDir(parent_dir,
                               prefix.empty() ? kDefaultTempDirPrefix : prefix,
                               new_temp_path)) {
@@ -802,32 +858,34 @@ bool NormalizeFilePath(const FilePath& path, FilePath* real_path) {
     return false;
   }
 
-  // The expansion of `path` into a full path may make it longer. Since
-  // '\Device\HarddiskVolume1' is 23 characters long, we can add 30 characters.
-  constexpr int kMaxPathLength = MAX_PATH + 30;
-  wchar_t native_file_path[kMaxPathLength];
+  // Add space for the `\\?\` or `\\?\UNC\` prefix.
+  constexpr int kMaxPathLength = MAX_PATH + 16;
+  wchar_t prefixed_file_path_buffer[kMaxPathLength];
   // On success, `used_wchars` returns the number of written characters, not
   // including the trailing '\0'. Thus, failure is indicated by returning 0 or
   // >= kMaxPathLength.
   DWORD used_wchars = ::GetFinalPathNameByHandle(
-      file.GetPlatformFile(), native_file_path, kMaxPathLength,
-      FILE_NAME_NORMALIZED | VOLUME_NAME_NT);
+      file.GetPlatformFile(), prefixed_file_path_buffer, kMaxPathLength,
+      FILE_NAME_NORMALIZED | VOLUME_NAME_DOS);
   if (used_wchars >= kMaxPathLength || used_wchars == 0) {
     return false;
   }
 
-  // With `VOLUME_NAME_NT` flag, GetFinalPathNameByHandle() returns the path
-  // with the volume device path and existing code expects we return a path
-  // starting 'X:\' so we need to call DevicePathToDriveLetterPath.
-  if (!DevicePathToDriveLetterPath(
-          FilePath(FilePath::StringPieceType(native_file_path, used_wchars)),
-          real_path)) {
-    return false;
-  }
+  std::wstring_view prefixed_file_path(prefixed_file_path_buffer, used_wchars);
+  *real_path = RemoveWindowsExtendedPathPrefix(prefixed_file_path);
 
   // `real_path` can be longer than MAX_PATH and we should only return paths
   // that are less than MAX_PATH.
-  return real_path->value().size() <= MAX_PATH;
+  if (real_path->value().size() >= MAX_PATH) {
+    real_path->clear();
+  }
+
+  return !real_path->empty();
+}
+
+FilePath RemoveWindowsExtendedPathPrefixForTesting(
+    std::wstring_view prefixed_path) {
+  return RemoveWindowsExtendedPathPrefix(prefixed_path);
 }
 
 bool DevicePathToDriveLetterPath(const FilePath& nt_device_path,
@@ -868,7 +926,7 @@ bool DevicePathToDriveLetterPath(const FilePath& nt_device_path,
           device_path.IsParent(nt_device_path)) {
         *out_drive_letter_path =
             FilePath(drive + nt_device_path.value().substr(
-                                 wcslen(device_path_as_string)));
+                                 UNSAFE_TODO(wcslen(device_path_as_string))));
         return true;
       }
     }
@@ -948,9 +1006,9 @@ bool GetFileInfo(const FilePath& file_path, File::Info* results) {
 FILE* OpenFile(const FilePath& filename, const char* mode) {
   // 'N' is unconditionally added below, so be sure there is not one already
   // present before a comma in |mode|.
-  DCHECK(
-      strchr(mode, 'N') == nullptr ||
-      (strchr(mode, ',') != nullptr && strchr(mode, 'N') > strchr(mode, ',')));
+  DCHECK(UNSAFE_TODO(strchr(mode, 'N')) == nullptr ||
+         (UNSAFE_TODO(strchr(mode, ',')) != nullptr &&
+          UNSAFE_TODO(strchr(mode, 'N')) > UNSAFE_TODO(strchr(mode, ','))));
   ScopedBlockingCall scoped_blocking_call(FROM_HERE, BlockingType::MAY_BLOCK);
   std::wstring w_mode = UTF8ToWide(mode);
   AppendModeCharacter(L'N', &w_mode);
@@ -1092,7 +1150,7 @@ bool GetCurrentDirectory(FilePath* dir) {
   // TODO(evanm): the old behavior of this function was to always strip the
   // trailing slash.  We duplicate this here, but it shouldn't be necessary
   // when everyone is using the appropriate FilePath APIs.
-  *dir = FilePath(FilePath::StringPieceType(system_buffer))
+  *dir = FilePath(FilePath::StringViewType(system_buffer))
              .StripTrailingSeparators();
   return true;
 }
