@@ -330,11 +330,12 @@ int ParseOSProductVersion(const std::string_view& version) {
     macos_version *= 100;
   }
 
-  // Checks that the value is within expected bounds corresponding to released
-  // OS version numbers. The most important bit is making sure that the "10.16"
-  // compatibility mode isn't engaged.
+  // Check that the value is within expected bounds corresponding to released
+  // OS version numbers. Specifically, ensure that neither the "macOS 10.16" nor
+  // the "macOS 16" compatibility modes are engaged.
   CHECK(macos_version >= 10'00'00);
   CHECK(macos_version < 10'16'00 || macos_version >= 11'00'00);
+  CHECK(macos_version < 16'00'00 || macos_version >= 26'00'00);
 
   return macos_version;
 }
@@ -386,7 +387,7 @@ std::string GetOSDisplayName() {
 
 std::string GetPlatformSerialNumber() {
   base::mac::ScopedIOObject<io_service_t> expert_device(
-      IOServiceGetMatchingService(kIOMasterPortDefault,
+      IOServiceGetMatchingService(kIOMainPortDefault,
                                   IOServiceMatching("IOPlatformExpertDevice")));
   if (!expert_device) {
     DLOG(ERROR) << "Error retrieving the machine serial number.";
@@ -574,6 +575,12 @@ void OpenSystemSettingsPane(SystemSettingsPane pane,
         pane_file = @"/System/Library/PreferencePanes/Trackpad.prefPane";
       }
       break;
+    case SystemSettingsPane::kPrivacySecurity_Pasteboard:
+      // Pasteboard permissions were added in macOS 15.
+      DCHECK_GE(MacOSMajorVersion(), 15);
+      url = @"x-apple.systempreferences:com.apple.settings.PrivacySecurity."
+            @"extension?Privacy_Pasteboard";
+      break;
   }
 
   DCHECK(url != nil ^ pane_file != nil);
