@@ -5,10 +5,14 @@
 #include "cc/layers/surface_layer_impl.h"
 
 #include <stddef.h>
+
 #include <utility>
 
 #include "base/test/bind.h"
+#include "base/test/scoped_feature_list.h"
 #include "base/threading/thread.h"
+#include "cc/base/features.h"
+#include "cc/layers/append_quads_context.h"
 #include "cc/layers/append_quads_data.h"
 #include "cc/test/layer_tree_impl_test_base.h"
 #include "testing/gmock/include/gmock/gmock.h"
@@ -108,7 +112,9 @@ TEST(SurfaceLayerImplTest, SurfaceLayerImplWithTwoDifferentSurfaces) {
   auto render_pass = viz::CompositorRenderPass::Create();
   {
     AppendQuadsData data;
-    surface_layer_impl->AppendQuads(render_pass.get(), &data);
+    surface_layer_impl->AppendQuads(
+        AppendQuadsContext{DRAW_MODE_HARDWARE, {}, false}, render_pass.get(),
+        &data);
     // The the primary viz::SurfaceInfo will be added to
     // activation_dependencies.
     EXPECT_THAT(data.activation_dependencies,
@@ -124,7 +130,9 @@ TEST(SurfaceLayerImplTest, SurfaceLayerImplWithTwoDifferentSurfaces) {
     AppendQuadsData data;
     surface_layer_impl->SetRange(viz::SurfaceRange(std::nullopt, surface_id1),
                                  0u);
-    surface_layer_impl->AppendQuads(render_pass.get(), &data);
+    surface_layer_impl->AppendQuads(
+        AppendQuadsContext{DRAW_MODE_HARDWARE, {}, false}, render_pass.get(),
+        &data);
     // The primary viz::SurfaceInfo should be added to activation_dependencies.
     EXPECT_THAT(data.activation_dependencies,
                 UnorderedElementsAre(surface_id1));
@@ -138,7 +146,9 @@ TEST(SurfaceLayerImplTest, SurfaceLayerImplWithTwoDifferentSurfaces) {
     AppendQuadsData data;
     surface_layer_impl->SetRange(viz::SurfaceRange(surface_id2, surface_id1),
                                  4u);
-    surface_layer_impl->AppendQuads(render_pass.get(), &data);
+    surface_layer_impl->AppendQuads(
+        AppendQuadsContext{DRAW_MODE_HARDWARE, {}, false}, render_pass.get(),
+        &data);
     // The the primary viz::SurfaceInfo will be added to
     // activation_dependencies.
     EXPECT_THAT(data.activation_dependencies,
@@ -210,11 +220,15 @@ TEST(SurfaceLayerImplTest, SurfaceLayerImplsWithDeadlines) {
 
   auto render_pass = viz::CompositorRenderPass::Create();
   AppendQuadsData data;
-  surface_layer_impl->AppendQuads(render_pass.get(), &data);
+  surface_layer_impl->AppendQuads(
+      AppendQuadsContext{DRAW_MODE_HARDWARE, {}, false}, render_pass.get(),
+      &data);
   EXPECT_EQ(1u, data.deadline_in_frames);
   EXPECT_FALSE(data.use_default_lower_bound_deadline);
 
-  surface_layer_impl2->AppendQuads(render_pass.get(), &data);
+  surface_layer_impl2->AppendQuads(
+      AppendQuadsContext{DRAW_MODE_HARDWARE, {}, false}, render_pass.get(),
+      &data);
   EXPECT_EQ(1u, data.deadline_in_frames);
   EXPECT_TRUE(data.use_default_lower_bound_deadline);
 }
@@ -248,7 +262,9 @@ TEST(SurfaceLayerImplTest, SurfaceLayerImplWithMatchingPrimaryAndFallback) {
 
   auto render_pass = viz::CompositorRenderPass::Create();
   AppendQuadsData data;
-  surface_layer_impl->AppendQuads(render_pass.get(), &data);
+  surface_layer_impl->AppendQuads(
+      AppendQuadsContext{DRAW_MODE_HARDWARE, {}, false}, render_pass.get(),
+      &data);
   EXPECT_THAT(data.activation_dependencies, UnorderedElementsAre(surface_id1));
   EXPECT_EQ(2u, data.deadline_in_frames);
 
@@ -371,5 +387,106 @@ TEST(SurfaceLayerImplTest, WillDrawNotifiesAsynchronously) {
   EXPECT_TRUE(updated);
 }
 
+class SurfaceLayerImplAlignToPixelGridTest : public testing::Test {
+ public:
+  SurfaceLayerImplAlignToPixelGridTest() {
+    scoped_feature_list_.InitWithFeatures(
+        {features::kAlignSurfaceLayerImplToPixelGrid}, {});
+  }
+
+ private:
+  base::test::ScopedFeatureList scoped_feature_list_;
+};
+
+TEST_F(SurfaceLayerImplAlignToPixelGridTest, FractionalOffsetSnapsToPixelGrid) {
+  gfx::Size layer_size(200, 200);
+  gfx::Size viewport_size(1000, 1000);
+  LayerTreeImplTestBase impl;
+  SurfaceLayerImpl* surface_layer_impl =
+      impl.AddLayerInActiveTree<SurfaceLayerImpl>();
+  surface_layer_impl->SetBounds(layer_size);
+  surface_layer_impl->SetDrawsContent(true);
+  CopyProperties(impl.root_layer(), surface_layer_impl);
+
+  // Create transform with fractional translation.
+  gfx::Transform transform;
+  transform.PostTranslate(0.3, 0.7);
+  EXPECT_FALSE(transform.IsIdentityOrIntegerTranslation());
+
+  impl.CalcDrawProps(viewport_size);
+  surface_layer_impl->draw_properties().target_space_transform = transform;
+
+  // Compute RenderPass, with DrawQuads for SurfaceLayer.
+  auto render_pass = viz::CompositorRenderPass::Create();
+  AppendQuadsData data;
+  surface_layer_impl->AppendQuads(
+      AppendQuadsContext{DRAW_MODE_HARDWARE, {}, false}, render_pass.get(),
+      &data);
+
+  // Verify that the DrawQuads for the SurfaceLayer have an integral offset.
+  ASSERT_EQ(1U, render_pass->shared_quad_state_list.size());
+  viz::SharedQuadState* state =
+      render_pass->shared_quad_state_list.ElementAt(0);
+  gfx::Transform quad_to_target_transform = state->quad_to_target_transform;
+  EXPECT_TRUE(quad_to_target_transform.IsIdentityOrIntegerTranslation());
+}
+
+// This test verifies that paint flag overrides are propagated to the
+// viz::SurfaceDrawQuad.
+TEST(SurfaceLayerImplTest, OverrideChildPaintFlags) {
+  LayerTreeImplTestBase impl;
+  SurfaceLayerImpl* surface_layer_impl =
+      impl.AddLayerInActiveTree<SurfaceLayerImpl>();
+  CopyProperties(impl.root_layer(), surface_layer_impl);
+
+  gfx::Size viewport_size(1000, 1000);
+  impl.CalcDrawProps(viewport_size);
+
+  {
+    const viz::LocalSurfaceId kArbitraryLocalSurfaceId1(
+        1, base::UnguessableToken::Create());
+    viz::SurfaceId surface_id1(kArbitraryFrameSinkId,
+                               kArbitraryLocalSurfaceId1);
+
+    gfx::Size layer_size(400, 100);
+    surface_layer_impl->SetBounds(layer_size);
+    surface_layer_impl->SetDrawsContent(true);
+    surface_layer_impl->SetRange(viz::SurfaceRange(surface_id1), 1u);
+    surface_layer_impl->SetFilterQuality(PaintFlags::FilterQuality::kNone);
+  }
+
+  // By default, surfaces don't override their child paint flags.
+  {
+    auto render_pass = viz::CompositorRenderPass::Create();
+    AppendQuadsData data;
+    surface_layer_impl->AppendQuads(
+        AppendQuadsContext{DRAW_MODE_HARDWARE, {}, false}, render_pass.get(),
+        &data);
+    const viz::SurfaceDrawQuad* surface_draw_quad =
+        viz::SurfaceDrawQuad::MaterialCast(render_pass->quad_list.ElementAt(0));
+    EXPECT_EQ(surface_draw_quad->override_child_filter_quality, std::nullopt);
+    EXPECT_EQ(surface_draw_quad->override_child_dynamic_range_limit,
+              std::nullopt);
+  }
+
+  // When specified, surfaces will propagate their paint flags (using the
+  // default when none has been set on the layer).
+  {
+    surface_layer_impl->SetOverrideChildPaintFlags(true);
+
+    auto render_pass = viz::CompositorRenderPass::Create();
+    AppendQuadsData data;
+    surface_layer_impl->AppendQuads(
+        AppendQuadsContext{DRAW_MODE_HARDWARE, {}, false}, render_pass.get(),
+        &data);
+    const viz::SurfaceDrawQuad* surface_draw_quad =
+        viz::SurfaceDrawQuad::MaterialCast(render_pass->quad_list.ElementAt(0));
+    EXPECT_EQ(surface_draw_quad->override_child_filter_quality,
+              PaintFlags::FilterQuality::kNone);
+    EXPECT_EQ(surface_draw_quad->override_child_dynamic_range_limit,
+              PaintFlags::DynamicRangeLimitMixture());
+  }
+}
+
 }  // namespace
 }  // namespace cc
