@@ -605,11 +605,19 @@ class LayerTreeHostTestHiddenSurfaceNotAllocatedForSubtreeCopyRequest
     did_swap_ = true;
   }
 
-  void AfterTest() override { EXPECT_TRUE(did_swap_); }
+  void AfterTest() override {
+    EXPECT_TRUE(did_swap_);
+
+    // Clear frame_sink_ to prevent dangling pointer access during destruction.
+    // LayerTreeHost owns the TestLayerTreeFrameSink and releases it immediately
+    // after this method is called.
+    frame_sink_ = nullptr;
+    LayerTreeHostCopyRequestTest::AfterTest();
+  }
 
   viz::AggregatedRenderPassId parent_render_pass_id;
   viz::AggregatedRenderPassId copy_layer_render_pass_id;
-  raw_ptr<TestLayerTreeFrameSink, DanglingUntriaged> frame_sink_ = nullptr;
+  raw_ptr<TestLayerTreeFrameSink> frame_sink_ = nullptr;
   bool did_swap_ = false;
   FakeContentLayerClient client_;
   scoped_refptr<FakePictureLayer> root_;
@@ -854,7 +862,8 @@ TEST_P(LayerTreeHostTestAsyncTwoReadbacksWithoutDraw, Test) {
 }
 
 class LayerTreeHostCopyRequestTestDeleteSharedImage
-    : public LayerTreeHostCopyRequestTest {
+    : public LayerTreeHostCopyRequestTest,
+      public gpu::TestSharedImageInterfaceClient {
  protected:
   std::unique_ptr<viz::DisplayCompositorMemoryAndTaskController>
   CreateDisplayControllerOnThread() override {
@@ -865,6 +874,7 @@ class LayerTreeHostCopyRequestTestDeleteSharedImage
   std::unique_ptr<viz::SkiaOutputSurface> CreateSkiaOutputSurfaceOnThread(
       viz::DisplayCompositorMemoryAndTaskController*) override {
     display_context_provider_ = viz::TestContextProvider::Create();
+    display_context_provider_->SharedImageInterface()->SetClient(this);
     display_context_provider_->BindToCurrentSequence();
     return viz::FakeSkiaOutputSurface::Create3d(display_context_provider_);
   }
@@ -890,8 +900,8 @@ class LayerTreeHostCopyRequestTestDeleteSharedImage
     EXPECT_EQ(gfx::Size(10, 10).ToString(), result->size().ToString());
     EXPECT_EQ(result->format(), viz::CopyOutputResult::Format::RGBA);
     EXPECT_EQ(result->destination(),
-              viz::CopyOutputResult::Destination::kNativeTextures);
-    EXPECT_NE(result->GetTextureResult(), nullptr);
+              viz::CopyOutputResult::Destination::kSharedImage);
+    EXPECT_NE(result->GetSharedImage().get(), nullptr);
 
     // Save the result for later.
     EXPECT_FALSE(result_);
@@ -904,7 +914,7 @@ class LayerTreeHostCopyRequestTestDeleteSharedImage
   void InsertCopyRequest() {
     copy_layer_->RequestCopyOfOutput(std::make_unique<viz::CopyOutputRequest>(
         viz::CopyOutputRequest::ResultFormat::RGBA,
-        viz::CopyOutputResult::Destination::kNativeTextures,
+        viz::CopyOutputResult::Destination::kSharedImage,
         base::BindOnce(&LayerTreeHostCopyRequestTestDeleteSharedImage::
                            ReceiveCopyRequestOutputAndCommit,
                        base::Unretained(this))));
@@ -912,27 +922,8 @@ class LayerTreeHostCopyRequestTestDeleteSharedImage
 
   void DestroyCopyResultAndCheckNumSharedImages() {
     EXPECT_TRUE(result_);
+    // We expect DidDestroySharedImage to be called after releasing the result.
     result_.reset();
-
-    ImplThreadTaskRunner()->PostTask(
-        FROM_HERE,
-        base::BindOnce(&LayerTreeHostCopyRequestTestDeleteSharedImage::
-                           CheckNumSharedImagesAfterReadbackDestroyed,
-                       base::Unretained(this)));
-  }
-
-  void CheckNumSharedImagesAfterReadbackDestroyed() {
-    // After the copy we had |num_shared_images_after_readback_| many shared
-    // images, but releasing the copy output request should cause the shared
-    // image in the request to be destroyed by the compositor, so we should have
-    // 1 less by now.
-    EXPECT_EQ(num_shared_images_after_readback_ - 1,
-              display_context_provider_->SharedImageInterface()
-                  ->shared_image_count());
-
-    // Drop the reference to the context provider on the compositor thread.
-    display_context_provider_.reset();
-    EndTest();
   }
 
   void DisplayDidDrawAndSwapOnThread() override {
@@ -974,6 +965,20 @@ class LayerTreeHostCopyRequestTestDeleteSharedImage
     }
   }
 
+  void DidDestroySharedImage() override {
+    // After the copy we had |num_shared_images_after_readback_| many shared
+    // images, but releasing the copy output request should cause the shared
+    // image in the request to be destroyed by the compositor, so we should have
+    // 1 less by now.
+    EXPECT_EQ(num_shared_images_after_readback_ - 1,
+              display_context_provider_->SharedImageInterface()
+                  ->shared_image_count());
+
+    // Drop the reference to the context provider on the compositor thread.
+    display_context_provider_.reset();
+    EndTest();
+  }
+
   scoped_refptr<viz::TestContextProvider> display_context_provider_;
   int num_swaps_ = 0;
   size_t num_shared_images_without_readback_ = 0;
@@ -1117,7 +1122,7 @@ class LayerTreeHostCopyRequestTestCreatesSharedImage
     // Request a normal texture copy. This should create a new shared image.
     copy_layer_->RequestCopyOfOutput(std::make_unique<viz::CopyOutputRequest>(
         viz::CopyOutputRequest::ResultFormat::RGBA,
-        viz::CopyOutputResult::Destination::kNativeTextures,
+        viz::CopyOutputResult::Destination::kSharedImage,
         base::BindOnce(
             &LayerTreeHostCopyRequestTestCreatesSharedImage::CopyOutputCallback,
             base::Unretained(this))));
@@ -1127,9 +1132,9 @@ class LayerTreeHostCopyRequestTestCreatesSharedImage
     EXPECT_FALSE(result->IsEmpty());
     EXPECT_EQ(result->format(), viz::CopyOutputResult::Format::RGBA);
     EXPECT_EQ(result->destination(),
-              viz::CopyOutputResult::Destination::kNativeTextures);
-    ASSERT_NE(nullptr, result->GetTextureResult());
-    release_ = result->TakeTextureOwnership();
+              viz::CopyOutputResult::Destination::kSharedImage);
+    ASSERT_NE(result->GetSharedImage().get(), nullptr);
+    release_ = result->TakeSharedImageOwnership();
     EXPECT_EQ(1u, release_.size());
   }
 
@@ -1202,7 +1207,7 @@ class LayerTreeHostCopyRequestTestDestroyBeforeCopy
         std::unique_ptr<viz::CopyOutputRequest> request =
             std::make_unique<viz::CopyOutputRequest>(
                 viz::CopyOutputRequest::ResultFormat::RGBA,
-                viz::CopyOutputResult::Destination::kNativeTextures,
+                viz::CopyOutputResult::Destination::kSharedImage,
                 base::BindOnce(&LayerTreeHostCopyRequestTestDestroyBeforeCopy::
                                    CopyOutputCallback,
                                base::Unretained(this)));
@@ -1294,7 +1299,7 @@ class LayerTreeHostCopyRequestTestShutdownBeforeCopy
         std::unique_ptr<viz::CopyOutputRequest> request =
             std::make_unique<viz::CopyOutputRequest>(
                 viz::CopyOutputRequest::ResultFormat::RGBA,
-                viz::CopyOutputResult::Destination::kNativeTextures,
+                viz::CopyOutputResult::Destination::kSharedImage,
                 base::BindOnce(&LayerTreeHostCopyRequestTestShutdownBeforeCopy::
                                    CopyOutputCallback,
                                base::Unretained(this)));
@@ -1410,7 +1415,8 @@ class LayerTreeHostCopyRequestTestMultipleDrawsHiddenCopyRequest
         EXPECT_TRUE(saw_child);
         // Make another draw happen after doing the copy request.
         host_impl->SetViewportDamage(gfx::Rect(1, 1));
-        host_impl->SetNeedsRedraw();
+        host_impl->SetNeedsRedraw(/*animation_only=*/false,
+                                  /*skip_if_inside_draw=*/false);
         break;
       case 3:
         // If LayerTreeHostImpl does the wrong thing, it will try to draw the
