@@ -11,6 +11,7 @@
 #include <optional>
 
 #include "chrome/common/extensions/api/accessibility_private.h"
+#include "content/public/browser/scoped_accessibility_mode.h"
 #include "extensions/browser/extension_function.h"
 
 // API function that darkens or undarkens the screen.
@@ -40,6 +41,14 @@ class AccessibilityPrivateEnableMouseEventsFunction : public ExtensionFunction {
                              ACCESSIBILITY_PRIVATE_ENABLEMOUSEEVENTS)
 };
 
+// API function that enables or disables the live caption feature.
+class AccessibilityPrivateEnableLiveCaptionFunction : public ExtensionFunction {
+  ~AccessibilityPrivateEnableLiveCaptionFunction() override = default;
+  ResponseAction Run() override;
+  DECLARE_EXTENSION_FUNCTION("accessibilityPrivate.enableLiveCaption",
+                             ACCESSIBILITY_PRIVATE_ENABLELIVECAPTION)
+};
+
 // API function that sets the cursor position on the screen in absolute
 // coordinates.
 class AccessibilityPrivateSetCursorPositionFunction : public ExtensionFunction {
@@ -283,12 +292,16 @@ class AccessibilityPrivateSetKeyboardListenerFunction
 // API function that enables or disables web content accessibility support.
 class AccessibilityPrivateSetNativeAccessibilityEnabledFunction
     : public ExtensionFunction {
-  ~AccessibilityPrivateSetNativeAccessibilityEnabledFunction() override =
-      default;
+ public:
+  AccessibilityPrivateSetNativeAccessibilityEnabledFunction();
+
+ private:
+  ~AccessibilityPrivateSetNativeAccessibilityEnabledFunction() override;
   ResponseAction Run() override;
   DECLARE_EXTENSION_FUNCTION(
       "accessibilityPrivate.setNativeAccessibilityEnabled",
       ACCESSIBILITY_PRIVATE_SETNATIVEACCESSIBILITYENABLED)
+  std::unique_ptr<content::ScopedAccessibilityMode> scoped_accessibility_mode_;
 };
 
 // API function that sets native ChromeVox ARC support.
