@@ -10,7 +10,6 @@
 #include "base/files/file_path.h"
 #include "base/functional/callback_forward.h"
 #include "build/build_config.h"
-#include "build/chromeos_buildflags.h"
 #include "chrome/browser/accessibility/caption_bubble_context_browser.h"
 #include "chrome/browser/accessibility/live_caption/live_caption_controller_factory.h"
 #include "chrome/browser/accessibility/live_caption/live_caption_test_util.h"
@@ -34,7 +33,7 @@
 #include "components/sync_preferences/pref_service_syncable.h"
 #include "content/public/test/browser_test.h"
 
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
 #include "ash/constants/ash_features.h"
 #endif
 
@@ -50,14 +49,6 @@ speech::LanguageCode fr_fr() {
   return speech::LanguageCode::kFrFr;
 }
 
-// Unused on builds that aren't ash. CQ fails
-// without this guard.
-#if BUILDFLAG(IS_CHROMEOS_ASH)
-speech::LanguageCode de_de() {
-  return speech::LanguageCode::kDeDe;
-}
-#endif  // BUILDFLAG(IS_CHROMEOS_ASH)
-
 }  // namespace
 
 Profile* CreateProfile() {
@@ -102,6 +93,10 @@ class LiveCaptionControllerTest : public LiveCaptionBrowserTest {
 
   bool DispatchTranscriptionToProfile(std::string text, Profile* profile) {
     return GetControllerForProfile(profile)->DispatchTranscription(
+        browser()
+            ->tab_strip_model()
+            ->GetActiveWebContents()
+            ->GetPrimaryMainFrame(),
         GetCaptionBubbleContextBrowser(),
         media::SpeechRecognitionResult(text, /* is_final */ false));
   }
@@ -120,6 +115,10 @@ class LiveCaptionControllerTest : public LiveCaptionBrowserTest {
 
   void OnAudioStreamEndOnProfile(Profile* profile) {
     GetControllerForProfile(profile)->OnAudioStreamEnd(
+        browser()
+            ->tab_strip_model()
+            ->GetActiveWebContents()
+            ->GetPrimaryMainFrame(),
         GetCaptionBubbleContextBrowser());
   }
 
@@ -164,13 +163,6 @@ class LiveCaptionControllerTest : public LiveCaptionBrowserTest {
 #endif
   }
 
-#if BUILDFLAG(IS_CHROMEOS_ASH)
-  void ToggleLiveCaptionForBabelOrca(bool enabled) {
-    LiveCaptionControllerFactory::GetForProfile(browser()->profile())
-        ->ToggleLiveCaptionForBabelOrca(enabled);
-  }
-#endif
-
  private:
   std::unique_ptr<CaptionBubbleContextBrowser> caption_bubble_context_;
 };
@@ -358,7 +350,7 @@ IN_PROC_BROWSER_TEST_F(LiveCaptionControllerTest, OnToggleFullscreen) {
 }
 #endif
 
-#if !BUILDFLAG(IS_CHROMEOS_ASH)  // No multi-profile on ChromeOS.
+#if !BUILDFLAG(IS_CHROMEOS)  // No multi-profile on ChromeOS.
 
 IN_PROC_BROWSER_TEST_F(LiveCaptionControllerTest,
                        LiveCaptionEnabledChanged_MultipleProfiles) {
@@ -461,99 +453,6 @@ IN_PROC_BROWSER_TEST_F(LiveCaptionControllerTest,
   ExpectIsWidgetVisibleOnProfile(false, profile1);
   ExpectIsWidgetVisibleOnProfile(false, profile2);
 }
-#endif  // !BUILDFLAG(IS_CHROMEOS_ASH)
+#endif  // !BUILDFLAG(IS_CHROMEOS)
 
-#if BUILDFLAG(IS_CHROMEOS_ASH)
-// Tests that live caption can be enabled for babel orca.
-IN_PROC_BROWSER_TEST_F(LiveCaptionControllerTest,
-                       ToggleLiveCaptionForBabelOrca) {
-  EXPECT_EQ(nullptr, GetBubbleController());
-  EXPECT_FALSE(HasBubbleController());
-
-  // This helper function doesn't notify Soda installed as oppposed to
-  // `SetLiveCaptionEnabled` so we manually invoke those methods below.
-  ToggleLiveCaptionForBabelOrca(true);
-  speech::SodaInstaller::GetInstance()->NotifySodaInstalledForTesting();
-  speech::SodaInstaller::GetInstance()->NotifySodaInstalledForTesting(en_us());
-  EXPECT_NE(nullptr, GetBubbleController());
-  EXPECT_TRUE(HasBubbleController());
-
-  ToggleLiveCaptionForBabelOrca(false);
-  EXPECT_EQ(nullptr, GetBubbleController());
-  EXPECT_FALSE(HasBubbleController());
-}
-
-// like the test above, but verifies that BabelOrca still works  with a
-// distinct language from live caption.
-IN_PROC_BROWSER_TEST_F(LiveCaptionControllerTest,
-                       ToggleBabelOrcaDistinctLanguage) {
-  browser()->profile()->GetPrefs()->SetString(
-      prefs::kUserMicrophoneCaptionLanguageCode,
-      speech::GetLanguageName(fr_fr()));
-
-  EXPECT_EQ(nullptr, GetBubbleController());
-  EXPECT_FALSE(HasBubbleController());
-
-  // This helper function doesn't notify Soda installed as oppposed to
-  // `SetLiveCaptionEnabled` so we manually invoke those methods below.
-  ToggleLiveCaptionForBabelOrca(true);
-  speech::SodaInstaller::GetInstance()->NotifySodaInstalledForTesting();
-  speech::SodaInstaller::GetInstance()->NotifySodaInstalledForTesting(fr_fr());
-  EXPECT_NE(nullptr, GetBubbleController());
-  EXPECT_TRUE(HasBubbleController());
-
-  ToggleLiveCaptionForBabelOrca(false);
-  EXPECT_EQ(nullptr, GetBubbleController());
-  EXPECT_FALSE(HasBubbleController());
-}
-
-IN_PROC_BROWSER_TEST_F(LiveCaptionControllerTest, OnSodaInstalledForBabelOrca) {
-  browser()->profile()->GetPrefs()->SetString(
-      prefs::kUserMicrophoneCaptionLanguageCode,
-      speech::GetLanguageName(fr_fr()));
-
-  // Toggle the feature.
-  EXPECT_FALSE(HasBubbleController());
-  ToggleLiveCaptionForBabelOrca(true);
-  EXPECT_FALSE(HasBubbleController());
-
-  // install a language and binary that is not either the live caption language
-  // or the language for BabelOrca.
-  speech::SodaInstaller::GetInstance()->NotifySodaInstalledForTesting(de_de());
-  speech::SodaInstaller::GetInstance()->NotifySodaInstalledForTesting();
-  EXPECT_FALSE(HasBubbleController());
-
-  // Install the language for BabelOrca, live caption should be enabled.
-  speech::SodaInstaller::GetInstance()->NotifySodaInstalledForTesting(fr_fr());
-  EXPECT_TRUE(HasBubbleController());
-
-  // turn off Babel Orca, now we make sure that Live Caption still works.
-  ToggleLiveCaptionForBabelOrca(false);
-  EXPECT_FALSE(HasBubbleController());
-
-  // Toggle live caption, but the associated language is not currently
-  // installed. manually invoke rather than use the helper so that we
-  // can verify that we ignore irrelevant languages below.
-  browser()->profile()->GetPrefs()->SetBoolean(prefs::kLiveCaptionEnabled,
-                                               true);
-  EXPECT_FALSE(HasBubbleController());
-
-  // Once again install the neither nor language to verify we're handling
-  // preconditions correctly in both cases.  We have to invoke
-  // `UninstallSodaForTesting` in order to verify with the irrelevant
-  // language again.
-  speech::SodaInstaller::GetInstance()->UninstallSodaForTesting();
-  speech::SodaInstaller::GetInstance()->NotifySodaInstalledForTesting(de_de());
-  speech::SodaInstaller::GetInstance()->NotifySodaInstalledForTesting();
-  EXPECT_FALSE(HasBubbleController());
-
-  // Install the language for live caption, should be enabled.
-  speech::SodaInstaller::GetInstance()->NotifySodaInstalledForTesting(en_us());
-  EXPECT_TRUE(HasBubbleController());
-
-  // Finally verify we can still turn it off.
-  SetLiveCaptionEnabled(false);
-  EXPECT_FALSE(HasBubbleController());
-}
-#endif  // BUILDFLAG(IS_CHROMEOS_ASH)
 }  // namespace captions
