@@ -1,4 +1,4 @@
-// Copyright 2014 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -7,23 +7,31 @@
 #include <stddef.h>
 #include <string.h>
 
+#include <string_view>
 #include <utility>
 
-#include "base/bind.h"
+#include "base/compiler_specific.h"
+#include "base/functional/bind.h"
 #include "base/location.h"
 #include "base/memory/ptr_util.h"
-#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_type.h"
+#include "base/no_destructor.h"
 #include "base/strings/strcat.h"
 #include "base/strings/string_number_conversions.h"
 #include "base/strings/string_util.h"
 #include "base/strings/stringprintf.h"
-#include "base/task/post_task.h"
-#include "base/threading/thread_task_runner_handle.h"
+#include "base/task/single_thread_task_runner.h"
+#include "base/task/thread_pool.h"
+#include "base/threading/thread.h"
+#include "base/time/time.h"
 #include "chrome/browser/devtools/device/usb/usb_device_manager_helper.h"
 #include "chrome/browser/devtools/device/usb/usb_device_provider.h"
-#include "content/public/browser/browser_task_traits.h"
+#include "content/public/browser/browser_thread.h"
 #include "net/base/io_buffer.h"
+#include "net/base/ip_endpoint.h"
 #include "net/base/net_errors.h"
+#include "net/http/http_response_headers.h"
+#include "net/http/http_util.h"
 #include "net/socket/stream_socket.h"
 #include "net/traffic_annotation/network_traffic_annotation.h"
 
@@ -65,31 +73,31 @@ net::NetworkTrafficAnnotationTag kAndroidDeviceManagerTrafficAnnotation =
 
 static void PostDeviceInfoCallback(
     scoped_refptr<base::SingleThreadTaskRunner> response_task_runner,
-    const AndroidDeviceManager::DeviceInfoCallback& callback,
+    AndroidDeviceManager::DeviceInfoCallback callback,
     const AndroidDeviceManager::DeviceInfo& device_info) {
-  response_task_runner->PostTask(FROM_HERE,
-                                 base::BindOnce(callback, device_info));
+  response_task_runner->PostTask(
+      FROM_HERE, base::BindOnce(std::move(callback), device_info));
 }
 
 static void PostCommandCallback(
     scoped_refptr<base::SingleThreadTaskRunner> response_task_runner,
-    const AndroidDeviceManager::CommandCallback& callback,
+    AndroidDeviceManager::CommandCallback callback,
     int result,
     const std::string& response) {
-  response_task_runner->PostTask(FROM_HERE,
-                                 base::BindOnce(callback, result, response));
+  response_task_runner->PostTask(
+      FROM_HERE, base::BindOnce(std::move(callback), result, response));
 }
 
 static void PostHttpUpgradeCallback(
     scoped_refptr<base::SingleThreadTaskRunner> response_task_runner,
-    const AndroidDeviceManager::HttpUpgradeCallback& callback,
+    AndroidDeviceManager::HttpUpgradeCallback callback,
     int result,
     const std::string& extensions,
     const std::string& body_head,
     std::unique_ptr<net::StreamSocket> socket) {
   response_task_runner->PostTask(
-      FROM_HERE, base::BindOnce(callback, result, extensions, body_head,
-                                std::move(socket)));
+      FROM_HERE, base::BindOnce(std::move(callback), result, extensions,
+                                body_head, std::move(socket)));
 }
 
 class HttpRequest {
@@ -98,24 +106,24 @@ class HttpRequest {
   typedef AndroidDeviceManager::HttpUpgradeCallback HttpUpgradeCallback;
 
   static void CommandRequest(const std::string& path,
-                             const CommandCallback& callback,
+                             CommandCallback callback,
                              int result,
                              std::unique_ptr<net::StreamSocket> socket) {
     if (result != net::OK) {
-      callback.Run(result, std::string());
+      std::move(callback).Run(result, std::string());
       return;
     }
-    new HttpRequest(std::move(socket), path, {}, callback);
+    new HttpRequest(std::move(socket), path, {}, std::move(callback));
   }
 
   static void HttpUpgradeRequest(const std::string& path,
                                  const std::string& extensions,
-                                 const HttpUpgradeCallback& callback,
+                                 HttpUpgradeCallback callback,
                                  int result,
                                  std::unique_ptr<net::StreamSocket> socket) {
     if (result != net::OK) {
-      callback.Run(result, std::string(), std::string(),
-                   base::WrapUnique<net::StreamSocket>(nullptr));
+      std::move(callback).Run(result, std::string(), std::string(),
+                              base::WrapUnique<net::StreamSocket>(nullptr));
       return;
     }
     std::map<std::string, std::string> headers = {
@@ -125,34 +133,31 @@ class HttpRequest {
         {"Sec-WebSocket-Version", "13"}};
     if (!extensions.empty())
       headers["Sec-WebSocket-Extensions"] = extensions;
-    new HttpRequest(std::move(socket), path, headers, callback);
+    new HttpRequest(std::move(socket), path, headers, std::move(callback));
   }
 
  private:
   HttpRequest(std::unique_ptr<net::StreamSocket> socket,
               const std::string& path,
               const std::map<std::string, std::string>& headers,
-              const CommandCallback& callback)
+              CommandCallback callback)
       : socket_(std::move(socket)),
-        command_callback_(callback),
-        expected_total_size_(0),
-        header_size_(std::string::npos) {
+        command_callback_(std::move(callback)),
+        expected_total_size_(0) {
     SendRequest(path, headers);
   }
 
   HttpRequest(std::unique_ptr<net::StreamSocket> socket,
               const std::string& path,
               const std::map<std::string, std::string>& headers,
-              const HttpUpgradeCallback& callback)
+              HttpUpgradeCallback callback)
       : socket_(std::move(socket)),
-        http_upgrade_callback_(callback),
-        expected_total_size_(0),
-        header_size_(std::string::npos) {
+        http_upgrade_callback_(std::move(callback)),
+        expected_total_size_(0) {
     SendRequest(path, headers);
   }
 
-  ~HttpRequest() {
-  }
+  ~HttpRequest() = default;
 
   void DoSendRequest(int result) {
     while (result != net::ERR_IO_PENDING) {
@@ -168,10 +173,10 @@ class HttpRequest {
         return;
       }
 
-      result = socket_->Write(
-          request_.get(), request_->BytesRemaining(),
-          base::Bind(&HttpRequest::DoSendRequest, base::Unretained(this)),
-          kAndroidDeviceManagerTrafficAnnotation);
+      result = socket_->Write(request_.get(), request_->BytesRemaining(),
+                              base::BindOnce(&HttpRequest::DoSendRequest,
+                                             weak_ptr_factory_.GetWeakPtr()),
+                              kAndroidDeviceManagerTrafficAnnotation);
     }
   }
 
@@ -186,7 +191,7 @@ class HttpRequest {
     std::string crlf = "\r\n";
     std::string colon = ": ";
 
-    std::vector<base::StringPiece> pieces = {requestLine, crlf};
+    std::vector<std::string_view> pieces = {requestLine, crlf};
     for (const auto& header_and_value : headers) {
       pieces.insert(pieces.end(), {header_and_value.first, colon,
                                    header_and_value.second, crlf});
@@ -194,12 +199,15 @@ class HttpRequest {
     pieces.insert(pieces.end(), {crlf});
 
     std::string request = base::StrCat(pieces);
-    scoped_refptr<net::IOBuffer> base_buffer =
-        base::MakeRefCounted<net::IOBuffer>(request.size());
-    memcpy(base_buffer->data(), request.data(), request.size());
+    auto base_buffer =
+        base::MakeRefCounted<net::IOBufferWithSize>(request.size());
+    UNSAFE_TODO(memcpy(base_buffer->data(), request.data(), request.size()));
     request_ = base::MakeRefCounted<net::DrainableIOBuffer>(
         std::move(base_buffer), request.size());
-
+    timeout_timer_.Start(
+        FROM_HERE, base::Seconds(1),
+        base::BindOnce(&HttpRequest::Die, weak_ptr_factory_.GetWeakPtr(),
+                       net::ERR_TIMED_OUT));
     DoSendRequest(net::OK);
   }
 
@@ -207,17 +215,19 @@ class HttpRequest {
     if (!CheckNetResultOrDie(result))
       return;
 
-    response_buffer_ = base::MakeRefCounted<net::IOBuffer>(kBufferSize);
+    response_buffer_ = base::MakeRefCounted<net::IOBufferWithSize>(kBufferSize);
 
-    result = socket_->Read(
-        response_buffer_.get(),
-        kBufferSize,
-        base::Bind(&HttpRequest::OnResponseData, base::Unretained(this)));
+    result = socket_->Read(response_buffer_.get(), kBufferSize,
+                           base::BindOnce(&HttpRequest::OnResponseData,
+                                          weak_ptr_factory_.GetWeakPtr()));
     if (result != net::ERR_IO_PENDING)
       OnResponseData(result);
   }
 
   void OnResponseData(int result) {
+    scoped_refptr<net::HttpResponseHeaders> headers = nullptr;
+    size_t header_size;
+
     do {
       if (!CheckNetResultOrDie(result))
         return;
@@ -228,24 +238,26 @@ class HttpRequest {
 
       response_.append(response_buffer_->data(), result);
 
-      if (header_size_ == std::string::npos) {
-        header_size_ = response_.find("\r\n\r\n");
+      if (!headers) {
+        header_size = response_.find("\r\n\r\n");
 
-        if (header_size_ != std::string::npos) {
-          header_size_ += 4;
+        if (header_size != std::string::npos) {
+          header_size += 4;
+          headers = base::MakeRefCounted<net::HttpResponseHeaders>(
+              net::HttpUtil::AssembleRawHeaders(
+                  std::string_view(response_.data(), header_size)));
 
           int expected_body_size = 0;
 
-          // TODO(kaznacheev): Use net::HttpResponseHeader to parse the header.
-          std::string content_length = ExtractHeader("Content-Length:");
-          if (!content_length.empty()) {
-            if (!base::StringToInt(content_length, &expected_body_size)) {
+          if (std::optional<std::string> content_length =
+                  headers->GetNormalizedHeader("Content-Length")) {
+            if (!base::StringToInt(*content_length, &expected_body_size)) {
               CheckNetResultOrDie(net::ERR_FAILED);
               return;
             }
           }
 
-          expected_total_size_ = header_size_ + expected_body_size;
+          expected_total_size_ = header_size + expected_body_size;
         }
       }
 
@@ -255,59 +267,58 @@ class HttpRequest {
       //
       // Some (part of) WebSocket frames can be already received into
       // |response_|.
-      if (header_size_ != std::string::npos &&
-          response_.length() >= expected_total_size_) {
-        const std::string& body = response_.substr(header_size_);
+      if (headers && response_.length() >= expected_total_size_) {
+        const std::string& body = response_.substr(header_size);
 
         if (!command_callback_.is_null()) {
-          command_callback_.Run(net::OK, body);
+          std::move(command_callback_).Run(net::OK, body);
         } else {
-          http_upgrade_callback_.Run(net::OK,
-                                     ExtractHeader("Sec-WebSocket-Extensions:"),
-                                     body, std::move(socket_));
+          std::string sec_websocket_extensions =
+              headers->GetNormalizedHeader("Sec-WebSocket-Extensions")
+                  .value_or(std::string());
+          std::move(http_upgrade_callback_)
+              .Run(net::OK, sec_websocket_extensions, body,
+                   std::move(socket_));
         }
 
         delete this;
         return;
       }
 
-      result = socket_->Read(
-          response_buffer_.get(), kBufferSize,
-          base::Bind(&HttpRequest::OnResponseData, base::Unretained(this)));
+      result = socket_->Read(response_buffer_.get(), kBufferSize,
+                             base::BindOnce(&HttpRequest::OnResponseData,
+                                            weak_ptr_factory_.GetWeakPtr()));
     } while (result != net::ERR_IO_PENDING);
   }
 
-  std::string ExtractHeader(const std::string& header) {
-    size_t start_pos = response_.find(header);
-    if (start_pos == std::string::npos)
-      return std::string();
-
-    size_t endline_pos = response_.find("\n", start_pos);
-    if (endline_pos == std::string::npos)
-      return std::string();
-
-    std::string value = response_.substr(
-        start_pos + header.length(), endline_pos - start_pos - header.length());
-    base::TrimWhitespaceASCII(value, base::TRIM_ALL, &value);
-    return value;
+  void Die(int result) {
+    if (!command_callback_.is_null()) {
+      std::move(command_callback_).Run(result, std::string());
+    } else {
+      std::move(http_upgrade_callback_)
+          .Run(result, std::string(), std::string(),
+               base::WrapUnique<net::StreamSocket>(nullptr));
+    }
+    delete this;
   }
 
   bool CheckNetResultOrDie(int result) {
-    if (result >= 0)
+    if (result >= 0) {
+      // Reset the timer whenever a non-error is received from network.
+      // It means network is responsive for now, so we reset the timer
+      // and wait for a new result until the next timeout.
+      timeout_timer_.Reset();
       return true;
-    if (!command_callback_.is_null()) {
-      command_callback_.Run(result, std::string());
-    } else {
-      http_upgrade_callback_.Run(result, std::string(), std::string(),
-                                 base::WrapUnique<net::StreamSocket>(nullptr));
     }
-    delete this;
+
+    Die(result);
     return false;
   }
 
   std::unique_ptr<net::StreamSocket> socket_;
   scoped_refptr<net::DrainableIOBuffer> request_;
   std::string response_;
+  base::OneShotTimer timeout_timer_;
   CommandCallback command_callback_;
   HttpUpgradeCallback http_upgrade_callback_;
 
@@ -320,53 +331,52 @@ class HttpRequest {
   // - Otherwise, this variable is set to the size of the header (including the
   //   last two CRLFs).
   size_t expected_total_size_;
-  // Initially set to std::string::npos. Once the end of the header is seen,
-  // set to the size of the header part in |response_| including the two CRLFs
-  // at the end.
-  size_t header_size_;
+  base::WeakPtrFactory<HttpRequest> weak_ptr_factory_{this};
 };
 
 class DevicesRequest : public base::RefCountedThreadSafe<DevicesRequest> {
  public:
-  typedef AndroidDeviceManager::DeviceInfo DeviceInfo;
-  typedef AndroidDeviceManager::DeviceProvider DeviceProvider;
-  typedef AndroidDeviceManager::DeviceProviders DeviceProviders;
-  typedef AndroidDeviceManager::DeviceDescriptors DeviceDescriptors;
-  typedef base::Callback<void(std::unique_ptr<DeviceDescriptors>)>
-      DescriptorsCallback;
+  using DeviceInfo = AndroidDeviceManager::DeviceInfo;
+  using DeviceProvider = AndroidDeviceManager::DeviceProvider;
+  using DeviceProviders = AndroidDeviceManager::DeviceProviders;
+  using DeviceDescriptors = AndroidDeviceManager::DeviceDescriptors;
+  using DescriptorsCallback =
+      base::OnceCallback<void(std::unique_ptr<DeviceDescriptors>)>;
 
   static void Start(
       scoped_refptr<base::SingleThreadTaskRunner> device_task_runner,
       const DeviceProviders& providers,
-      const DescriptorsCallback& callback) {
+      DescriptorsCallback callback) {
     // Don't keep counted reference on calling thread;
     scoped_refptr<DevicesRequest> request =
-        base::WrapRefCounted(new DevicesRequest(callback));
-    for (auto it = providers.begin(); it != providers.end(); ++it) {
+        base::WrapRefCounted(new DevicesRequest(std::move(callback)));
+    for (const auto& provider : providers) {
       device_task_runner->PostTask(
-          FROM_HERE, base::BindOnce(&DeviceProvider::QueryDevices, *it,
-                                    base::Bind(&DevicesRequest::ProcessSerials,
-                                               request, *it)));
+          FROM_HERE,
+          base::BindOnce(&DeviceProvider::QueryDevices, provider,
+                         base::BindOnce(&DevicesRequest::ProcessSerials,
+                                        request, provider)));
     }
     device_task_runner->ReleaseSoon(FROM_HERE, std::move(request));
   }
 
  private:
-  explicit DevicesRequest(const DescriptorsCallback& callback)
-      : response_task_runner_(base::ThreadTaskRunnerHandle::Get()),
-        callback_(callback),
+  explicit DevicesRequest(DescriptorsCallback callback)
+      : response_task_runner_(
+            base::SingleThreadTaskRunner::GetCurrentDefault()),
+        callback_(std::move(callback)),
         descriptors_(new DeviceDescriptors()) {}
 
   friend class base::RefCountedThreadSafe<DevicesRequest>;
   ~DevicesRequest() {
     response_task_runner_->PostTask(
-        FROM_HERE, base::BindOnce(callback_, std::move(descriptors_)));
+        FROM_HERE,
+        base::BindOnce(std::move(callback_), std::move(descriptors_)));
   }
 
-  typedef std::vector<std::string> Serials;
+  using Serials = std::vector<std::string>;
 
-  void ProcessSerials(scoped_refptr<DeviceProvider> provider,
-                      const Serials& serials) {
+  void ProcessSerials(scoped_refptr<DeviceProvider> provider, Serials serials) {
     for (auto it = serials.begin(); it != serials.end(); ++it) {
       descriptors_->resize(descriptors_->size() + 1);
       descriptors_->back().provider = provider;
@@ -379,10 +389,9 @@ class DevicesRequest : public base::RefCountedThreadSafe<DevicesRequest> {
   std::unique_ptr<DeviceDescriptors> descriptors_;
 };
 
-void OnCountDevices(const base::Callback<void(int)>& callback,
-                    int device_count) {
-  base::PostTaskWithTraits(FROM_HERE, {BrowserThread::UI},
-                           base::BindOnce(callback, device_count));
+void OnCountDevices(base::OnceCallback<void(int)> callback, int device_count) {
+  content::GetUIThreadTaskRunner({})->PostTask(
+      FROM_HERE, base::BindOnce(std::move(callback), device_count));
 }
 
 }  // namespace
@@ -394,31 +403,32 @@ AndroidDeviceManager::BrowserInfo::BrowserInfo()
 AndroidDeviceManager::BrowserInfo::BrowserInfo(const BrowserInfo& other) =
     default;
 
+AndroidDeviceManager::BrowserInfo& AndroidDeviceManager::BrowserInfo::operator=(
+    const BrowserInfo& other) = default;
+
 AndroidDeviceManager::DeviceInfo::DeviceInfo()
     : model(kModelOffline), connected(false) {
 }
 
 AndroidDeviceManager::DeviceInfo::DeviceInfo(const DeviceInfo& other) = default;
 
-AndroidDeviceManager::DeviceInfo::~DeviceInfo() {
-}
+AndroidDeviceManager::DeviceInfo::~DeviceInfo() = default;
 
-AndroidDeviceManager::DeviceDescriptor::DeviceDescriptor() {
-}
+AndroidDeviceManager::DeviceDescriptor::DeviceDescriptor() = default;
 
 AndroidDeviceManager::DeviceDescriptor::DeviceDescriptor(
     const DeviceDescriptor& other) = default;
 
-AndroidDeviceManager::DeviceDescriptor::~DeviceDescriptor() {
-}
+AndroidDeviceManager::DeviceDescriptor::~DeviceDescriptor() = default;
 
 void AndroidDeviceManager::DeviceProvider::SendJsonRequest(
     const std::string& serial,
     const std::string& socket_name,
     const std::string& request,
-    const CommandCallback& callback) {
+    CommandCallback callback) {
   OpenSocket(serial, socket_name,
-             base::Bind(&HttpRequest::CommandRequest, request, callback));
+             base::BindOnce(&HttpRequest::CommandRequest, request,
+                            std::move(callback)));
 }
 
 void AndroidDeviceManager::DeviceProvider::HttpUpgrade(
@@ -426,69 +436,72 @@ void AndroidDeviceManager::DeviceProvider::HttpUpgrade(
     const std::string& socket_name,
     const std::string& path,
     const std::string& extensions,
-    const HttpUpgradeCallback& callback) {
-  OpenSocket(
-      serial, socket_name,
-      base::Bind(&HttpRequest::HttpUpgradeRequest, path, extensions, callback));
+    HttpUpgradeCallback callback) {
+  OpenSocket(serial, socket_name,
+             base::BindOnce(&HttpRequest::HttpUpgradeRequest, path, extensions,
+                            std::move(callback)));
 }
 
 void AndroidDeviceManager::DeviceProvider::ReleaseDevice(
     const std::string& serial) {
 }
 
-AndroidDeviceManager::DeviceProvider::DeviceProvider() {
-}
+AndroidDeviceManager::DeviceProvider::DeviceProvider() = default;
 
-AndroidDeviceManager::DeviceProvider::~DeviceProvider() {
-}
+AndroidDeviceManager::DeviceProvider::~DeviceProvider() = default;
 
 void AndroidDeviceManager::Device::QueryDeviceInfo(
-    const DeviceInfoCallback& callback) {
+    DeviceInfoCallback callback) {
   task_runner_->PostTask(
       FROM_HERE,
       base::BindOnce(
           &DeviceProvider::QueryDeviceInfo, provider_, serial_,
-          base::Bind(&PostDeviceInfoCallback,
-                     base::ThreadTaskRunnerHandle::Get(), callback)));
+          base::BindOnce(&PostDeviceInfoCallback,
+                         base::SingleThreadTaskRunner::GetCurrentDefault(),
+                         std::move(callback))));
 }
 
 void AndroidDeviceManager::Device::OpenSocket(const std::string& socket_name,
-                                              const SocketCallback& callback) {
+                                              SocketCallback callback) {
   task_runner_->PostTask(
       FROM_HERE, base::BindOnce(&DeviceProvider::OpenSocket, provider_, serial_,
-                                socket_name, callback));
+                                socket_name, std::move(callback)));
 }
 
 void AndroidDeviceManager::Device::SendJsonRequest(
     const std::string& socket_name,
     const std::string& request,
-    const CommandCallback& callback) {
+    CommandCallback callback) {
   task_runner_->PostTask(
-      FROM_HERE, base::BindOnce(&DeviceProvider::SendJsonRequest, provider_,
-                                serial_, socket_name, request,
-                                base::Bind(&PostCommandCallback,
-                                           base::ThreadTaskRunnerHandle::Get(),
-                                           callback)));
+      FROM_HERE,
+      base::BindOnce(
+          &DeviceProvider::SendJsonRequest, provider_, serial_, socket_name,
+          request,
+          base::BindOnce(&PostCommandCallback,
+                         base::SingleThreadTaskRunner::GetCurrentDefault(),
+                         std::move(callback))));
 }
 
-void AndroidDeviceManager::Device::HttpUpgrade(
-    const std::string& socket_name,
-    const std::string& path,
-    const std::string& extensions,
-    const HttpUpgradeCallback& callback) {
+void AndroidDeviceManager::Device::HttpUpgrade(const std::string& socket_name,
+                                               const std::string& path,
+                                               const std::string& extensions,
+                                               HttpUpgradeCallback callback) {
   task_runner_->PostTask(
-      FROM_HERE, base::BindOnce(&DeviceProvider::HttpUpgrade, provider_,
-                                serial_, socket_name, path, extensions,
-                                base::Bind(&PostHttpUpgradeCallback,
-                                           base::ThreadTaskRunnerHandle::Get(),
-                                           callback)));
+      FROM_HERE,
+      base::BindOnce(
+          &DeviceProvider::HttpUpgrade, provider_, serial_, socket_name, path,
+          extensions,
+          base::BindOnce(&PostHttpUpgradeCallback,
+                         base::SingleThreadTaskRunner::GetCurrentDefault(),
+                         std::move(callback))));
 }
 
 AndroidDeviceManager::Device::Device(
     scoped_refptr<base::SingleThreadTaskRunner> device_task_runner,
     scoped_refptr<DeviceProvider> provider,
     const std::string& serial)
-    : RefCountedDeleteOnSequence<Device>(base::ThreadTaskRunnerHandle::Get()),
+    : RefCountedDeleteOnSequence<Device>(
+          base::SingleThreadTaskRunner::GetCurrentDefault()),
       task_runner_(device_task_runner),
       provider_(provider),
       serial_(serial) {}
@@ -499,25 +512,20 @@ AndroidDeviceManager::Device::~Device() {
                                 std::move(provider_), std::move(serial_)));
 }
 
-AndroidDeviceManager::HandlerThread*
-AndroidDeviceManager::HandlerThread::instance_ = nullptr;
-
 // static
-scoped_refptr<AndroidDeviceManager::HandlerThread>
+AndroidDeviceManager::HandlerThread*
 AndroidDeviceManager::HandlerThread::GetInstance() {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
-  if (!instance_)
-    new HandlerThread();
-  return instance_;
+  static base::NoDestructor<AndroidDeviceManager::HandlerThread> s_instance;
+  return s_instance.get();
 }
 
 AndroidDeviceManager::HandlerThread::HandlerThread() {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
-  instance_ = this;
   thread_ = new base::Thread(kDevToolsAdbBridgeThreadName);
   base::Thread::Options options;
-  options.message_loop_type = base::MessageLoop::TYPE_IO;
-  if (!thread_->StartWithOptions(options)) {
+  options.message_pump_type = base::MessagePumpType::IO;
+  if (!thread_->StartWithOptions(std::move(options))) {
     delete thread_;
     thread_ = nullptr;
   }
@@ -536,11 +544,10 @@ void AndroidDeviceManager::HandlerThread::StopThread(
 
 AndroidDeviceManager::HandlerThread::~HandlerThread() {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
-  instance_ = nullptr;
   if (!thread_)
     return;
   // Shut down thread on a thread other than UI so it can join a thread.
-  base::PostTaskWithTraits(
+  base::ThreadPool::PostTask(
       FROM_HERE,
       {base::WithBaseSyncPrimitives(), base::TaskPriority::BEST_EFFORT},
       base::BindOnce(&HandlerThread::StopThread, thread_));
@@ -559,22 +566,24 @@ void AndroidDeviceManager::SetDeviceProviders(
   providers_ = providers;
 }
 
-void AndroidDeviceManager::QueryDevices(const DevicesCallback& callback) {
-  DevicesRequest::Start(handler_thread_->message_loop(), providers_,
-                        base::Bind(&AndroidDeviceManager::UpdateDevices,
-                                   weak_factory_.GetWeakPtr(), callback));
+void AndroidDeviceManager::QueryDevices(DevicesCallback callback) {
+  DevicesRequest::Start(
+      handler_thread_->message_loop(), providers_,
+      base::BindOnce(&AndroidDeviceManager::UpdateDevices,
+                     weak_factory_.GetWeakPtr(), std::move(callback)));
 }
 
 void AndroidDeviceManager::CountDevices(
-    const base::Callback<void(int)>& callback) {
+    base::OnceCallback<void(int)> callback) {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
   handler_thread_->message_loop()->PostTask(
-      FROM_HERE, base::BindOnce(&UsbDeviceManagerHelper::CountDevices,
-                                base::BindOnce(&OnCountDevices, callback)));
+      FROM_HERE,
+      base::BindOnce(&UsbDeviceManagerHelper::CountDevices,
+                     base::BindOnce(&OnCountDevices, std::move(callback))));
 }
 
 void AndroidDeviceManager::set_usb_device_manager_for_test(
-    device::mojom::UsbDeviceManagerPtrInfo fake_usb_manager) {
+    mojo::PendingRemote<device::mojom::UsbDeviceManager> fake_usb_manager) {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
   handler_thread_->message_loop()->PostTask(
       FROM_HERE,
@@ -591,7 +600,7 @@ AndroidDeviceManager::~AndroidDeviceManager() {
 }
 
 void AndroidDeviceManager::UpdateDevices(
-    const DevicesCallback& callback,
+    DevicesCallback callback,
     std::unique_ptr<DeviceDescriptors> descriptors) {
   Devices response;
   DeviceWeakMap new_devices;
@@ -611,5 +620,5 @@ void AndroidDeviceManager::UpdateDevices(
     new_devices[it->serial] = device->weak_factory_.GetWeakPtr();
   }
   devices_.swap(new_devices);
-  callback.Run(response);
+  std::move(callback).Run(response);
 }
