@@ -8,26 +8,31 @@
 
 #include "base/functional/bind.h"
 #include "base/functional/callback_helpers.h"
-#include "base/lazy_instance.h"
+#include "base/no_destructor.h"
 #include "base/strings/utf_string_conversions.h"
 #include "chrome/browser/browser_features.h"
 #include "chrome/browser/devtools/chrome_devtools_manager_delegate.h"
 #include "chrome/browser/devtools/devtools_window.h"
-#include "chrome/browser/ui/browser.h"
-#include "chrome/browser/ui/browser_window.h"
-#include "chrome/browser/ui/tabs/tab_strip_model.h"
 #include "content/public/browser/devtools_agent_host.h"
 #include "content/public/browser/render_frame_host.h"
 #include "content/public/browser/web_contents.h"
 #include "content/public/test/test_utils.h"
 
+#if !BUILDFLAG(IS_ANDROID)
+#include "chrome/browser/ui/browser.h"
+#include "chrome/browser/ui/browser_window.h"
+#include "chrome/browser/ui/tabs/tab_strip_model.h"
+#endif  // !BUILDFLAG(IS_ANDROID)
+
 namespace {
 
 const char kHarnessScript[] = "Tests.js";
 
 typedef std::vector<DevToolsWindowTesting*> DevToolsWindowTestings;
-base::LazyInstance<DevToolsWindowTestings>::Leaky
-    g_devtools_window_testing_instances = LAZY_INSTANCE_INITIALIZER;
+DevToolsWindowTestings& GetDevToolsWindowTestingInstances() {
+  static base::NoDestructor<DevToolsWindowTestings> instances;
+  return *instances;
+}
 }
 
 DevToolsWindowTesting::DevToolsWindowTesting(DevToolsWindow* window)
@@ -35,21 +40,22 @@ DevToolsWindowTesting::DevToolsWindowTesting(DevToolsWindow* window)
   DCHECK(window);
   window->close_callback_ =
       base::BindOnce(&DevToolsWindowTesting::WindowClosed, window);
-  g_devtools_window_testing_instances.Get().push_back(this);
+  GetDevToolsWindowTestingInstances().push_back(this);
 }
 
 DevToolsWindowTesting::~DevToolsWindowTesting() {
-  DevToolsWindowTestings* instances =
-      g_devtools_window_testing_instances.Pointer();
-  auto it = std::ranges::find(*instances, this);
-  CHECK(it != instances->end());
-  instances->erase(it);
+  DevToolsWindowTestings& instances = GetDevToolsWindowTestingInstances();
+  auto it = std::ranges::find(instances, this);
+  CHECK(it != instances.end());
+  instances.erase(it);
   if (!close_callback_.is_null())
     std::move(close_callback_).Run();
 
+#if !BUILDFLAG(IS_ANDROID)
   // Needed for Chrome_DevToolsADBThread to shut down gracefully in tests.
   ChromeDevToolsManagerDelegate::GetInstance()
       ->ResetAndroidDeviceManagerForTesting();
+#endif  // !BUILDFLAG(IS_ANDROID)
 }
 
 // static
@@ -62,13 +68,10 @@ DevToolsWindowTesting* DevToolsWindowTesting::Get(DevToolsWindow* window) {
 
 // static
 DevToolsWindowTesting* DevToolsWindowTesting::Find(DevToolsWindow* window) {
-  if (!g_devtools_window_testing_instances.IsCreated())
-    return nullptr;
-  DevToolsWindowTestings* instances =
-      g_devtools_window_testing_instances.Pointer();
-  for (auto it(instances->begin()); it != instances->end(); ++it) {
-    if ((*it)->devtools_window_ == window)
-      return *it;
+  for (auto& instance : GetDevToolsWindowTestingInstances()) {
+    if (instance->devtools_window_ == window) {
+      return instance;
+    }
   }
   return nullptr;
 }
@@ -157,6 +160,7 @@ DevToolsWindow* DevToolsWindowTesting::OpenDevToolsWindowSync(
       is_docked);
 }
 
+#if !BUILDFLAG(IS_ANDROID)
 // static
 DevToolsWindow* DevToolsWindowTesting::OpenDevToolsWindowSync(
     Browser* browser,
@@ -164,6 +168,7 @@ DevToolsWindow* DevToolsWindowTesting::OpenDevToolsWindowSync(
   return OpenDevToolsWindowSync(
       browser->tab_strip_model()->GetActiveWebContents(), is_docked);
 }
+#endif  // !BUILDFLAG(IS_ANDROID)
 
 // static
 DevToolsWindow* DevToolsWindowTesting::OpenDevToolsWindowSync(
@@ -191,7 +196,11 @@ void DevToolsWindowTesting::CloseDevToolsWindow(
   if (window->is_docked_) {
     window->CloseWindow();
   } else {
+#if BUILDFLAG(IS_ANDROID)
+    window->main_web_contents_->Close();
+#else
     window->browser_->window()->Close();
+#endif  // BUILDFLAG(IS_ANDROID)
   }
 }
 
