@@ -93,6 +93,7 @@ std::vector<std::string> GetTargetUrlsWithoutPorts(
 }
 }  // namespace
 
+using testing::ElementsAre;
 using testing::Eq;
 
 class DebuggerApiTest : public ExtensionApiTest {
@@ -364,7 +365,7 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest,
 }
 
 IN_PROC_BROWSER_TEST_F(DebuggerApiTest,
-                       DebuggerNotAllowedOnSecirutyInterstitials) {
+                       DebuggerNotAllowedOnSecurityInterstitials) {
   content::WebContents* web_contents =
       browser()->tab_strip_model()->GetActiveWebContents();
   std::unique_ptr<content::MockNavigationHandle> navigation_handle =
@@ -687,10 +688,9 @@ IN_PROC_BROWSER_TEST_F(CrossProfileDebuggerApiTest, GetTargets) {
             get_targets_function.get(), "[]", profile()));
 
     ASSERT_TRUE(value.is_list());
-    const base::Value::List targets = std::move(value).TakeList();
-    ASSERT_THAT(targets, testing::SizeIs(1));
-    EXPECT_THAT(targets[0].GetDict(), base::test::DictionaryHasValue(
-                                          "url", base::Value("about:blank")));
+    EXPECT_THAT(std::move(value).TakeList(),
+                ElementsAre(base::test::DictionaryHasValue(
+                    "url", base::Value("about:blank"))));
   }
 
   {
@@ -834,6 +834,12 @@ IN_PROC_BROWSER_TEST_F(DebuggerExtensionApiTest, Debugger) {
   ASSERT_TRUE(RunExtensionTest("debugger")) << message_;
 }
 
+// TODO(crbug.com/40276609): Reenable this test once the
+// OptimizeServiceWorkerStartRequests feature is re-enabled.
+IN_PROC_BROWSER_TEST_F(DebuggerExtensionApiTest, DISABLED_DebuggerMv3) {
+  ASSERT_TRUE(RunExtensionTest("debugger_mv3")) << message_;
+}
+
 IN_PROC_BROWSER_TEST_F(DebuggerExtensionApiTest, ParentTargetPermissions) {
   // Run test with file access disabled.
   ASSERT_TRUE(RunExtensionTest("parent_target_permissions")) << message_;
@@ -1016,6 +1022,24 @@ IN_PROC_BROWSER_TEST_F(SitePerProcessDebuggerExtensionApiTest,
       << message_;
 }
 
+IN_PROC_BROWSER_TEST_F(SitePerProcessDebuggerExtensionApiTest,
+                       NavigateSubframePolicyRestriction) {
+  URLPatternSet default_blocked_hosts;
+  default_blocked_hosts.AddPattern(
+      URLPattern(URLPattern::SCHEME_HTTP, "http://c.com/*"));
+  PermissionsData::SetDefaultPolicyHostRestrictions(
+      util::GetBrowserContextId(profile()), default_blocked_hosts,
+      URLPatternSet());
+
+  GURL url(embedded_test_server()->GetURL(
+      "a.com",
+      "/extensions/api_test/debugger_navigate_subframe_policy_restriction/"
+      "inspected_page.html"));
+  ASSERT_TRUE(RunExtensionTest("debugger_navigate_subframe",
+                               {.custom_arg = url.spec().c_str()}))
+      << message_;
+}
+
 IN_PROC_BROWSER_TEST_F(SitePerProcessDebuggerExtensionApiTest,
                        AutoAttachPermissions) {
   GURL url(embedded_test_server()->GetURL(
