@@ -1,33 +1,38 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2012 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 #include "extensions/browser/api/declarative/rules_registry_service.h"
 
 #include <stddef.h>
+
+#include <memory>
 #include <utility>
 
-#include "base/bind.h"
+#include "base/functional/bind.h"
 #include "base/run_loop.h"
-#include "base/strings/stringprintf.h"
-#include "base/task/post_task.h"
+#include "base/strings/strcat.h"
+#include "base/values.h"
 #include "chrome/test/base/testing_profile.h"
 #include "components/version_info/channel.h"
 #include "components/version_info/version_info.h"
 #include "content/public/browser/browser_task_traits.h"
-#include "content/public/test/test_browser_thread.h"
-#include "content/public/test/test_browser_thread_bundle.h"
+#include "content/public/browser/browser_thread.h"
+#include "content/public/test/browser_task_environment.h"
 #include "extensions/browser/api/declarative/test_rules_registry.h"
 #include "extensions/browser/api/declarative_webrequest/webrequest_constants.h"
+#include "extensions/browser/rules_registry_ids.h"
+#include "extensions/buildflags/buildflags.h"
 #include "extensions/common/api/declarative/declarative_constants.h"
 #include "extensions/common/extension.h"
 #include "extensions/common/extension_builder.h"
 #include "extensions/common/features/feature.h"
 #include "extensions/common/features/feature_channel.h"
 #include "extensions/common/features/feature_provider.h"
-#include "extensions/common/value_builder.h"
 #include "testing/gtest/include/gtest/gtest.h"
 
+static_assert(BUILDFLAG(ENABLE_EXTENSIONS_CORE));
+
 namespace {
 const char kExtensionId[] = "foo";
 
@@ -35,7 +40,7 @@ void InsertRule(scoped_refptr<extensions::RulesRegistry> registry,
                 const std::string& id) {
   std::vector<extensions::api::events::Rule> add_rules;
   add_rules.emplace_back();
-  add_rules[0].id.reset(new std::string(id));
+  add_rules[0].id = id;
   std::string error = registry->AddRules(kExtensionId, std::move(add_rules));
   EXPECT_TRUE(error.empty());
 }
@@ -55,7 +60,7 @@ class RulesRegistryServiceTest : public testing::Test {
  public:
   RulesRegistryServiceTest() = default;
 
-  ~RulesRegistryServiceTest() override {}
+  ~RulesRegistryServiceTest() override = default;
 
   void TearDown() override {
     // Make sure that deletion traits of all registries are executed.
@@ -63,57 +68,39 @@ class RulesRegistryServiceTest : public testing::Test {
   }
 
  protected:
-  content::TestBrowserThreadBundle test_browser_thread_bundle_;
+  content::BrowserTaskEnvironment task_environment_;
 };
 
 TEST_F(RulesRegistryServiceTest, TestConstructionAndMultiThreading) {
-  RulesRegistryService registry_service(NULL);
+  RulesRegistryService registry_service(nullptr);
 
-  int key = RulesRegistryService::kDefaultRulesRegistryID;
-  TestRulesRegistry* ui_registry =
-      new TestRulesRegistry(content::BrowserThread::UI, "ui", key);
-
-  TestRulesRegistry* io_registry =
-      new TestRulesRegistry(content::BrowserThread::IO, "io", key);
+  int key = rules_registry_ids::kDefaultRulesRegistryID;
+  TestRulesRegistry* ui_registry = new TestRulesRegistry("ui", key);
 
   // Test registration.
 
   registry_service.RegisterRulesRegistry(base::WrapRefCounted(ui_registry));
-  registry_service.RegisterRulesRegistry(base::WrapRefCounted(io_registry));
 
   EXPECT_TRUE(registry_service.GetRulesRegistry(key, "ui").get());
-  EXPECT_TRUE(registry_service.GetRulesRegistry(key, "io").get());
   EXPECT_FALSE(registry_service.GetRulesRegistry(key, "foo").get());
 
-  base::PostTaskWithTraits(
-      FROM_HERE, {content::BrowserThread::UI},
+  content::GetUIThreadTaskRunner({})->PostTask(
+      FROM_HERE,
       base::BindOnce(&InsertRule, registry_service.GetRulesRegistry(key, "ui"),
                      "ui_task"));
 
-  base::PostTaskWithTraits(
-      FROM_HERE, {content::BrowserThread::IO},
-      base::BindOnce(&InsertRule, registry_service.GetRulesRegistry(key, "io"),
-                     "io_task"));
-
-  base::PostTaskWithTraits(
-      FROM_HERE, {content::BrowserThread::UI},
+  content::GetUIThreadTaskRunner({})->PostTask(
+      FROM_HERE,
       base::BindOnce(&VerifyNumberOfRules,
                      registry_service.GetRulesRegistry(key, "ui"), 1));
 
-  base::PostTaskWithTraits(
-      FROM_HERE, {content::BrowserThread::IO},
-      base::BindOnce(&VerifyNumberOfRules,
-                     registry_service.GetRulesRegistry(key, "io"), 1));
-
   base::RunLoop().RunUntilIdle();
 
   // Test extension uninstalling.
-  std::unique_ptr<base::DictionaryValue> manifest =
-      DictionaryBuilder()
-          .Set("name", "Extension")
-          .Set("version", "1.0")
-          .Set("manifest_version", 2)
-          .Build();
+  base::Value::Dict manifest = base::Value::Dict()
+                                   .Set("name", "Extension")
+                                   .Set("version", "1.0")
+                                   .Set("manifest_version", 2);
   scoped_refptr<const Extension> extension =
       ExtensionBuilder()
           .SetManifest(std::move(manifest))
@@ -121,19 +108,19 @@ TEST_F(RulesRegistryServiceTest, TestConstructionAndMultiThreading) {
           .Build();
   registry_service.SimulateExtensionUninstalled(extension.get());
 
-  base::PostTaskWithTraits(
-      FROM_HERE, {content::BrowserThread::UI},
+  content::GetUIThreadTaskRunner({})->PostTask(
+      FROM_HERE,
       base::BindOnce(&VerifyNumberOfRules,
                      registry_service.GetRulesRegistry(key, "ui"), 0));
 
-  base::PostTaskWithTraits(
-      FROM_HERE, {content::BrowserThread::IO},
-      base::BindOnce(&VerifyNumberOfRules,
-                     registry_service.GetRulesRegistry(key, "io"), 0));
-
   base::RunLoop().RunUntilIdle();
 }
 
+#if !BUILDFLAG(IS_ANDROID)
+// This test relies on declarativeWebRequest, which is deprecated and will not
+// be supported on desktop Android. We can't just replace it with
+// declarativeNetRequest because the test relies on the API being unavailable
+// on stable channel.
 TEST_F(RulesRegistryServiceTest, DefaultRulesRegistryRegistered) {
   struct {
     version_info::Channel channel;
@@ -144,14 +131,14 @@ TEST_F(RulesRegistryServiceTest, DefaultRulesRegistryRegistered) {
   };
 
   for (const auto& test_case : test_cases) {
-    SCOPED_TRACE(base::StringPrintf(
-        "Testing Channel %s",
-        version_info::GetChannelString(test_case.channel).c_str()));
+    SCOPED_TRACE(
+        base::StrCat({"Testing Channel ",
+                      version_info::GetChannelString(test_case.channel)}));
     ScopedCurrentChannel scoped_channel(test_case.channel);
 
     ASSERT_EQ(test_case.expect_api_enabled,
               FeatureProvider::GetAPIFeature("declarativeWebRequest")
-                  ->IsAvailableToEnvironment()
+                  ->IsAvailableToEnvironment(kUnspecifiedContextId)
                   .is_available());
 
     TestingProfile profile;
@@ -162,13 +149,13 @@ TEST_F(RulesRegistryServiceTest, DefaultRulesRegistryRegistered) {
     EXPECT_EQ(
         test_case.expect_api_enabled,
         registry_service
-                .GetRulesRegistry(RulesRegistryService::kDefaultRulesRegistryID,
+                .GetRulesRegistry(rules_registry_ids::kDefaultRulesRegistryID,
                                   declarative_webrequest_constants::kOnRequest)
                 .get() != nullptr);
 
     // Content rules registry should always be created.
     EXPECT_TRUE(registry_service.GetRulesRegistry(
-        RulesRegistryService::kDefaultRulesRegistryID,
+        rules_registry_ids::kDefaultRulesRegistryID,
         declarative_content_constants::kOnPageChanged));
     EXPECT_TRUE(registry_service.content_rules_registry());
 
@@ -178,5 +165,6 @@ TEST_F(RulesRegistryServiceTest, DefaultRulesRegistryRegistered) {
         kWebViewRulesRegistryID, declarative_webrequest_constants::kOnRequest));
   }
 }
+#endif  // !BUILDFLAG(IS_ANDROID)
 
 }  // namespace extensions
