@@ -6,12 +6,15 @@
 #include <string>
 #include <utility>
 
+#include "base/strings/string_number_conversions.h"
+#include "base/strings/stringprintf.h"
 #include "base/test/scoped_feature_list.h"
 #include "build/branding_buildflags.h"
 #include "build/build_config.h"
 #include "build/chromeos_buildflags.h"
 #include "chrome/browser/enterprise/browser_management/management_service_factory.h"
 #include "chrome/browser/enterprise/connectors/test/deep_scanning_test_utils.h"
+#include "chrome/browser/extensions/api/enterprise_reporting_private/enterprise_reporting_private_event_router.h"
 #include "chrome/browser/extensions/chrome_test_extension_loader.h"
 #include "chrome/browser/extensions/extension_apitest.h"
 #include "chrome/browser/policy/profile_policy_connector.h"
@@ -21,12 +24,15 @@
 #include "chrome/common/extensions/api/enterprise_reporting_private.h"
 #include "chrome/test/base/in_process_browser_test.h"
 #include "components/policy/core/common/management/management_service.h"
+#include "components/safe_browsing/core/common/proto/realtimeapi.pb.h"
+#include "components/signin/public/identity_manager/account_capabilities_test_mutator.h"
 #include "components/signin/public/identity_manager/account_info.h"
 #include "components/signin/public/identity_manager/identity_test_environment.h"
 #include "components/version_info/version_info.h"
 #include "content/public/test/browser_test.h"
 #include "extensions/common/extension.h"
 #include "extensions/common/extension_features.h"
+#include "extensions/test/extension_test_message_listener.h"
 #include "extensions/test/result_catcher.h"
 #include "extensions/test/test_extension_dir.h"
 #include "google_apis/gaia/gaia_id.h"
@@ -110,6 +116,8 @@ constexpr char kManifestTemplate[] = R"(
       "background": { "service_worker": "background.js" }
     })";
 
+constexpr char kTestUrl[] = "https://foo.bar";
+
 }  // namespace
 
 // This test class is to validate that the API is correctly unavailable on
@@ -120,20 +128,6 @@ constexpr char kManifestTemplate[] = R"(
 class EnterpriseReportingPrivateApiTest : public extensions::ExtensionApiTest {
  public:
   EnterpriseReportingPrivateApiTest() {
-#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
-    scoped_features_.InitWithFeatures(
-        /*enabled_features=*/
-        {
-            extensions_features::
-                kApiEnterpriseReportingPrivateReportDataMaskingEvent,
-        },
-        /*disabled_features=*/{});
-#else
-    scoped_features_.InitAndEnableFeature(
-        extensions_features::
-            kApiEnterpriseReportingPrivateReportDataMaskingEvent);
-#endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
-
 #if !BUILDFLAG(IS_CHROMEOS)
     browser_dm_token_storage_.SetClientId("client_id");
     browser_dm_token_storage_.SetEnrollmentToken("enrollment_token");
@@ -167,6 +161,8 @@ class EnterpriseReportingPrivateApiTest : public extensions::ExtensionApiTest {
           ->store()
           ->set_policy_data_for_testing(std::move(profile_policy_data));
     }
+    AccountCapabilitiesTestMutator(&account_info.capabilities)
+        .set_is_subject_to_enterprise_features(as_managed);
 
     return account_info;
   }
@@ -198,21 +194,11 @@ class EnterpriseReportingPrivateApiTest : public extensions::ExtensionApiTest {
   }
 
  protected:
-  void SetUpInProcessBrowserTestFixture() override {
-    extensions::ExtensionApiTest::SetUpInProcessBrowserTestFixture();
-
-    create_services_subscription_ =
-        BrowserContextDependencyManager::GetInstance()
-            ->RegisterCreateServicesCallbackForTesting(
-                base::BindRepeating(&EnterpriseReportingPrivateApiTest::
-                                        OnWillCreateBrowserContextServices,
-                                    base::Unretained(this)));
-  }
-
-  void OnWillCreateBrowserContextServices(content::BrowserContext* context) {
+  void SetUpBrowserContextKeyedServices(
+      content::BrowserContext* context) override {
+    extensions::ExtensionApiTest::SetUpBrowserContextKeyedServices(context);
     IdentityTestEnvironmentProfileAdaptor::
         SetIdentityTestEnvironmentFactoriesOnBrowserContext(context);
-
     ChromeSigninClientFactory::GetInstance()->SetTestingFactory(
         context, base::BindRepeating(&BuildChromeSigninClientWithURLLoader,
                                      &test_url_loader_factory_));
@@ -257,10 +243,6 @@ class EnterpriseReportingPrivateApiTest : public extensions::ExtensionApiTest {
 
   network::TestURLLoaderFactory test_url_loader_factory_;
 
-  base::CallbackListSubscription create_services_subscription_;
-
-  base::test::ScopedFeatureList scoped_features_;
-
 #if !BUILDFLAG(IS_CHROMEOS)
   policy::FakeBrowserDMTokenStorage browser_dm_token_storage_;
 #endif
@@ -459,14 +441,6 @@ IN_PROC_BROWSER_TEST_F(EnterpriseReportingPrivateApiTest, GetDeviceInfo) {
 }
 
 IN_PROC_BROWSER_TEST_F(EnterpriseReportingPrivateApiTest, GetContextInfo) {
-#if BUILDFLAG(IS_WIN) && BUILDFLAG(GOOGLE_CHROME_BRANDING)
-  constexpr char kThirdPartyBlockingEnabledType[] = "boolean";
-  constexpr char kCount[] = "18";
-#else
-  constexpr char kThirdPartyBlockingEnabledType[] = "undefined";
-  constexpr char kCount[] = "17";
-#endif  // BUILDFLAG(IS_WIN) && BUILDFLAG(GOOGLE_CHROME_BRANDING)
-
   constexpr char kTest[] = R"(
     chrome.test.assertEq(
       'function',
@@ -474,7 +448,7 @@ IN_PROC_BROWSER_TEST_F(EnterpriseReportingPrivateApiTest, GetContextInfo) {
     chrome.enterprise.reportingPrivate.getContextInfo((info) => {
       chrome.test.assertNoLastError();
 
-      chrome.test.assertEq(%s, Object.keys(info).length);
+      chrome.test.assertEq(17, Object.keys(info).length);
       chrome.test.assertTrue(info.browserAffiliationIds instanceof Array);
       chrome.test.assertTrue(info.profileAffiliationIds instanceof Array);
       chrome.test.assertTrue(info.onFileAttachedProviders instanceof Array);
@@ -491,14 +465,13 @@ IN_PROC_BROWSER_TEST_F(EnterpriseReportingPrivateApiTest, GetContextInfo) {
         (typeof info.passwordProtectionWarningTrigger, 'string');
       chrome.test.assertEq
         (typeof info.chromeRemoteDesktopAppBlocked, 'boolean');
-      chrome.test.assertEq(typeof info.thirdPartyBlockingEnabled,'%s');
       chrome.test.assertEq(typeof info.osFirewall, 'string');
       chrome.test.assertTrue(info.systemDnsServers instanceof Array);
       chrome.test.assertEq(typeof info.enterpriseProfileId, 'string');
 
       chrome.test.notifyPass();
     });)";
-  RunTest(base::StringPrintf(kTest, kCount, kThirdPartyBlockingEnabledType));
+  RunTest(kTest);
 }
 
 IN_PROC_BROWSER_TEST_F(EnterpriseReportingPrivateApiTest, GetCertificate) {
@@ -698,8 +671,8 @@ IN_PROC_BROWSER_TEST_F(EnterpriseReportingPrivateApiTest,
 #endif
 IN_PROC_BROWSER_TEST_F(EnterpriseReportingPrivateApiTest,
                        MAYBE_GetFileSystemInfo_Success) {
-  // Use the test runner process and binary as test parameters, as it will always
-  // be running.
+  // Use the test runner process and binary as test parameters, as it will
+  // always be running.
   auto test_runner_file_path =
       device_signals::GetProcessExePath(base::Process::Current().Pid());
 
@@ -1163,6 +1136,8 @@ IN_PROC_BROWSER_TEST_F(EnterpriseReportDataMaskingEventTest,
       api::enterprise_reporting_private::EventResult::kEventResultDataMasked;
   event.url = "https://foo.com";
   event.triggered_rule_info.push_back(std::move(rule_info));
+  base::RunLoop run_loop;
+  event_validator.SetDoneClosure(run_loop.QuitClosure());
   event_validator.ExpectDataMaskingEvent("test-user@chromium.org",
                                          profile()->GetPath().AsUTF8Unsafe(),
                                          std::move(event));
@@ -1173,6 +1148,182 @@ IN_PROC_BROWSER_TEST_F(EnterpriseReportDataMaskingEventTest,
       profile()->GetPrefs(), true, {"sensitiveDataEvent"}, {});
 
   RunTest(kTestJS);
+  run_loop.Run();
+}
+
+class EnterpriseOnDataMaskingRulesTriggeredTest
+    : public EnterpriseReportingPrivateApiTest {
+ public:
+  EnterpriseOnDataMaskingRulesTriggeredTest() = default;
+
+ private:
+  base::test::ScopedFeatureList scoped_features_{
+      extensions_features::
+          kApiEnterpriseReportingPrivateOnDataMaskingRulesTriggered};
+};
+
+IN_PROC_BROWSER_TEST_F(EnterpriseOnDataMaskingRulesTriggeredTest,
+                       WithoutRules) {
+  static constexpr char kTestJS[] = R"(
+    chrome.test.runTests([
+      async function asyncAssertions() {
+        chrome.enterprise.reportingPrivate.onDataMaskingRulesTriggered.addListener(
+          rules => {
+            if (rules.triggeredRuleInfo.length === 0) {
+              chrome.test.fail(
+                  'There should not be an event when no rules are triggered');
+            } else {
+              chrome.test.assertEq(rules, {
+                  triggeredRuleInfo: [
+                    {
+                      matchedDetectors:[
+                        {
+                          detectorId: "12345",
+                          displayName: "display_name",
+                          maskType:'mask_type',
+                          pattern:'pattern'
+                        }
+                      ],
+                      ruleId:'rule_id',
+                      ruleName:'rule_name'
+                    }
+                  ],
+                  url:'https://foo.bar/'
+                });
+              chrome.test.succeed();
+            }
+          }
+        );
+      }
+    ]);)";
+
+  TestExtensionDir test_dir;
+  test_dir.WriteManifest(
+      base::StringPrintf(kManifestTemplate, kAuthorizedManifestKey));
+  test_dir.WriteFile(FILE_PATH_LITERAL("background.js"), kTestJS);
+
+  const Extension* extension = LoadExtension(test_dir.UnpackedPath());
+  EXPECT_TRUE(extension);
+
+  ResultCatcher result_catcher;
+
+  auto* router = EnterpriseReportingPrivateEventRouterFactory::GetInstance()
+                     ->GetForProfile(profile());
+
+  // This first call should not produce any result as there are no triggered
+  // rules in the response.
+  router->OnUrlFilteringVerdict(GURL(kTestUrl),
+                                safe_browsing::RTLookupResponse());
+
+  safe_browsing::RTLookupResponse response;
+
+  auto* rule =
+      response.add_threat_info()->mutable_matched_url_navigation_rule();
+  rule->set_rule_id("rule_id");
+  rule->set_rule_name("rule_name");
+
+  auto* data_masking = rule->add_data_masking_actions();
+  data_masking->set_display_name("display_name");
+  data_masking->set_mask_type("mask_type");
+  data_masking->set_pattern("pattern");
+  data_masking->set_detector_id("12345");
+
+  router->OnUrlFilteringVerdict(GURL(kTestUrl), response);
+
+  ASSERT_TRUE(result_catcher.GetNextResult()) << result_catcher.message();
+}
+
+IN_PROC_BROWSER_TEST_F(EnterpriseOnDataMaskingRulesTriggeredTest, WithRules) {
+  static constexpr char kTestJS[] = R"(
+    chrome.test.runTests([
+      async function asyncAssertions() {
+        chrome.enterprise.reportingPrivate.onDataMaskingRulesTriggered.addListener(
+          rules => {
+            chrome.test.assertEq(rules, {
+              triggeredRuleInfo: [
+                {
+                  ruleId:'rule_id_1',
+                  ruleName:'rule_name_1',
+                  matchedDetectors:[
+                    {
+                      displayName: "display_name_1",
+                      detectorId: "id_1",
+                      maskType:'mask_type_1',
+                      pattern:'pattern_1'
+                    },
+                    {
+                      displayName: "display_name_2",
+                      detectorId: "id_2",
+                      maskType:'mask_type_2',
+                      pattern:'pattern_2'
+                    }
+                  ],
+                },
+                {
+                  ruleId:'rule_id_2',
+                  ruleName:'rule_name_2',
+                  matchedDetectors:[
+                    {
+                      displayName: "display_name_3",
+                      detectorId: "id_3",
+                      maskType:'mask_type_3',
+                      pattern:'pattern_3'
+                    }
+                  ]
+                }
+              ],
+              url:'https://foo.bar/'
+            });
+            chrome.test.succeed();
+          }
+        );
+      }]);)";
+
+  TestExtensionDir test_dir;
+  test_dir.WriteManifest(
+      base::StringPrintf(kManifestTemplate, kAuthorizedManifestKey));
+  test_dir.WriteFile(FILE_PATH_LITERAL("background.js"), kTestJS);
+
+  const Extension* extension = LoadExtension(test_dir.UnpackedPath());
+  EXPECT_TRUE(extension);
+
+  ResultCatcher result_catcher;
+
+  safe_browsing::RTLookupResponse response;
+
+  auto* rule_1 =
+      response.add_threat_info()->mutable_matched_url_navigation_rule();
+  rule_1->set_rule_id("rule_id_1");
+  rule_1->set_rule_name("rule_name_1");
+
+  auto* data_masking_1 = rule_1->add_data_masking_actions();
+  data_masking_1->set_display_name("display_name_1");
+  data_masking_1->set_mask_type("mask_type_1");
+  data_masking_1->set_pattern("pattern_1");
+  data_masking_1->set_detector_id("id_1");
+
+  auto* data_masking_2 = rule_1->add_data_masking_actions();
+  data_masking_2->set_display_name("display_name_2");
+  data_masking_2->set_mask_type("mask_type_2");
+  data_masking_2->set_pattern("pattern_2");
+  data_masking_2->set_detector_id("id_2");
+
+  auto* rule_2 =
+      response.add_threat_info()->mutable_matched_url_navigation_rule();
+  rule_2->set_rule_id("rule_id_2");
+  rule_2->set_rule_name("rule_name_2");
+
+  auto* data_masking_3 = rule_2->add_data_masking_actions();
+  data_masking_3->set_display_name("display_name_3");
+  data_masking_3->set_mask_type("mask_type_3");
+  data_masking_3->set_pattern("pattern_3");
+  data_masking_3->set_detector_id("id_3");
+
+  EnterpriseReportingPrivateEventRouterFactory::GetInstance()
+      ->GetForProfile(profile())
+      ->OnUrlFilteringVerdict(GURL(kTestUrl), response);
+
+  ASSERT_TRUE(result_catcher.GetNextResult()) << result_catcher.message();
 }
 
 }  // namespace extensions
