@@ -23,6 +23,7 @@
 #include "chrome/browser/ui/browser_window.h"
 #include "chrome/browser/ui/extensions/extension_action_test_helper.h"
 #include "chrome/browser/ui/tabs/tab_strip_model.h"
+#include "chrome/browser/ui/toolbar/toolbar_action_view_controller.h"
 #include "chrome/browser/ui/toolbar/toolbar_actions_model.h"
 #include "chrome/browser/ui/views/extensions/extensions_toolbar_container.h"
 #include "chrome/browser/ui/views/frame/browser_view.h"
@@ -226,7 +227,7 @@ class BrowserActionInteractiveTest : public ExtensionApiTest {
   bool HasPopupNativeView() {
     ToolbarActionViewController* popup_owner =
         extensions_container()->popup_owner_for_testing();
-    return popup_owner ? popup_owner->GetPopupNativeView() != nullptr : false;
+    return popup_owner ? !!popup_owner->GetPopupNativeView() : false;
   }
 
   // Trigger a focus loss to close the popup.
@@ -957,9 +958,9 @@ class NavigatingExtensionPopupInteractiveTest
                     "browser_action/popup_with_iframe")));
   }
 
-  enum ExpectedNavigationStatus {
-    EXPECTING_NAVIGATION_SUCCESS,
-    EXPECTING_NAVIGATION_FAILURE,
+  enum class ExpectedNavigationStatus {
+    kSuccess,
+    kFailure,
   };
 
   void TestPopupNavigationViaGet(
@@ -1009,18 +1010,11 @@ class NavigatingExtensionPopupInteractiveTest
     GURL popup_url = popup_extension().GetResourceURL("popup.html");
     EXPECT_EQ(popup_url, popup->GetLastCommittedURL());
 
-    // Note that the |setTimeout| call below is needed to make sure EvalJs
-    // returns *after* a scheduled navigation has already started.
-    std::string script_to_execute = navigation_starting_script +
-                                    "new Promise(resolve => {\n"
-                                    "  setTimeout(\n"
-                                    "    function() { resolve(true); },\n"
-                                    "    0);\n"
-                                    "});\n";
-
     // Try to navigate the pop-up.
+    content::TestNavigationObserver navigation_observer(popup);
     content::WebContentsDestroyedWatcher popup_destruction_watcher(popup);
-    EXPECT_TRUE(ExecJs(popup, script_to_execute));
+    EXPECT_TRUE(ExecJs(popup, navigation_starting_script));
+    navigation_observer.Wait();
     popup = popup_destruction_watcher.web_contents();
 
     // Verify if the popup navigation succeeded or failed as expected.
@@ -1037,7 +1031,7 @@ class NavigatingExtensionPopupInteractiveTest
       // The popup should still be alive.
       ASSERT_TRUE(popup_destruction_watcher.web_contents());
 
-      if (expected_navigation_status == EXPECTING_NAVIGATION_SUCCESS) {
+      if (expected_navigation_status == ExpectedNavigationStatus::kSuccess) {
         EXPECT_EQ(target_url, popup->GetLastCommittedURL())
             << "Navigation to " << target_url
             << " should succeed in an extension pop-up";
@@ -1077,11 +1071,11 @@ class NavigatingExtensionPopupInteractiveTest
 // Tests that an extension pop-up cannot be navigated to a web page.
 IN_PROC_BROWSER_TEST_F(NavigatingExtensionPopupInteractiveTest, Webpage_Get) {
   GURL web_url(embedded_test_server()->GetURL("foo.com", "/title1.html"));
-  TestPopupNavigationViaGet(web_url, EXPECTING_NAVIGATION_FAILURE);
+  TestPopupNavigationViaGet(web_url, ExpectedNavigationStatus::kFailure);
 }
 IN_PROC_BROWSER_TEST_F(NavigatingExtensionPopupInteractiveTest, Webpage_Post) {
   GURL web_url(embedded_test_server()->GetURL("foo.com", "/title1.html"));
-  TestPopupNavigationViaPost(web_url, EXPECTING_NAVIGATION_FAILURE);
+  TestPopupNavigationViaPost(web_url, ExpectedNavigationStatus::kFailure);
 }
 
 // Tests that an extension pop-up can be navigated to another page
@@ -1091,14 +1085,14 @@ IN_PROC_BROWSER_TEST_F(NavigatingExtensionPopupInteractiveTest,
   GURL other_page_in_same_extension =
       popup_extension().GetResourceURL("other_page.html");
   TestPopupNavigationViaGet(other_page_in_same_extension,
-                            EXPECTING_NAVIGATION_SUCCESS);
+                            ExpectedNavigationStatus::kSuccess);
 }
 IN_PROC_BROWSER_TEST_F(NavigatingExtensionPopupInteractiveTest,
                        PageInSameExtension_Post) {
   GURL other_page_in_same_extension =
       popup_extension().GetResourceURL("other_page.html");
   TestPopupNavigationViaPost(other_page_in_same_extension,
-                             EXPECTING_NAVIGATION_SUCCESS);
+                             ExpectedNavigationStatus::kSuccess);
 }
 
 // Tests that an extension pop-up cannot be navigated to a page
@@ -1106,13 +1100,15 @@ IN_PROC_BROWSER_TEST_F(NavigatingExtensionPopupInteractiveTest,
 IN_PROC_BROWSER_TEST_F(NavigatingExtensionPopupInteractiveTest,
                        PageInOtherExtension_Get) {
   GURL other_extension_url = other_extension().GetResourceURL("other.html");
-  TestPopupNavigationViaGet(other_extension_url, EXPECTING_NAVIGATION_FAILURE);
+  TestPopupNavigationViaGet(other_extension_url,
+                            ExpectedNavigationStatus::kFailure);
 }
 
 IN_PROC_BROWSER_TEST_F(NavigatingExtensionPopupInteractiveTest,
                        PageInOtherExtension_Post) {
   GURL other_extension_url = other_extension().GetResourceURL("other.html");
-  TestPopupNavigationViaPost(other_extension_url, EXPECTING_NAVIGATION_FAILURE);
+  TestPopupNavigationViaPost(other_extension_url,
+                             ExpectedNavigationStatus::kFailure);
 }
 
 // Tests that navigating an extension pop-up to a http URI that returns
@@ -1131,7 +1127,7 @@ IN_PROC_BROWSER_TEST_F(NavigatingExtensionPopupInteractiveTest,
   // header.
   GURL download_url(
       embedded_test_server()->GetURL("foo.com", "/download-test3.gif"));
-  TestPopupNavigationViaPost(download_url, EXPECTING_NAVIGATION_FAILURE);
+  TestPopupNavigationViaPost(download_url, ExpectedNavigationStatus::kFailure);
 
   // Verify that "download-test3.gif got downloaded.
   downloads_observer.WaitForFinished();
@@ -1167,7 +1163,7 @@ IN_PROC_BROWSER_TEST_F(NavigatingExtensionPopupInteractiveTest,
   // header.
   GURL download_url(
       embedded_test_server()->GetURL("foo.com", "/download-test3.gif"));
-  TestPopupNavigationViaGet(download_url, EXPECTING_NAVIGATION_FAILURE);
+  TestPopupNavigationViaGet(download_url, ExpectedNavigationStatus::kFailure);
 
   // Verify that "download-test3.gif got downloaded.
   downloads_observer.WaitForFinished();
