@@ -14,6 +14,7 @@ class IdentityGetAuthTokenError {
  public:
   // These values are persisted to logs. Entries should not be renumbered and
   // numeric values should never be reused.
+  // LINT.IfChange(GetAuthTokenResult)
   enum class State {
     kNone = 0,
     kInvalidClientId = 1,
@@ -46,23 +47,25 @@ class IdentityGetAuthTokenError {
     kInteractivityDenied = 28,
     kCannotCreateWindow = 29,
     kBrowserContextShutDown = 30,
-    kMaxValue = kBrowserContextShutDown,
+    kSetRemoteConsentResolutionCookiesFailed = 31,
+    kMaxValue = kSetRemoteConsentResolutionCookiesFailed,
   };
+  // LINT.ThenChange(//tools/metrics/histograms/metadata/signin/enums.xml:GetAuthTokenResult)
 
   // Constructs a |State::kMintTokenAuthFailure| error with an
-  // |error_message|.
+  // `error_message`.
   static IdentityGetAuthTokenError FromMintTokenAuthError(
       std::string_view error_message);
 
   // Constructs a |State::kGetAccessTokenAuthFailure| error with an
-  // |error_message|.
+  // `error_message`.
   static IdentityGetAuthTokenError FromGetAccessTokenAuthError(
       std::string_view error_message);
 
   // Constructs a |State::kNone| error.
   IdentityGetAuthTokenError();
 
-  // Constructs an IdentityGetAuthTokenError from |state| with no additional
+  // Constructs an IdentityGetAuthTokenError from `state` with no additional
   // data.
   explicit IdentityGetAuthTokenError(State state);
 
