@@ -35,6 +35,7 @@
 #include "components/signin/public/identity_manager/access_token_info.h"
 #include "components/signin/public/identity_manager/account_info.h"
 #include "components/signin/public/identity_manager/accounts_in_cookie_jar_info.h"
+#include "components/signin/public/identity_manager/identity_manager.h"
 #include "components/signin/public/identity_manager/scope_set.h"
 #include "components/version_info/version_info.h"
 #include "content/public/browser/browser_task_traits.h"
@@ -52,10 +53,16 @@
 
 #if BUILDFLAG(IS_CHROMEOS)
 #include "chrome/browser/browser_process.h"
+#include "chrome/browser/device_identity/device_oauth2_token_service.h"
+#include "chrome/browser/device_identity/device_oauth2_token_service_factory.h"
 #include "chrome/browser/policy/chrome_browser_policy_connector.h"
 #include "chromeos/components/kiosk/kiosk_utils.h"
 #include "chromeos/components/mgs/managed_guest_session_utils.h"
 #include "components/account_manager_core/account_manager_util.h"
+#include "components/signin/public/identity_manager/scope_set.h"
+#include "google_apis/gaia/google_service_auth_error.h"
+#include "google_apis/gaia/oauth2_access_token_consumer.h"
+#include "google_apis/gaia/oauth2_access_token_manager.h"
 #endif
 
 namespace extensions {
@@ -190,16 +197,36 @@ ExtensionFunction::ResponseAction IdentityGetAuthTokenFunction::Run() {
   StartAsyncRun();
 
   // TODO(crbug.com/40614113): collapse the asynchronicity
-  content::GetUIThreadTaskRunner({})->PostTask(
-      FROM_HERE,
+  base::OnceCallback next_step =
       base::BindOnce(&IdentityGetAuthTokenFunction::GetAuthTokenForAccount,
-                     weak_ptr_factory_.GetWeakPtr(), gaia_id));
+                     weak_ptr_factory_.GetWeakPtr(), gaia_id);
+
+#if BUILDFLAG(IS_CHROMEOS)
+  const bool needs_identity_manager_tokens =
+      !(g_browser_process->browser_policy_connector()
+            ->IsDeviceEnterpriseManaged() &&
+        (chromeos::IsManagedGuestSession() || chromeos::IsKioskSession()));
+#else
+  const bool needs_identity_manager_tokens = true;
+#endif  // BUILDFLAG(IS_CHROMEOS)
+  signin::IdentityManager* identity_manager =
+      IdentityManagerFactory::GetForProfile(GetProfile());
+  if (needs_identity_manager_tokens &&
+      !identity_manager->AreRefreshTokensLoaded()) {
+    refresh_tokens_loaded_waiter_ = std::make_unique<RefreshTokensLoadedWaiter>(
+        *identity_manager, std::move(next_step));
+  } else {
+    content::GetUIThreadTaskRunner({})->PostTask(FROM_HERE,
+                                                 std::move(next_step));
+  }
 
   return RespondLater();
 }
 
 void IdentityGetAuthTokenFunction::GetAuthTokenForAccount(
     const GaiaId& gaia_id) {
+  refresh_tokens_loaded_waiter_.reset();
+
   selected_gaia_id_ = gaia_id;
   if (gaia_id.empty()) {
     selected_gaia_id_ = IdentityAPI::GetFactoryInstance()
@@ -329,8 +356,7 @@ void IdentityGetAuthTokenFunction::StartSigninFlow() {
 
 #if BUILDFLAG(ENABLE_DICE_SUPPORT)
   if (!identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSignin) &&
-      !identity_manager->GetAccountsWithRefreshTokens().empty() &&
-      switches::IsExplicitBrowserSigninUIOnDesktopEnabled()) {
+      !identity_manager->GetAccountsWithRefreshTokens().empty()) {
     // The user is signed in on the web but not to Chrome.
     MaybeShowChromeSigninDialog();
     return;
@@ -729,26 +755,6 @@ void IdentityGetAuthTokenFunction::OnGetAccessTokenComplete(
   }
 }
 
-#if BUILDFLAG(IS_CHROMEOS)
-void IdentityGetAuthTokenFunction::OnAccessTokenForDeviceAccountFetchCompleted(
-    crosapi::mojom::AccessTokenResultPtr result) {
-  std::optional<std::string> access_token;
-  base::Time expiration_time;
-  GoogleServiceAuthError error = GoogleServiceAuthError::AuthErrorNone();
-  if (result->is_access_token_info()) {
-    access_token = result->get_access_token_info()->access_token;
-    expiration_time = result->get_access_token_info()->expiration_time;
-  } else {
-    DCHECK(result->is_error());
-    error = account_manager::FromMojoGoogleServiceAuthError(result->get_error())
-                .value_or(GoogleServiceAuthError(
-                    GoogleServiceAuthError::SERVICE_ERROR));
-  }
-  device_oauth2_token_fetcher_.reset();
-  OnGetAccessTokenComplete(access_token, expiration_time, error);
-}
-#endif
-
 void IdentityGetAuthTokenFunction::OnAccessTokenFetchCompleted(
     GoogleServiceAuthError error,
     signin::AccessTokenInfo access_token_info) {
@@ -766,10 +772,9 @@ void IdentityGetAuthTokenFunction::OnIdentityAPIShutdown() {
 #if BUILDFLAG(IS_CHROMEOS)
   device_oauth2_token_fetcher_.reset();
 #endif
-  if (gaia_remote_consent_flow_) {
-    gaia_remote_consent_flow_->Stop();
-  }
+  gaia_remote_consent_flow_.reset();
   token_key_account_access_token_fetcher_.reset();
+  refresh_tokens_loaded_waiter_.reset();
   scoped_identity_manager_observation_.Reset();
   extensions::IdentityAPI::GetFactoryInstance()
       ->Get(GetProfile())
@@ -780,21 +785,6 @@ void IdentityGetAuthTokenFunction::OnIdentityAPIShutdown() {
       IdentityGetAuthTokenError::State::kBrowserContextShutDown));
 }
 
-#if BUILDFLAG(IS_CHROMEOS)
-void IdentityGetAuthTokenFunction::StartDeviceAccessTokenRequest() {
-  device_oauth2_token_fetcher_ = std::make_unique<DeviceOAuth2TokenFetcher>();
-  // Since robot account refresh tokens are scoped down to [any-api] only,
-  // request access token for [any-api] instead of login.
-  // `Unretained()` is safe because this outlives
-  // `device_oauth2_token_fetcher_`.
-  device_oauth2_token_fetcher_->FetchAccessTokenForDeviceAccount(
-      {GaiaConstants::kAnyApiOAuth2Scope},
-      base::BindOnce(&IdentityGetAuthTokenFunction::
-                         OnAccessTokenForDeviceAccountFetchCompleted,
-                     base::Unretained(this)));
-}
-#endif
-
 void IdentityGetAuthTokenFunction::StartTokenKeyAccountAccessTokenRequest() {
   TRACE_EVENT_NESTABLE_ASYNC_BEGIN0("identity", "GetAccessToken", this);
 
@@ -878,12 +868,6 @@ IdentityGetAuthTokenFunction::CreateMintTokenFlow() {
   return mint_token_flow;
 }
 
-bool IdentityGetAuthTokenFunction::HasRefreshTokenForTokenKeyAccount() const {
-  auto* identity_manager = IdentityManagerFactory::GetForProfile(GetProfile());
-  return identity_manager->HasAccountWithRefreshToken(
-      token_key_.account_info.account_id);
-}
-
 std::string IdentityGetAuthTokenFunction::GetOAuth2ClientId() const {
   DCHECK(extension());
   const auto& oauth2_info = OAuth2ManifestHandler::GetOAuth2Info(*extension());
@@ -992,4 +976,101 @@ IdentityGetAuthTokenFunction::GetErrorFromInteractivityStatus(
   return IdentityGetAuthTokenError(state);
 }
 
+class IdentityGetAuthTokenFunction::RefreshTokensLoadedWaiter
+    : public signin::IdentityManager::Observer {
+ public:
+  RefreshTokensLoadedWaiter(signin::IdentityManager& identity_manager,
+                            base::OnceClosure callback);
+
+  // signin::IdentityManager::Observer:
+  void OnRefreshTokensLoaded() override;
+
+ private:
+  base::OnceClosure callback_;
+  base::ScopedObservation<signin::IdentityManager,
+                          signin::IdentityManager::Observer>
+      identity_manager_observation_{this};
+};
+
+IdentityGetAuthTokenFunction::RefreshTokensLoadedWaiter::
+    RefreshTokensLoadedWaiter(signin::IdentityManager& identity_manager,
+                              base::OnceClosure callback)
+    : callback_(std::move(callback)) {
+  CHECK(callback_);
+  CHECK(!identity_manager.AreRefreshTokensLoaded());
+
+  identity_manager_observation_.Observe(&identity_manager);
+}
+
+void IdentityGetAuthTokenFunction::RefreshTokensLoadedWaiter::
+    OnRefreshTokensLoaded() {
+  identity_manager_observation_.Reset();
+  std::move(callback_).Run();
+}
+
+#if BUILDFLAG(IS_CHROMEOS)
+
+class IdentityGetAuthTokenFunction::DeviceOAuth2TokenFetcher
+    : public OAuth2AccessTokenManager::Consumer {
+ public:
+  using CallbackType = base::OnceCallback<void(
+      const std::optional<std::string>& /*access_token*/,
+      base::Time /*expiration_time*/,
+      const GoogleServiceAuthError& /*error*/)>;
+
+  DeviceOAuth2TokenFetcher()
+      : OAuth2AccessTokenManager::Consumer("device_oauth2_token_service_ash") {}
+  ~DeviceOAuth2TokenFetcher() override = default;
+
+  // Starts requesting access token.
+  void StartRequest(CallbackType callback) {
+    request_ = DeviceOAuth2TokenServiceFactory::Get()->StartAccessTokenRequest(
+        {GaiaConstants::kAnyApiOAuth2Scope}, this);
+    callback_ = std::move(callback);
+  }
+
+  // OAuth2AccessTokenManager::Consumer:
+
+  void OnGetTokenSuccess(
+      const OAuth2AccessTokenManager::Request* request,
+      const OAuth2AccessTokenConsumer::TokenResponse& token_response) override {
+    if (callback_) {
+      std::move(callback_).Run(token_response.access_token,
+                               token_response.expiration_time,
+                               GoogleServiceAuthError::AuthErrorNone());
+    }
+  }
+
+  void OnGetTokenFailure(const OAuth2AccessTokenManager::Request* request,
+                         const GoogleServiceAuthError& error) override {
+    if (callback_) {
+      std::move(callback_).Run(std::nullopt, base::Time(), error);
+    }
+  }
+
+ private:
+  std::unique_ptr<OAuth2AccessTokenManager::Request> request_;
+  CallbackType callback_;
+};
+
+void IdentityGetAuthTokenFunction::StartDeviceAccessTokenRequest() {
+  device_oauth2_token_fetcher_ = std::make_unique<DeviceOAuth2TokenFetcher>();
+  // Since robot account refresh tokens are scoped down to [any-api] only,
+  // request access token for [any-api] instead of login.
+  device_oauth2_token_fetcher_->StartRequest(
+      base::BindOnce(&IdentityGetAuthTokenFunction::
+                         OnAccessTokenForDeviceAccountFetchCompleted,
+                     weak_ptr_factory_.GetWeakPtr()));
+}
+
+void IdentityGetAuthTokenFunction::OnAccessTokenForDeviceAccountFetchCompleted(
+    const std::optional<std::string>& access_token,
+    base::Time expiration_time,
+    const GoogleServiceAuthError& error) {
+  device_oauth2_token_fetcher_.reset();
+  OnGetAccessTokenComplete(access_token, expiration_time, error);
+}
+
+#endif  // BUILDFLAG(IS_CHROMEOS)
+
 }  // namespace extensions
