@@ -1,4 +1,4 @@
-// Copyright 2013 The Chromium Authors. All rights reserved.
+// Copyright 2013 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -9,21 +9,21 @@
 
 #include <memory>
 
-#include "base/callback.h"
 #include "base/files/file.h"
 #include "base/files/scoped_temp_dir.h"
-#include "base/hash/md5.h"
+#include "base/functional/callback.h"
 #include "base/memory/ref_counted_memory.h"
 #include "base/memory/weak_ptr.h"
-#include "base/sequenced_task_runner.h"
+#include "base/task/sequenced_task_runner.h"
 #include "base/task/task_traits.h"
 #include "build/build_config.h"
-#include "chrome/browser/extensions/api/image_writer_private/image_writer_utility_client.h"
+#include "build/chromeos_buildflags.h"
 #include "chrome/common/extensions/api/image_writer_private.h"
+#include "crypto/obsolete/md5.h"
 #include "extensions/common/extension_id.h"
 
-#if defined(OS_CHROMEOS)
-#include "chromeos/disks/disk_mount_manager.h"
+#if BUILDFLAG(IS_CHROMEOS)
+#include "chromeos/ash/components/disks/disk_mount_manager.h"
 #endif
 
 namespace image_writer_api = extensions::api::image_writer_private;
@@ -32,17 +32,17 @@ namespace base {
 class FilePath;
 }  // namespace base
 
-namespace service_manager {
-class Connector;
-}
-
 namespace extensions {
 namespace image_writer {
 
-const int kProgressComplete = 100;
+inline constexpr int kProgressComplete = 100;
 
 class OperationManager;
 
+#if !BUILDFLAG(IS_CHROMEOS)
+class ImageWriterUtilityClient;
+#endif
+
 // Encapsulates an operation being run on behalf of the
 // OperationManager.  Construction of the operation does not start
 // anything.  The operation's Start method should be called to start it, and
@@ -67,11 +67,13 @@ class Operation : public base::RefCountedThreadSafe<Operation> {
       base::OnceCallback<void(bool, const std::string&)>;
 
   Operation(base::WeakPtr<OperationManager> manager,
-            std::unique_ptr<service_manager::Connector> connector,
             const ExtensionId& extension_id,
             const std::string& device_path,
             const base::FilePath& download_folder);
 
+  Operation(const Operation&) = delete;
+  Operation& operator=(const Operation&) = delete;
+
   // Starts the operation.
   void Start();
 
@@ -87,7 +89,7 @@ class Operation : public base::RefCountedThreadSafe<Operation> {
   int GetProgress();
   image_writer_api::Stage GetStage();
 
-  // Posts |task| to Operation's |task_runner_|.
+  // Posts `task` to Operation's `task_runner_`.
   void PostTask(base::OnceClosure task);
 
  protected:
@@ -101,28 +103,28 @@ class Operation : public base::RefCountedThreadSafe<Operation> {
   // operation.  It will be called from Start().
   virtual void StartImpl() = 0;
 
-  // Unzips the current file if it ends in ".zip".  The current_file will be set
-  // to the unzipped file.
-  void Unzip(const base::Closure& continuation);
+  // Extracts the current file if it's an archive.  The current_file will be set
+  // to the extracted file.
+  void Extract(base::OnceClosure continuation);
 
   // Writes the current file to device_path.
-  void Write(const base::Closure& continuation);
+  void Write(base::OnceClosure continuation);
 
   // Verifies that the current file and device_path contents match.
-  void VerifyWrite(const base::Closure& continuation);
+  void VerifyWrite(base::OnceClosure continuation);
 
   // Completes the operation.
   void Finish();
 
   // Generates an error.
-  // |error_message| is used to create an OnWriteError event which is
+  // `error_message` is used to create an OnWriteError event which is
   // sent to the extension
   void Error(const std::string& error_message);
 
-  // Set |progress_| and send an event.  Progress should be in the interval
+  // Set `progress_` and send an event.  Progress should be in the interval
   // [0,100]
   void SetProgress(int progress);
-  // Change to a new |stage_| and set |progress_| to zero.  Triggers a progress
+  // Change to a new `stage_` and set `progress_` to zero.  Triggers a progress
   // event.
   void SetStage(image_writer_api::Stage stage);
 
@@ -131,23 +133,20 @@ class Operation : public base::RefCountedThreadSafe<Operation> {
 
   // Adds a callback that will be called during clean-up, whether the operation
   // is aborted, encounters and error, or finishes successfully.  These
-  // functions will be run on |task_runner_|.
+  // functions will be run on `task_runner_`.
   void AddCleanUpFunction(base::OnceClosure callback);
 
   // Completes the current operation (progress set to 100) and runs the
   // continuation.
-  void CompleteAndContinue(const base::Closure& continuation);
+  void CompleteAndContinue(base::OnceClosure continuation);
 
-  // If |file_size| is non-zero, only |file_size| bytes will be read from file,
+  // If `file_size` is non-zero, only `file_size` bytes will be read from file,
   // otherwise the entire file will be read.
-  // |progress_scale| is a percentage to which the progress will be scale, e.g.
+  // `progress_scale` is a percentage to which the progress will be scale, e.g.
   // a scale of 50 means it will increment from 0 to 50 over the course of the
-  // sum.  |progress_offset| is an percentage that will be added to the progress
-  // of the MD5 sum before updating |progress_| but after scaling.
+  // sum.  `progress_offset` is an percentage that will be added to the progress
+  // of the MD5 sum before updating `progress_` but after scaling.
   void GetMD5SumOfFile(const base::FilePath& file,
-                       int64_t file_size,
-                       int progress_offset,
-                       int progress_scale,
                        base::OnceCallback<void(const std::string&)> callback);
 
   bool IsRunningInCorrectSequence() const;
@@ -167,7 +166,7 @@ class Operation : public base::RefCountedThreadSafe<Operation> {
   friend class ImageWriterUtilityClientTest;
   friend class WriteFromUrlOperationForTest;
 
-#if !defined(OS_CHROMEOS)
+#if !BUILDFLAG(IS_CHROMEOS)
   // Ensures the client is started.  This may be called many times but will only
   // instantiate one client which should exist for the lifetime of the
   // Operation.
@@ -183,17 +182,17 @@ class Operation : public base::RefCountedThreadSafe<Operation> {
   scoped_refptr<ImageWriterUtilityClient> image_writer_client_;
 #endif
 
-#if defined(OS_CHROMEOS)
-  // Unmounts all volumes on |device_path_|.
-  void UnmountVolumes(const base::Closure& continuation);
+#if BUILDFLAG(IS_CHROMEOS)
+  // Unmounts all volumes on `device_path_`.
+  void UnmountVolumes(base::OnceClosure continuation);
   // Starts the write after unmounting.
-  void UnmountVolumesCallback(const base::Closure& continuation,
-                              chromeos::MountError error_code);
+  void UnmountVolumesCallback(base::OnceClosure continuation,
+                              ash::MountError error_code);
   // Starts the ImageBurner write.  Note that target_path is the file path of
   // the device where device_path has been a system device path.
   void StartWriteOnUIThread(const std::string& target_path,
-                            const base::Closure& continuation);
-  void OnBurnFinished(const base::Closure& continuation,
+                            base::OnceClosure continuation);
+  void OnBurnFinished(base::OnceClosure continuation,
                       const std::string& target_path,
                       bool success,
                       const std::string& error);
@@ -205,34 +204,26 @@ class Operation : public base::RefCountedThreadSafe<Operation> {
 
   // Incrementally calculates the MD5 sum of a file.
   void MD5Chunk(base::File file,
-                int64_t bytes_processed,
-                int64_t bytes_total,
-                int progress_offset,
-                int progress_scale,
+                crypto::obsolete::Md5 md5,
+                size_t bytes_processed,
+                size_t bytes_total,
                 const base::OnceCallback<void(const std::string&)> callback);
 
-  // Callbacks for UnzipHelper.
-  void OnUnzipOpenComplete(const base::FilePath& image_path);
-  void OnUnzipProgress(int64_t total_bytes, int64_t progress_bytes);
-  void OnUnzipFailure(const std::string& error);
+  // Callbacks for Extractor.
+  void OnExtractOpenComplete(const base::FilePath& image_path);
+  void OnExtractProgress(int64_t total_bytes, int64_t progress_bytes);
+  void OnExtractFailure(const std::string& error);
 
   // Runs all cleanup functions.
   void CleanUp();
 
-  // Connector to the service manager. Used and deleted on |task_runner_|.
-  std::unique_ptr<service_manager::Connector> connector_;
-
-  // |stage_| and |progress_| are owned by the FILE thread, use |SetStage| and
-  // |SetProgress| to update.  Progress should be in the interval [0,100]
+  // `stage_` and `progress_` are owned by the FILE thread, use `SetStage` and
+  // `SetProgress` to update.  Progress should be in the interval [0,100]
   image_writer_api::Stage stage_;
   int progress_;
 
-  // MD5 contexts don't play well with smart pointers.  Just going to allocate
-  // memory here.  This requires that we only do one MD5 sum at a time.
-  base::MD5Context md5_context_;
-
   // Cleanup operations that must be run.  All these functions are run on
-  // |task_runner_|.
+  // `task_runner_`.
   std::vector<base::OnceClosure> cleanup_functions_;
 
   static constexpr base::TaskTraits blocking_task_traits() {
@@ -252,8 +243,6 @@ class Operation : public base::RefCountedThreadSafe<Operation> {
   // Sequenced task runner where all I/O operation will be performed.
   // Most of the methods of this class run in this task runner.
   scoped_refptr<base::SequencedTaskRunner> task_runner_;
-
-  DISALLOW_COPY_AND_ASSIGN(Operation);
 };
 
 }  // namespace image_writer
