@@ -2,13 +2,9 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#include "chrome/browser/extensions/api/messaging/native_messaging_test_util.h"
-#include "chrome/browser/extensions/browsertest_util.h"
 #include "chrome/browser/extensions/extension_apitest.h"
 #include "chrome/browser/profiles/profile.h"
-#include "chrome/browser/ui/browser.h"
 #include "chrome/common/chrome_switches.h"
-#include "chrome/test/base/ui_test_utils.h"
 #include "content/public/browser/service_worker_context.h"
 #include "content/public/test/browser_test.h"
 #include "content/public/test/service_worker_test_helpers.h"
@@ -21,6 +17,10 @@
 #include "extensions/test/test_extension_dir.h"
 #include "net/dns/mock_host_resolver.h"
 
+#if BUILDFLAG(ENABLE_EXTENSIONS)
+#include "chrome/browser/extensions/api/messaging/native_messaging_test_util.h"
+#endif
+
 namespace extensions {
 
 namespace {
@@ -88,11 +88,18 @@ class ServiceWorkerMessagingTest : public ExtensionApiTest {
   void StopServiceWorker(const Extension& extension) {
     // TODO(lazyboy): Ideally we'd want to test worker shutdown on idle, do that
     // once //content API allows to override test timeouts for Service Workers.
-    browsertest_util::StopServiceWorkerForExtensionGlobalScope(
-        browser()->profile(), extension.id());
+    browsertest_util::StopServiceWorkerForExtensionGlobalScope(profile(),
+                                                               extension.id());
   }
 
+  content::WebContents* AddTab(const GURL& url) {
+    EXPECT_TRUE(NavigateToURLInNewTab(url)) << url;
+    return GetActiveWebContents();
+  }
+
+#if BUILDFLAG(ENABLE_EXTENSIONS)
   extensions::ScopedTestNativeMessagingHost test_host_;
+#endif
 };
 
 class ServiceWorkerMessagingTestWithActivityLog
@@ -119,8 +126,7 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest, TabToWorkerOneWay) {
     ASSERT_TRUE(StartEmbeddedTestServer());
     const GURL url =
         embedded_test_server()->GetURL("/extensions/test_file.html");
-    content::WebContents* new_web_contents =
-        browsertest_util::AddTab(browser(), url);
+    content::WebContents* new_web_contents = AddTab(url);
     EXPECT_TRUE(new_web_contents);
   }
 
@@ -142,8 +148,7 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest, TabToWorker) {
     ASSERT_TRUE(StartEmbeddedTestServer());
     const GURL url =
         embedded_test_server()->GetURL("/extensions/test_file.html");
-    content::WebContents* new_web_contents =
-        browsertest_util::AddTab(browser(), url);
+    content::WebContents* new_web_contents = AddTab(url);
     EXPECT_TRUE(new_web_contents);
   }
 
@@ -199,7 +204,7 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
 
   GURL url =
       embedded_test_server()->GetURL("example.com", "/extensions/body1.html");
-  ASSERT_TRUE(ui_test_utils::NavigateToURL(browser(), url));
+  ASSERT_TRUE(NavigateToURL(url));
 
   // Wait for the content script to connect to the worker's port.
   EXPECT_TRUE(catcher.GetNextResult()) << catcher.message();
@@ -211,14 +216,16 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
   EXPECT_TRUE(catcher.GetNextResult()) << catcher.message();
 }
 
+#if BUILDFLAG(ENABLE_EXTENSIONS)
 // Regression test for https://crbug.com/1176400.
 // Tests that service worker shutdown closes messaging channel properly.
+// TODO(crbug.com/417786914): Support native messaging tests on desktop Android.
 IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
                        WorkerShutsDownWhileNativeMessagePortIsOpen) {
   // Set up an observer to wait for the registration to be stored before
   // calling StopServiceWorker below.
   service_worker_test_utils::TestServiceWorkerContextObserver observer(
-      browser()->profile());
+      profile());
   ASSERT_NO_FATAL_FAILURE(test_host_.RegisterTestHost(false));
 
   ResultCatcher catcher;
@@ -237,6 +244,7 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
 }
 
 // Tests chrome.tabs.sendMessage from SW extension to content script.
+// TODO(crbug.com/371432155): Support chrome.tabs on desktop Android.
 IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest, WorkerToTab) {
   ASSERT_TRUE(StartEmbeddedTestServer());
   ASSERT_TRUE(
@@ -248,6 +256,7 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest, WorkerToTab) {
 // callback doesn't crash.
 //
 // Regression test for https://crbug.com/1218569.
+// TODO(crbug.com/371432155): Support chrome.tabs on desktop Android.
 IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
                        TabsSendMessageWithoutCallback) {
   ASSERT_TRUE(StartEmbeddedTestServer());
@@ -255,6 +264,7 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
       "service_worker/messaging/tabs_send_message_without_callback"))
       << message_;
 }
+#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
 
 // Tests port creation (chrome.runtime.connect) from content script to an
 // extension SW and disconnecting the port.
@@ -270,9 +280,8 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
   ResultCatcher catcher;
   {
     ASSERT_TRUE(StartEmbeddedTestServer());
-    content::WebContents* new_web_contents = browsertest_util::AddTab(
-        browser(),
-        embedded_test_server()->GetURL("/extensions/test_file.html"));
+    content::WebContents* new_web_contents =
+        AddTab(embedded_test_server()->GetURL("/extensions/test_file.html"));
     EXPECT_TRUE(new_web_contents);
   }
   EXPECT_TRUE(catcher.GetNextResult()) << catcher.message();
@@ -293,9 +302,8 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
   ResultCatcher catcher;
   {
     ASSERT_TRUE(StartEmbeddedTestServer());
-    content::WebContents* new_web_contents = browsertest_util::AddTab(
-        browser(),
-        embedded_test_server()->GetURL("/extensions/test_file.html"));
+    content::WebContents* new_web_contents =
+        AddTab(embedded_test_server()->GetURL("/extensions/test_file.html"));
     EXPECT_TRUE(new_web_contents);
   }
   EXPECT_TRUE(catcher.GetNextResult()) << catcher.message();
@@ -359,7 +367,7 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
   // content script to connect to its background's port.
   GURL url =
       embedded_test_server()->GetURL("example.com", "/extensions/body1.html");
-  ASSERT_TRUE(ui_test_utils::NavigateToURL(browser(), url));
+  ASSERT_TRUE(NavigateToURL(url));
   EXPECT_TRUE(content_script_connected_catcher.GetNextResult())
       << content_script_connected_catcher.message();
 
@@ -398,9 +406,8 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTestWithActivityLog, ActivityLog) {
   ASSERT_TRUE(friend_extension);
   {
     ResultCatcher catcher;
-    content::WebContents* new_web_contents = browsertest_util::AddTab(
-        browser(),
-        embedded_test_server()->GetURL("/extensions/test_file.html"));
+    content::WebContents* new_web_contents =
+        AddTab(embedded_test_server()->GetURL("/extensions/test_file.html"));
     EXPECT_TRUE(new_web_contents);
     EXPECT_TRUE(catcher.GetNextResult()) << catcher.message();
   }
@@ -417,7 +424,7 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest, LongLivedChannelNoMessage) {
   ASSERT_TRUE(StartEmbeddedTestServer());
 
   service_worker_test_utils::TestServiceWorkerContextObserver observer(
-      browser()->profile());
+      profile());
   const Extension* extension = LoadExtension(test_data_dir_.AppendASCII(
       "service_worker/messaging/connect_to_worker/connect"));
   ASSERT_TRUE(extension);
@@ -426,9 +433,8 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest, LongLivedChannelNoMessage) {
   // Load the tab with content script to open a Port to |extension|.
   ResultCatcher catcher;
   {
-    content::WebContents* new_web_contents = browsertest_util::AddTab(
-        browser(),
-        embedded_test_server()->GetURL("/extensions/test_file.html"));
+    content::WebContents* new_web_contents =
+        AddTab(embedded_test_server()->GetURL("/extensions/test_file.html"));
     EXPECT_TRUE(new_web_contents);
   }
   EXPECT_TRUE(catcher.GetNextResult()) << catcher.message();
@@ -437,8 +443,7 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest, LongLivedChannelNoMessage) {
   // external request.
   base::RunLoop().RunUntilIdle();
   content::ServiceWorkerContext* context =
-      util::GetServiceWorkerContextForExtensionId(extension->id(),
-                                                  browser()->profile());
+      util::GetServiceWorkerContextForExtensionId(extension->id(), profile());
   EXPECT_FALSE(
       content::TriggerTimeoutAndCheckRunningState(context, version_id));
 }
@@ -449,7 +454,7 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest, OneTimeChannel) {
   ASSERT_TRUE(StartEmbeddedTestServer());
 
   service_worker_test_utils::TestServiceWorkerContextObserver observer(
-      browser()->profile());
+      profile());
   const Extension* extension = LoadExtension(test_data_dir_.AppendASCII(
       "service_worker/messaging/connect_to_worker/send_message"));
   ASSERT_TRUE(extension);
@@ -458,9 +463,8 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest, OneTimeChannel) {
   // Load the tab with content script to open a Port to |extension|.
   ResultCatcher catcher;
   {
-    content::WebContents* new_web_contents = browsertest_util::AddTab(
-        browser(),
-        embedded_test_server()->GetURL("/extensions/test_file.html"));
+    content::WebContents* new_web_contents =
+        AddTab(embedded_test_server()->GetURL("/extensions/test_file.html"));
     EXPECT_TRUE(new_web_contents);
   }
   EXPECT_TRUE(catcher.GetNextResult()) << catcher.message();
@@ -471,19 +475,20 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest, OneTimeChannel) {
   // request is not finished.
   base::RunLoop().RunUntilIdle();
   content::ServiceWorkerContext* context =
-      util::GetServiceWorkerContextForExtensionId(extension->id(),
-                                                  browser()->profile());
+      util::GetServiceWorkerContextForExtensionId(extension->id(), profile());
   EXPECT_TRUE(content::TriggerTimeoutAndCheckRunningState(context, version_id));
 }
 
+#if BUILDFLAG(ENABLE_EXTENSIONS)
 // Tests post messages through a long-lived channel from content script to an
 // extension SW should extend SW lifetime.
+// TODO(crbug.com/383366125): Flaky on desktop Android.
 IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
                        LongLivedChannelPostMessage) {
   ASSERT_TRUE(StartEmbeddedTestServer());
 
   service_worker_test_utils::TestServiceWorkerContextObserver observer(
-      browser()->profile());
+      profile());
   const Extension* extension = LoadExtension(test_data_dir_.AppendASCII(
       "service_worker/messaging/connect_to_worker/connect_and_post"));
   ASSERT_TRUE(extension);
@@ -491,16 +496,14 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
 
   // Set idle timeout to 1 second.
   content::ServiceWorkerContext* context =
-      util::GetServiceWorkerContextForExtensionId(extension->id(),
-                                                  browser()->profile());
+      util::GetServiceWorkerContextForExtensionId(extension->id(), profile());
   content::SetServiceWorkerIdleDelay(context, version_id, base::Seconds(1));
 
   // Load the tab with content script to open a Port to |extension|.
   ResultCatcher catcher;
   {
-    content::WebContents* new_web_contents = browsertest_util::AddTab(
-        browser(),
-        embedded_test_server()->GetURL("/extensions/test_file.html"));
+    content::WebContents* new_web_contents =
+        AddTab(embedded_test_server()->GetURL("/extensions/test_file.html"));
     EXPECT_TRUE(new_web_contents);
   }
   // Catching the succeed test message means the service worker has been alive
@@ -513,5 +516,6 @@ IN_PROC_BROWSER_TEST_F(ServiceWorkerMessagingTest,
   base::RunLoop().RunUntilIdle();
   EXPECT_TRUE(content::CheckServiceWorkerIsRunning(context, version_id));
 }
+#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
 
 }  // namespace extensions
