@@ -1,14 +1,12 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 #include "chrome/browser/extensions/api/notifications/extension_notification_handler.h"
 
-#include "base/callback.h"
-#include "base/logging.h"
+#include "base/check_op.h"
+#include "base/functional/callback.h"
 #include "base/metrics/histogram_macros.h"
-#include "base/strings/nullable_string16.h"
-#include "base/strings/string_piece.h"
 #include "chrome/browser/extensions/api/notifications/extension_notification_display_helper.h"
 #include "chrome/browser/extensions/api/notifications/extension_notification_display_helper_factory.h"
 #include "chrome/browser/notifications/notification_common.h"
@@ -20,17 +18,16 @@
 #include "extensions/browser/app_window/app_window_registry.h"
 #include "extensions/browser/app_window/native_app_window.h"
 #include "extensions/common/constants.h"
+#include "extensions/common/extension_id.h"
 #include "ui/message_center/public/cpp/notifier_id.h"
 #include "url/gurl.h"
 
 namespace extensions {
 
-namespace notifications = api::notifications;
-
 namespace {
 
-std::unique_ptr<base::ListValue> CreateBaseEventArgs(
-    const std::string& extension_id,
+base::Value::List CreateBaseEventArgs(
+    const ExtensionId& extension_id,
     const std::string& scoped_notification_id) {
   // Unscope the notification id before returning it.
   size_t index_of_separator = extension_id.length() + 1;
@@ -38,8 +35,8 @@ std::unique_ptr<base::ListValue> CreateBaseEventArgs(
   std::string unscoped_notification_id =
       scoped_notification_id.substr(index_of_separator);
 
-  std::unique_ptr<base::ListValue> args(new base::ListValue());
-  args->AppendString(unscoped_notification_id);
+  base::Value::List args;
+  args.Append(unscoped_notification_id);
   return args;
 }
 
@@ -50,10 +47,11 @@ ExtensionNotificationHandler::ExtensionNotificationHandler() = default;
 ExtensionNotificationHandler::~ExtensionNotificationHandler() = default;
 
 // static
-std::string ExtensionNotificationHandler::GetExtensionId(const GURL& url) {
-  if (!url.is_valid() || !url.SchemeIs(extensions::kExtensionScheme))
+ExtensionId ExtensionNotificationHandler::GetExtensionId(const GURL& url) {
+  if (!url.is_valid() || !url.SchemeIs(kExtensionScheme)) {
     return "";
-  return url.GetOrigin().host_piece().as_string();
+  }
+  return ExtensionId(url.DeprecatedGetOriginAsURL().host_piece());
 }
 
 void ExtensionNotificationHandler::OnClose(
@@ -63,14 +61,13 @@ void ExtensionNotificationHandler::OnClose(
     bool by_user,
     base::OnceClosure completed_closure) {
   EventRouter::UserGestureState gesture =
-      by_user ? EventRouter::USER_GESTURE_ENABLED
-              : EventRouter::USER_GESTURE_NOT_ENABLED;
-  std::string extension_id(GetExtensionId(GURL(origin)));
+      by_user ? EventRouter::UserGestureState::kEnabled
+              : EventRouter::UserGestureState::kNotEnabled;
+  ExtensionId extension_id(GetExtensionId(GURL(origin)));
   DCHECK(!extension_id.empty());
 
-  std::unique_ptr<base::ListValue> args(
-      CreateBaseEventArgs(extension_id, notification_id));
-  args->AppendBoolean(by_user);
+  base::Value::List args = CreateBaseEventArgs(extension_id, notification_id);
+  args.Append(by_user);
   SendEvent(profile, extension_id, events::NOTIFICATIONS_ON_CLOSED,
             api::notifications::OnClosed::kEventName, gesture, std::move(args));
 
@@ -86,16 +83,15 @@ void ExtensionNotificationHandler::OnClick(
     Profile* profile,
     const GURL& origin,
     const std::string& notification_id,
-    const base::Optional<int>& action_index,
-    const base::Optional<base::string16>& reply,
+    const std::optional<int>& action_index,
+    const std::optional<std::u16string>& reply,
     base::OnceClosure completed_closure) {
   DCHECK(!reply.has_value());
 
-  std::string extension_id(GetExtensionId(GURL(origin)));
-  std::unique_ptr<base::ListValue> args(
-      CreateBaseEventArgs(extension_id, notification_id));
+  ExtensionId extension_id(GetExtensionId(GURL(origin)));
+  base::Value::List args = CreateBaseEventArgs(extension_id, notification_id);
   if (action_index.has_value())
-    args->AppendInteger(action_index.value());
+    args.Append(action_index.value());
   events::HistogramValue histogram_value =
       action_index.has_value() ? events::NOTIFICATIONS_ON_BUTTON_CLICKED
                                : events::NOTIFICATIONS_ON_CLICKED;
@@ -104,26 +100,35 @@ void ExtensionNotificationHandler::OnClick(
                                : api::notifications::OnClicked::kEventName;
 
   SendEvent(profile, extension_id, histogram_value, event_name,
-            EventRouter::USER_GESTURE_ENABLED, std::move(args));
+            EventRouter::UserGestureState::kEnabled, std::move(args));
 
   std::move(completed_closure).Run();
 }
 
-void ExtensionNotificationHandler::DisableNotifications(Profile* profile,
-                                                        const GURL& origin) {
+void ExtensionNotificationHandler::DisableNotifications(
+    Profile* profile,
+    const GURL& origin,
+    const std::optional<std::string>& notification_id) {
   message_center::NotifierId notifier_id(
       message_center::NotifierType::APPLICATION, origin.host());
   NotifierStateTrackerFactory::GetForProfile(profile)->SetNotifierEnabled(
       notifier_id, false /* enabled */);
 }
 
+// There are not settings to open, but on the chance the notification shows with
+// the "Open Settings" prompt, this will no-op.
+void ExtensionNotificationHandler::OpenSettings(Profile* profile,
+                                                const GURL& origin) {
+  return;
+}
+
 void ExtensionNotificationHandler::SendEvent(
     Profile* profile,
-    const std::string& extension_id,
+    const ExtensionId& extension_id,
     events::HistogramValue histogram_value,
     const std::string& event_name,
     EventRouter::UserGestureState user_gesture,
-    std::unique_ptr<base::ListValue> args) {
+    base::Value::List args) {
   if (extension_id.empty())
     return;
 
@@ -131,8 +136,8 @@ void ExtensionNotificationHandler::SendEvent(
   if (!event_router)
     return;
 
-  std::unique_ptr<Event> event(
-      new Event(histogram_value, event_name, std::move(args)));
+  auto event =
+      std::make_unique<Event>(histogram_value, event_name, std::move(args));
   event->user_gesture = user_gesture;
   event_router->DispatchEventToExtension(extension_id, std::move(event));
 }
