@@ -3,7 +3,10 @@
 // found in the LICENSE file.
 
 #include "base/files/file_util.h"
+#include "base/path_service.h"
 #include "base/test/scoped_feature_list.h"
+#include "base/threading/thread_restrictions.h"
+#include "build/android_buildflags.h"
 #include "build/build_config.h"
 #include "build/chromeos_buildflags.h"
 #include "chrome/browser/extensions/api/permissions/permissions_api.h"
@@ -11,8 +14,7 @@
 #include "chrome/browser/extensions/extension_management_test_util.h"
 #include "chrome/browser/extensions/extension_with_management_policy_apitest.h"
 #include "chrome/browser/profiles/profile.h"
-#include "chrome/browser/ui/browser.h"
-#include "chrome/test/base/ui_test_utils.h"
+#include "chrome/common/chrome_paths.h"
 #include "components/policy/core/browser/browser_policy_connector.h"
 #include "components/policy/core/common/mock_configuration_policy_provider.h"
 #include "content/public/test/browser_test.h"
@@ -22,6 +24,10 @@
 #include "extensions/common/switches.h"
 #include "net/dns/mock_host_resolver.h"
 
+#if BUILDFLAG(IS_ANDROID)
+#include "chrome/browser/net/chrome_network_delegate.h"
+#endif
+
 namespace extensions {
 
 namespace {
@@ -112,11 +118,15 @@ IN_PROC_BROWSER_TEST_F(PermissionsApiTest, MAYBE_FaviconPermission) {
   ASSERT_TRUE(RunExtensionTest("permissions/favicon")) << message_;
 }
 
+#if BUILDFLAG(ENABLE_EXTENSIONS)
 // Test functions and APIs that are always allowed (even if you ask for no
 // permissions).
+// TODO(crbug.com/371432155): Port to desktop Android when chrome.tabs API
+// is available.
 IN_PROC_BROWSER_TEST_F(PermissionsApiTest, AlwaysAllowed) {
   ASSERT_TRUE(RunExtensionTest("permissions/always_allowed")) << message_;
 }
+#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
 
 // Tests that the optional permissions API works correctly.
 IN_PROC_BROWSER_TEST_P(PermissionsApiTestWithContextType,
@@ -127,7 +137,7 @@ IN_PROC_BROWSER_TEST_P(PermissionsApiTestWithContextType,
   URLPatternSet explicit_hosts;
   AddPattern(&explicit_hosts, "http://*.c.com/*");
 
-  ExtensionPrefs* prefs = ExtensionPrefs::Get(browser()->profile());
+  ExtensionPrefs* prefs = ExtensionPrefs::Get(profile());
   prefs->AddRuntimeGrantedPermissions(
       "kjmkgkdkpedkejedfhmfcenooemhbpbo",
       PermissionSet(std::move(apis), ManifestPermissionSet(),
@@ -158,7 +168,7 @@ IN_PROC_BROWSER_TEST_F(PermissionsApiTest, OptionalPermissionsDeny) {
   APIPermissionSet apis;
   apis.insert(mojom::APIPermissionID::kManagement);
 
-  ExtensionPrefs* prefs = ExtensionPrefs::Get(browser()->profile());
+  ExtensionPrefs* prefs = ExtensionPrefs::Get(profile());
   prefs->AddRuntimeGrantedPermissions(
       "kjmkgkdkpedkejedfhmfcenooemhbpbo",
       PermissionSet(std::move(apis), ManifestPermissionSet(), URLPatternSet(),
@@ -220,7 +230,7 @@ IN_PROC_BROWSER_TEST_F(PermissionsApiTest, OptionalPermissionsFileAccess) {
           PermissionsRequestFunction::DialogAction::kAutoReject);
   PermissionsRequestFunction::SetIgnoreUserGestureForTests(true);
 
-  ExtensionPrefs* prefs = ExtensionPrefs::Get(browser()->profile());
+  ExtensionPrefs* prefs = ExtensionPrefs::Get(profile());
 
   EXPECT_TRUE(RunExtensionTest("permissions/file_access_no")) << message_;
   EXPECT_FALSE(prefs->AllowFileAccess(last_loaded_extension_id()));
@@ -233,13 +243,21 @@ IN_PROC_BROWSER_TEST_F(PermissionsApiTest, OptionalPermissionsFileAccess) {
 // Tests loading of files or directory listings when an extension has file
 // access.
 IN_PROC_BROWSER_TEST_F(PermissionsApiTest, FileLoad) {
+#if BUILDFLAG(IS_ANDROID)
+  // Enable access to arbitrary files via file: schema. Ordinarily Chrome on
+  // Android blocks access to many directories, which affects the built-in
+  // web server this test extension accesses.
+  ChromeNetworkDelegate::EnableAccessToAllFilesForTesting(true);
+#endif
   base::ScopedTempDir temp_dir;
   {
     base::ScopedAllowBlockingForTesting allow_blocking;
     ASSERT_TRUE(temp_dir.CreateUniqueTempDir());
     base::FilePath empty_file = temp_dir.GetPath().AppendASCII("empty.html");
-    base::FilePath original_empty_file = ui_test_utils::GetTestFilePath(
-        base::FilePath(), base::FilePath().AppendASCII("empty.html"));
+    base::FilePath dir_test_data;
+    base::PathService::Get(chrome::DIR_TEST_DATA, &dir_test_data);
+    base::FilePath original_empty_file =
+        dir_test_data.AppendASCII("empty.html");
 
     EXPECT_TRUE(base::PathExists(original_empty_file));
     EXPECT_TRUE(base::CopyFile(original_empty_file, empty_file));
@@ -265,18 +283,25 @@ IN_PROC_BROWSER_TEST_P(PermissionsApiTestWithContextType, HostSubsets) {
   EXPECT_TRUE(RunExtensionTest("permissions/host_subsets")) << message_;
 }
 
+#if BUILDFLAG(ENABLE_EXTENSIONS)
 // Tests that requesting an optional permission from a background page, with
 // another window open, grants the permission and updates the bindings
 // (chrome.whatever, in this case chrome.alarms). Regression test for
 // crbug.com/435141, see details there for trickiness.
+// TODO(crbug.com/371432155): Port to desktop Android when chrome.tabs API
+// is available.
 IN_PROC_BROWSER_TEST_F(PermissionsApiTest, OptionalPermissionsUpdatesBindings) {
   ASSERT_TRUE(RunExtensionTest("permissions/optional_updates_bindings"))
       << message_;
 }
+#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
 
+// Desktop Android only supports manifest V3 / service worker.
+#if !BUILDFLAG(IS_ANDROID)
 INSTANTIATE_TEST_SUITE_P(PersistentBackground,
                          PermissionsApiTestWithContextType,
                          testing::Values(ContextType::kPersistentBackground));
+#endif
 INSTANTIATE_TEST_SUITE_P(ServiceWorker,
                          PermissionsApiTestWithContextType,
                          testing::Values(ContextType::kServiceWorker));
@@ -297,6 +322,9 @@ class PermissionsApiHostAccessRequestsTest : public PermissionsApiTest {
   base::test::ScopedFeatureList scoped_feature_list_;
 };
 
+#if BUILDFLAG(ENABLE_EXTENSIONS)
+// TODO(crbug.com/371432404): Port to desktop Android once
+// the webNavigation API and permission are supported.
 IN_PROC_BROWSER_TEST_F(PermissionsApiHostAccessRequestsTest,
                        InvalidAddHostAccessRequests) {
   ASSERT_TRUE(StartEmbeddedTestServer());
@@ -304,6 +332,7 @@ IN_PROC_BROWSER_TEST_F(PermissionsApiHostAccessRequestsTest,
   ASSERT_TRUE(RunExtensionTest("permissions/add_host_access_request"))
       << message_;
 }
+#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
 
 IN_PROC_BROWSER_TEST_F(PermissionsApiHostAccessRequestsTest,
                        InvalidRemoveHostAccessRequests) {
