@@ -19,13 +19,6 @@
 
 #if BUILDFLAG(ENABLE_PDF)
 #include "chrome/browser/pdf/pdf_extension_util.h"
-
-#if BUILDFLAG(IS_CHROMEOS)
-#include "chrome/browser/profiles/profile.h"
-#include "chrome/common/pref_names.h"
-#include "chromeos/ash/components/browser_context_helper/browser_context_types.h"
-#include "components/prefs/pref_service.h"
-#endif  // BUILDFLAG(IS_CHROMEOS)
 #endif  // BUILDFLAG(ENABLE_PDF)
 
 // To add a new component to this API, simply:
@@ -43,20 +36,6 @@ void AddStringsForIdentity(base::Value::Dict* dict) {
             l10n_util::GetStringUTF16(IDS_EXTENSION_CONFIRM_PERMISSIONS));
 }
 
-#if BUILDFLAG(ENABLE_PDF)
-bool IsPdfAnnotationsEnabled(content::BrowserContext* context) {
-#if BUILDFLAG(IS_CHROMEOS)
-  PrefService* prefs =
-      context ? Profile::FromBrowserContext(context)->GetPrefs() : nullptr;
-  if (prefs && prefs->IsManagedPreference(prefs::kPdfAnnotationsEnabled) &&
-      !prefs->GetBoolean(prefs::kPdfAnnotationsEnabled)) {
-    return false;
-  }
-#endif  // BUILDFLAG(IS_CHROMEOS)
-  return true;
-}
-#endif  // BUILDFLAG(ENABLE_PDF)
-
 }  // namespace
 
 namespace get_strings = api::resources_private::GetStrings;
@@ -82,13 +61,7 @@ ExtensionFunction::ResponseAction ResourcesPrivateGetStringsFunction::Run() {
 #if BUILDFLAG(ENABLE_PDF)
       pdf_extension_util::AddStrings(pdf_extension_util::PdfViewerContext::kAll,
                                      &dict);
-      bool enable_printing = true;
-#if BUILDFLAG(IS_CHROMEOS)
-      enable_printing = ash::IsUserBrowserContext(browser_context());
-#endif  // BUILDFLAG(IS_CHROMEOS)
-
-      pdf_extension_util::AddAdditionalData(
-          enable_printing, IsPdfAnnotationsEnabled(browser_context()), &dict);
+      pdf_extension_util::AddAdditionalData(browser_context(), &dict);
 #endif  // BUILDFLAG(ENABLE_PDF)
       break;
     }
