@@ -2,6 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+#include "chrome/browser/extensions/api/runtime/chrome_runtime_api_delegate.h"
+
 #include <memory>
 #include <set>
 #include <utility>
@@ -16,20 +18,21 @@
 #include "base/scoped_observation.h"
 #include "base/task/single_thread_task_runner.h"
 #include "base/test/simple_test_tick_clock.h"
-#include "chrome/browser/extensions/api/runtime/chrome_runtime_api_delegate.h"
 #include "chrome/browser/extensions/chrome_test_extension_loader.h"
 #include "chrome/browser/extensions/extension_service.h"
 #include "chrome/browser/extensions/extension_service_test_with_install.h"
 #include "chrome/browser/extensions/test_extension_system.h"
-#include "chrome/browser/extensions/update_install_gate.h"
 #include "chrome/browser/extensions/updater/extension_updater.h"
+#include "extensions/browser/delayed_install_manager.h"
 #include "extensions/browser/event_router.h"
 #include "extensions/browser/event_router_factory.h"
 #include "extensions/browser/extension_prefs.h"
 #include "extensions/browser/extension_registry.h"
+#include "extensions/browser/update_install_gate.h"
 #include "extensions/browser/updater/extension_downloader.h"
 #include "extensions/browser/updater/extension_downloader_test_delegate.h"
 #include "extensions/common/extension.h"
+#include "extensions/common/extension_id.h"
 #include "extensions/common/verifier_formats.h"
 #include "testing/gtest/include/gtest/gtest.h"
 
@@ -50,15 +53,15 @@ class TestEventRouter : public EventRouter {
   ~TestEventRouter() override = default;
 
   // An entry in our fake event registry.
-  using Entry = std::pair<std::string, std::string>;
+  using Entry = std::pair<ExtensionId, std::string>;
 
-  bool ExtensionHasEventListener(const std::string& extension_id,
+  bool ExtensionHasEventListener(const ExtensionId& extension_id,
                                  const std::string& event_name) const override {
     return base::Contains(fake_registry_, Entry(extension_id, event_name));
   }
 
   // Pretend that |extension_id| is listening for |event_name|.
-  void AddFakeListener(const std::string& extension_id,
+  void AddFakeListener(const ExtensionId& extension_id,
                        const std::string& event_name) {
     fake_registry_.insert(Entry(extension_id, event_name));
   }
@@ -83,7 +86,7 @@ class DownloaderTestDelegate : public ExtensionDownloaderTestDelegate {
 
   // On the next update check for extension |id|, we'll respond that no update
   // is available.
-  void AddNoUpdateResponse(const std::string& id) {
+  void AddNoUpdateResponse(const ExtensionId& id) {
     no_updates_.insert(id);
     if (updates_.find(id) != updates_.end()) {
       updates_.erase(id);
@@ -92,7 +95,7 @@ class DownloaderTestDelegate : public ExtensionDownloaderTestDelegate {
 
   // On the next update check for extension |id|, pretend that an update to
   // version |version| has been downloaded to |path|.
-  void AddUpdateResponse(const std::string& id,
+  void AddUpdateResponse(const ExtensionId& id,
                          const base::FilePath& path,
                          const std::string& version) {
     if (no_updates_.find(id) != no_updates_.end()) {
@@ -161,8 +164,8 @@ class DownloaderTestDelegate : public ExtensionDownloaderTestDelegate {
   // These keep track of what response we should give for update checks, keyed
   // by extension id. A given extension id should only appear in one or the
   // other.
-  std::set<std::string> no_updates_;
-  std::map<std::string, DownloadFinishedArgs> updates_;
+  std::set<ExtensionId> no_updates_;
+  std::map<ExtensionId, DownloadFinishedArgs> updates_;
 };
 
 // Helper to let test code wait for and return an update check result.
@@ -211,7 +214,7 @@ class ChromeRuntimeAPIDelegateTest : public ExtensionServiceTestWithInstall {
     InitializeExtensionServiceWithUpdater();
     runtime_delegate_ =
         std::make_unique<ChromeRuntimeAPIDelegate>(browser_context());
-    service()->updater()->SetExtensionCacheForTesting(nullptr);
+    ExtensionUpdater::Get(profile())->SetExtensionCacheForTesting(nullptr);
     EventRouterFactory::GetInstance()->SetTestingFactory(
         browser_context(),
         base::BindRepeating(&TestEventRouterFactoryFunction));
@@ -220,8 +223,9 @@ class ChromeRuntimeAPIDelegateTest : public ExtensionServiceTestWithInstall {
     // installation until the extension is idle.
     update_install_gate_ =
         std::make_unique<UpdateInstallGate>(service()->profile());
-    service()->RegisterInstallGate(ExtensionPrefs::DELAY_REASON_WAIT_FOR_IDLE,
-                                   update_install_gate_.get());
+    DelayedInstallManager::Get(browser_context())
+        ->RegisterInstallGate(ExtensionPrefs::DelayReason::kWaitForIdle,
+                              update_install_gate_.get());
     static_cast<TestExtensionSystem*>(ExtensionSystem::Get(browser_context()))
         ->SetReady();
   }
@@ -232,18 +236,18 @@ class ChromeRuntimeAPIDelegateTest : public ExtensionServiceTestWithInstall {
     ExtensionServiceTestWithInstall::TearDown();
   }
 
-  // Uses runtime_delegate_ to run an update check for |id|, expecting
+  // Uses runtime_delegate_ to run an update check for |extension_id|, expecting
   // |expected_status| and (if an update was available) |expected_version|.
   // The |expected_status| should be one of 'throttled', 'no_update', or
   // 'update_available'.
   void DoUpdateCheck(
-      const std::string& id,
+      const ExtensionId& extension_id,
       const api::runtime::RequestUpdateCheckStatus& expected_status,
       const std::string& expected_version) {
     UpdateCheckResultCatcher catcher;
     EXPECT_TRUE(runtime_delegate_->CheckForUpdates(
-        id, base::BindOnce(&UpdateCheckResultCatcher::OnResult,
-                           base::Unretained(&catcher))));
+        extension_id, base::BindOnce(&UpdateCheckResultCatcher::OnResult,
+                                     base::Unretained(&catcher))));
     std::unique_ptr<RuntimeAPIDelegate::UpdateCheckResult> result =
         catcher.WaitForResult();
     ASSERT_NE(nullptr, result.get());
@@ -281,7 +285,7 @@ TEST_F(ChromeRuntimeAPIDelegateTest, RequestUpdateCheck) {
 
   // Start by installing version 1.
   scoped_refptr<const Extension> v1(InstallCRX(v1_path, INSTALL_NEW));
-  std::string id = v1->id();
+  ExtensionId id = v1->id();
 
   // Make it look like our test extension listens for the
   // runtime.onUpdateAvailable event, so that it won't be updated immediately
@@ -292,20 +296,20 @@ TEST_F(ChromeRuntimeAPIDelegateTest, RequestUpdateCheck) {
 
   // Run an update check that should get a "no_update" response.
   downloader_test_delegate_.AddNoUpdateResponse(id);
-  DoUpdateCheck(id, api::runtime::REQUEST_UPDATE_CHECK_STATUS_NO_UPDATE, "");
+  DoUpdateCheck(id, api::runtime::RequestUpdateCheckStatus::kNoUpdate, "");
 
   // Check again after a short delay - we should be throttled because
   // not enough time has passed.
   clock_.Advance(base::Minutes(15));
   downloader_test_delegate_.AddNoUpdateResponse(id);
-  DoUpdateCheck(id, api::runtime::REQUEST_UPDATE_CHECK_STATUS_THROTTLED, "");
+  DoUpdateCheck(id, api::runtime::RequestUpdateCheckStatus::kThrottled, "");
 
   // Now simulate checking a few times at a 6 hour interval - none of these
   // should be throttled.
   for (int i = 0; i < 5; i++) {
     clock_.Advance(base::Hours(6));
     downloader_test_delegate_.AddNoUpdateResponse(id);
-    DoUpdateCheck(id, api::runtime::REQUEST_UPDATE_CHECK_STATUS_NO_UPDATE, "");
+    DoUpdateCheck(id, api::runtime::RequestUpdateCheckStatus::kNoUpdate, "");
   }
 
   // Run an update check that should get an "update_available" response. This
@@ -313,34 +317,34 @@ TEST_F(ChromeRuntimeAPIDelegateTest, RequestUpdateCheck) {
   // will not complete until we reload the extension.
   clock_.Advance(base::Days(1));
   downloader_test_delegate_.AddUpdateResponse(id, v2_path, "2.0");
-  DoUpdateCheck(id, api::runtime::REQUEST_UPDATE_CHECK_STATUS_UPDATE_AVAILABLE,
+  DoUpdateCheck(id, api::runtime::RequestUpdateCheckStatus::kUpdateAvailable,
                 "2.0");
 
   // Call again after short delay - it should be throttled instead of getting
   // another "update_available" response.
   clock_.Advance(base::Minutes(30));
   downloader_test_delegate_.AddUpdateResponse(id, v2_path, "2.0");
-  DoUpdateCheck(id, api::runtime::REQUEST_UPDATE_CHECK_STATUS_THROTTLED, "");
+  DoUpdateCheck(id, api::runtime::RequestUpdateCheckStatus::kThrottled, "");
 
   // Reload the extension, causing the delayed update to v2 to happen, then do
   // another update check - we should get a no_update instead of throttled.
-  service()->ReloadExtension(id);
+  registrar()->ReloadExtension(id);
   const Extension* current =
       ExtensionRegistry::Get(browser_context())->GetInstalledExtension(id);
   ASSERT_NE(nullptr, current);
   EXPECT_EQ("2.0", current->VersionString());
   clock_.Advance(base::Seconds(10));
   downloader_test_delegate_.AddNoUpdateResponse(id);
-  DoUpdateCheck(id, api::runtime::REQUEST_UPDATE_CHECK_STATUS_NO_UPDATE, "");
+  DoUpdateCheck(id, api::runtime::RequestUpdateCheckStatus::kNoUpdate, "");
 
   // Check again after short delay; we should be throttled.
   clock_.Advance(base::Minutes(5));
-  DoUpdateCheck(id, api::runtime::REQUEST_UPDATE_CHECK_STATUS_THROTTLED, "");
+  DoUpdateCheck(id, api::runtime::RequestUpdateCheckStatus::kThrottled, "");
 
   // Call again after a longer delay, we should should be unthrottled.
   clock_.Advance(base::Hours(8));
   downloader_test_delegate_.AddNoUpdateResponse(id);
-  DoUpdateCheck(id, api::runtime::REQUEST_UPDATE_CHECK_STATUS_NO_UPDATE, "");
+  DoUpdateCheck(id, api::runtime::RequestUpdateCheckStatus::kNoUpdate, "");
 }
 
 class ExtensionLoadWaiter : public ExtensionRegistryObserver {
