@@ -1,4 +1,4 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2012 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -8,19 +8,18 @@
 #include <stddef.h>
 
 #include <memory>
+#include <optional>
 #include <string>
 #include <vector>
 
-#include "base/memory/ref_counted.h"
 #include "base/values.h"
 #include "chrome/browser/extensions/api/storage/setting_sync_data.h"
-#include "components/sync/model/sync_change.h"
 #include "components/sync/model/syncable_service.h"
 #include "components/value_store/value_store.h"
 #include "extensions/browser/api/storage/settings_observer.h"
+#include "extensions/common/extension_id.h"
 
 namespace syncer {
-class SyncError;
 class ModelError;
 }  // namespace syncer
 
@@ -32,10 +31,10 @@ class SettingsSyncProcessor;
 class SyncableSettingsStorage : public value_store::ValueStore {
  public:
   SyncableSettingsStorage(SequenceBoundSettingsChangedCallback observer,
-                          const std::string& extension_id,
+                          const ExtensionId& extension_id,
                           // Ownership taken.
                           value_store::ValueStore* delegate,
-                          syncer::ModelType sync_type,
+                          syncer::DataType sync_type,
                           const syncer::SyncableService::StartSyncFlare& flare);
 
   SyncableSettingsStorage(const SyncableSettingsStorage&) = delete;
@@ -47,6 +46,7 @@ class SyncableSettingsStorage : public value_store::ValueStore {
   size_t GetBytesInUse(const std::string& key) override;
   size_t GetBytesInUse(const std::vector<std::string>& keys) override;
   size_t GetBytesInUse() override;
+  ReadResult GetKeys() override;
   ReadResult Get(const std::string& key) override;
   ReadResult Get(const std::vector<std::string>& keys) override;
   ReadResult Get() override;
@@ -54,7 +54,7 @@ class SyncableSettingsStorage : public value_store::ValueStore {
                   const std::string& key,
                   const base::Value& value) override;
   WriteResult Set(WriteOptions options,
-                  const base::DictionaryValue& values) override;
+                  const base::Value::Dict& values) override;
   WriteResult Remove(const std::string& key) override;
   WriteResult Remove(const std::vector<std::string>& keys) override;
   WriteResult Clear() override;
@@ -65,11 +65,11 @@ class SyncableSettingsStorage : public value_store::ValueStore {
 
   // Starts syncing this storage area. Must only be called if sync isn't
   // already active.
-  // |sync_state| is the current state of the extension settings in sync.
-  // |sync_processor| is used to write out any changes.
-  // Returns any error when trying to sync, or absl::nullopt on success.
-  absl::optional<syncer::ModelError> StartSyncing(
-      std::unique_ptr<base::DictionaryValue> sync_state,
+  // `sync_state` is the current state of the extension settings in sync.
+  // `sync_processor` is used to write out any changes.
+  // Returns any error when trying to sync, or std::nullopt on success.
+  std::optional<syncer::ModelError> StartSyncing(
+      base::Value::Dict sync_state,
       std::unique_ptr<SettingsSyncProcessor> sync_processor);
 
   // Stops syncing this storage area. May be called at any time (idempotent).
@@ -77,12 +77,12 @@ class SyncableSettingsStorage : public value_store::ValueStore {
 
   // Pushes a list of sync changes into this storage area. May be called at any
   // time, changes will be ignored if sync isn't active.
-  // Returns any error when trying to sync, or absl::nullopt on success.
-  absl::optional<syncer::ModelError> ProcessSyncChanges(
+  // Returns any error when trying to sync, or std::nullopt on success.
+  std::optional<syncer::ModelError> ProcessSyncChanges(
       std::unique_ptr<SettingSyncDataList> sync_changes);
 
  private:
-  // Sends the changes from |result| to sync if it's enabled.
+  // Sends the changes from `result` to sync if it's enabled.
   void SyncResultIfEnabled(const value_store::ValueStore::WriteResult& result);
 
   // Analyze the result returned by a call to the delegate, and take appropriate
@@ -92,33 +92,36 @@ class SyncableSettingsStorage : public value_store::ValueStore {
 
   // Sends all local settings to sync. This assumes that there are no settings
   // in sync yet.
-  // Returns any error when trying to sync, or absl::nullopt on success.
-  absl::optional<syncer::ModelError> SendLocalSettingsToSync(
-      std::unique_ptr<base::DictionaryValue> local_state);
+  // Returns any error when trying to sync, or std::nullopt on success.
+  std::optional<syncer::ModelError> SendLocalSettingsToSync(
+      base::Value::Dict local_state);
 
   // Overwrites local state with sync state.
-  // Returns any error when trying to sync, or absl::nullopt on success.
-  absl::optional<syncer::ModelError> OverwriteLocalSettingsWithSync(
-      std::unique_ptr<base::DictionaryValue> sync_state,
-      std::unique_ptr<base::DictionaryValue> local_state);
+  // Returns any error when trying to sync, or std::nullopt on success.
+  std::optional<syncer::ModelError> OverwriteLocalSettingsWithSync(
+      base::Value::Dict sync_state,
+      base::Value::Dict local_state);
 
   // Called when an Add/Update/Remove comes from sync.
-  syncer::SyncError OnSyncAdd(const std::string& key,
-                              std::unique_ptr<base::Value> new_value,
-                              value_store::ValueStoreChangeList* changes);
-  syncer::SyncError OnSyncUpdate(const std::string& key,
-                                 std::unique_ptr<base::Value> old_value,
-                                 std::unique_ptr<base::Value> new_value,
-                                 value_store::ValueStoreChangeList* changes);
-  syncer::SyncError OnSyncDelete(const std::string& key,
-                                 std::unique_ptr<base::Value> old_value,
-                                 value_store::ValueStoreChangeList* changes);
+  std::optional<syncer::ModelError> OnSyncAdd(
+      const std::string& key,
+      base::Value new_value,
+      value_store::ValueStoreChangeList* changes);
+  std::optional<syncer::ModelError> OnSyncUpdate(
+      const std::string& key,
+      base::Value old_value,
+      base::Value new_value,
+      value_store::ValueStoreChangeList* changes);
+  std::optional<syncer::ModelError> OnSyncDelete(
+      const std::string& key,
+      base::Value old_value,
+      value_store::ValueStoreChangeList* changes);
 
   // Observer to settings changes.
   SequenceBoundSettingsChangedCallback observer_;
 
   // Id of the extension these settings are for.
-  std::string const extension_id_;
+  ExtensionId const extension_id_;
 
   // Storage area to sync.
   const std::unique_ptr<value_store::ValueStore> delegate_;
@@ -126,7 +129,7 @@ class SyncableSettingsStorage : public value_store::ValueStore {
   // Object which sends changes to sync.
   std::unique_ptr<SettingsSyncProcessor> sync_processor_;
 
-  const syncer::ModelType sync_type_;
+  const syncer::DataType sync_type_;
   const syncer::SyncableService::StartSyncFlare flare_;
 };
 
