@@ -1,4 +1,4 @@
-// Copyright 2013 The Chromium Authors. All rights reserved.
+// Copyright 2013 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -7,31 +7,33 @@
 #include <memory>
 #include <utility>
 
-#include "base/bind.h"
 #include "base/command_line.h"
+#include "base/functional/bind.h"
+#include "base/functional/callback_helpers.h"
 #include "base/json/json_writer.h"
+#include "base/memory/raw_ptr.h"
 #include "base/strings/string_split.h"
 #include "base/strings/stringprintf.h"
 #include "base/test/scoped_command_line.h"
-#include "base/test/scoped_feature_list.h"
 #include "build/build_config.h"
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/extensions/api/webrtc_logging_private/webrtc_logging_private_api.h"
 #include "chrome/browser/extensions/extension_apitest.h"
-#include "chrome/browser/extensions/extension_function_test_utils.h"
 #include "chrome/browser/extensions/extension_tab_util.h"
 #include "chrome/browser/media/webrtc/webrtc_event_log_manager.h"
 #include "chrome/browser/media/webrtc/webrtc_event_log_manager_common.h"
 #include "chrome/browser/media/webrtc/webrtc_log_uploader.h"
-#include "chrome/browser/ui/tabs/tab_strip_model.h"
+#include "chrome/browser/profiles/profile.h"
 #include "chrome/common/chrome_features.h"
 #include "chrome/common/chrome_switches.h"
 #include "components/policy/core/browser/browser_policy_connector.h"
 #include "components/policy/core/common/mock_configuration_policy_provider.h"
 #include "components/policy/policy_constants.h"
-#include "content/public/browser/notification_service.h"
 #include "content/public/browser/render_view_host.h"
+#include "content/public/browser/web_contents.h"
+#include "content/public/test/browser_test.h"
 #include "content/public/test/test_utils.h"
+#include "extensions/browser/api_test_utils.h"
 #include "extensions/common/extension_builder.h"
 #include "net/test/embedded_test_server/embedded_test_server.h"
 #include "net/test/embedded_test_server/http_request.h"
@@ -65,7 +67,7 @@ using webrtc_event_logging::kStartRemoteLoggingFailureUnlimitedSizeDisallowed;
 using webrtc_event_logging::kWebRtcEventLogManagerUnlimitedFileSize;
 using webrtc_event_logging::WebRtcEventLogManager;
 
-namespace utils = extension_function_test_utils;
+namespace utils = extensions::api_test_utils;
 
 namespace {
 
@@ -78,31 +80,35 @@ constexpr int kWebAppId = 15;  // Arbitrary.
 constexpr char kTestUploadUrlPath[] = "/upload_webrtc_log";
 constexpr char kTestReportId[] = "report_id";
 
-std::string ParamsToString(const base::ListValue& parameters) {
+std::string ParamsToString(const base::Value::List& parameters) {
   std::string parameter_string;
   EXPECT_TRUE(base::JSONWriter::Write(parameters, &parameter_string));
   return parameter_string;
 }
 
-void InitializeTestMetaData(base::ListValue* parameters) {
-  std::unique_ptr<base::DictionaryValue> meta_data_entry(
-      new base::DictionaryValue());
-  meta_data_entry->SetString("key", kTestLoggingSessionIdKey);
-  meta_data_entry->SetString("value", kTestLoggingSessionIdValue);
-  std::unique_ptr<base::ListValue> meta_data(new base::ListValue());
-  meta_data->Append(std::move(meta_data_entry));
-  meta_data_entry.reset(new base::DictionaryValue());
-  meta_data_entry->SetString("key", "url");
-  meta_data_entry->SetString("value", kTestLoggingUrl);
-  meta_data->Append(std::move(meta_data_entry));
-  parameters->Append(std::move(meta_data));
+void InitializeTestMetaData(base::Value::List& parameters) {
+  base::Value::Dict meta_data_entry;
+  meta_data_entry.Set("key", kTestLoggingSessionIdKey);
+  meta_data_entry.Set("value", kTestLoggingSessionIdValue);
+  base::Value::List meta_data;
+  meta_data.Append(std::move(meta_data_entry));
+  base::Value::Dict meta_data_entry2;
+  meta_data_entry2.Set("key", "url");
+  meta_data_entry2.Set("value", kTestLoggingUrl);
+  meta_data.Append(std::move(meta_data_entry2));
+  parameters.Append(std::move(meta_data));
 }
 
 class WebrtcLoggingPrivateApiTest : public extensions::ExtensionApiTest {
  protected:
-  void SetUp() override {
-    extensions::ExtensionApiTest::SetUp();
+  void SetUpOnMainThread() override {
+    ExtensionApiTest::SetUpOnMainThread();
     extension_ = extensions::ExtensionBuilder("Test").Build();
+#if BUILDFLAG(IS_ANDROID)
+    // Android's default blank page doesn't have a renderer process,so navigate
+    // to a URL that has one. Peer connection tests need a real process ID.
+    ASSERT_TRUE(NavigateToURL(GURL("chrome://version")));
+#endif
   }
 
   template<typename T>
@@ -113,11 +119,16 @@ class WebrtcLoggingPrivateApiTest : public extensions::ExtensionApiTest {
     return function;
   }
 
-  // Overriding can use incognito session instead, etc.
-  virtual Browser* GetBrowser() { return browser(); }
+  // Override to use an alternate web contents. GetActiveWebContents() returns
+  // a web contents from the test's initial browser window, which may not be
+  // the only window in an incognito test.
+  virtual content::WebContents* GetWebContents() {
+    return GetActiveWebContents();
+  }
 
-  content::WebContents* web_contents() {
-    return GetBrowser()->tab_strip_model()->GetActiveWebContents();
+  // Convenience method to return the Profile from GetWebContents().
+  Profile* GetProfile() {
+    return Profile::FromBrowserContext(GetWebContents()->GetBrowserContext());
   }
 
   bool SetupTestServerLogUploading() {
@@ -144,48 +155,50 @@ class WebrtcLoggingPrivateApiTest : public extensions::ExtensionApiTest {
     return nullptr;
   }
 
-  void AppendTabIdAndUrl(base::ListValue* parameters) {
-    std::unique_ptr<base::DictionaryValue> request_info(
-        new base::DictionaryValue());
-    request_info->SetInteger(
-        "tabId", extensions::ExtensionTabUtil::GetTabId(web_contents()));
-    parameters->Append(std::move(request_info));
-    parameters->AppendString(web_contents()->GetURL().GetOrigin().spec());
+  void AppendTabIdAndUrl(base::Value::List& parameters) {
+    base::Value::Dict request_info;
+    request_info.Set("tabId",
+                     extensions::ExtensionTabUtil::GetTabId(GetWebContents()));
+    parameters.Append(std::move(request_info));
+    parameters.Append(GetWebContents()
+                          ->GetLastCommittedURL()
+                          .DeprecatedGetOriginAsURL()
+                          .spec());
   }
 
   // This function implicitly expects the function to succeed (test failure
   // initiated otherwise).
   // Returns the value (NOT whether it had succeeded or failed).
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   template <typename Function>
-  std::unique_ptr<base::Value> RunFunction(const base::ListValue& parameters) {
+  std::optional<base::Value> RunFunction(const base::Value::List& parameters) {
     scoped_refptr<Function> function(CreateFunction<Function>());
-    std::unique_ptr<base::Value> result(utils::RunFunctionAndReturnSingleResult(
-        function.get(), ParamsToString(parameters), GetBrowser()));
+    std::optional<base::Value> result = utils::RunFunctionAndReturnSingleResult(
+        function.get(), ParamsToString(parameters), GetProfile());
     return result;
   }
 
   // This function implicitly expects the function to succeed (test failure
   // initiated otherwise).
   // Returns the value (NOT whether it had succeeded or failed).
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   template <typename Function>
-  std::unique_ptr<base::Value> RunNoArgsFunction() {
-    base::ListValue params;
-    AppendTabIdAndUrl(&params);
+  std::optional<base::Value> RunNoArgsFunction() {
+    base::Value::List params;
+    AppendTabIdAndUrl(params);
     scoped_refptr<Function> function(CreateFunction<Function>());
-    std::unique_ptr<base::Value> result(utils::RunFunctionAndReturnSingleResult(
-        function.get(), ParamsToString(params), GetBrowser()));
+    std::optional<base::Value> result = utils::RunFunctionAndReturnSingleResult(
+        function.get(), ParamsToString(params), GetProfile());
     return result;
   }
 
   template <typename Function>
-  void RunFunctionAndExpectError(const base::ListValue& parameters,
+  void RunFunctionAndExpectError(const base::Value::List& parameters,
                                  const std::string& expected_error) {
     DCHECK(!expected_error.empty());
     scoped_refptr<Function> function(CreateFunction<Function>());
     const std::string error_message = utils::RunFunctionAndReturnError(
-        function.get(), ParamsToString(parameters), GetBrowser());
+        function.get(), ParamsToString(parameters), GetProfile());
     EXPECT_EQ(error_message, expected_error);
   }
 
@@ -193,50 +206,51 @@ class WebrtcLoggingPrivateApiTest : public extensions::ExtensionApiTest {
   // initiated otherwise).
   // Returns whether the function that was run returned a value, or avoided
   // returning a value, according to expectation.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   bool StartLogging() {
     constexpr bool value_expected = false;
-    std::unique_ptr<base::Value> value =
+    std::optional<base::Value> value =
         RunNoArgsFunction<WebrtcLoggingPrivateStartFunction>();
-    return value_expected == (value != nullptr);
+    return value_expected == value.has_value();
   }
 
   // This function implicitly expects the function to succeed (test failure
   // initiated otherwise).
   // Returns whether the function that was run returned a value, or avoided
   // returning a value, according to expectation.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   bool StopLogging() {
     constexpr bool value_expected = false;
-    std::unique_ptr<base::Value> value =
+    std::optional<base::Value> value =
         RunNoArgsFunction<WebrtcLoggingPrivateStopFunction>();
-    return value_expected == (value != nullptr);
+    return value_expected == value.has_value();
   }
 
   // This function implicitly expects the function to succeed (test failure
   // initiated otherwise).
   // Returns whether the function that was run returned a value, or avoided
   // returning a value, according to expectation.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   bool DiscardLog() {
     constexpr bool value_expected = false;
-    std::unique_ptr<base::Value> value =
+    std::optional<base::Value> value =
         RunNoArgsFunction<WebrtcLoggingPrivateDiscardFunction>();
-    return value_expected == (value != nullptr);
+    return value_expected == value.has_value();
   }
 
   // This function implicitly expects the function to succeed (test failure
   // initiated otherwise).
   // Returns whether the function that was run returned a value, or avoided
   // returning a value, according to expectation.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   bool UploadLog(std::string* report_id) {
     constexpr bool value_expected = true;
-    std::unique_ptr<base::Value> value =
+    std::optional<base::Value> value =
         RunNoArgsFunction<WebrtcLoggingPrivateUploadFunction>();
-    const bool value_returned = value != nullptr;
-    if (value_returned)
-      *report_id = *value->FindStringKey("reportId");
+    const bool value_returned = value.has_value();
+    if (value_returned) {
+      *report_id = *value->GetDict().FindString("reportId");
+    }
     return value_expected == value_returned;
   }
 
@@ -244,76 +258,77 @@ class WebrtcLoggingPrivateApiTest : public extensions::ExtensionApiTest {
   // initiated otherwise).
   // Returns whether the function that was run returned a value, or avoided
   // returning a value, according to expectation.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
-  bool SetMetaData(const base::ListValue& data) {
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
+  bool SetMetaData(const base::Value::List& data) {
     constexpr bool value_expected = false;
-    std::unique_ptr<base::Value> value =
+    std::optional<base::Value> value =
         RunFunction<WebrtcLoggingPrivateSetMetaDataFunction>(data);
-    return value_expected == (value != nullptr);
+    return value_expected == value.has_value();
   }
 
   // This function implicitly expects the function to succeed (test failure
   // initiated otherwise).
   // Returns whether the function that was run returned a value, or avoided
   // returning a value, according to expectation.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   bool StartRtpDump(bool incoming, bool outgoing) {
-    base::ListValue params;
-    AppendTabIdAndUrl(&params);
-    params.AppendBoolean(incoming);
-    params.AppendBoolean(outgoing);
+    base::Value::List params;
+    AppendTabIdAndUrl(params);
+    params.Append(incoming);
+    params.Append(outgoing);
     constexpr bool value_expected = false;
-    std::unique_ptr<base::Value> value =
+    std::optional<base::Value> value =
         RunFunction<WebrtcLoggingPrivateStartRtpDumpFunction>(params);
-    return value_expected == (value != nullptr);
+    return value_expected == value.has_value();
   }
 
   // This function implicitly expects the function to succeed (test failure
   // initiated otherwise).
   // Returns whether the function that was run returned a value, or avoided
   // returning a value, according to expectation.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   bool StopRtpDump(bool incoming, bool outgoing) {
-    base::ListValue params;
-    AppendTabIdAndUrl(&params);
-    params.AppendBoolean(incoming);
-    params.AppendBoolean(outgoing);
+    base::Value::List params;
+    AppendTabIdAndUrl(params);
+    params.Append(incoming);
+    params.Append(outgoing);
     constexpr bool value_expected = false;
-    std::unique_ptr<base::Value> value =
+    std::optional<base::Value> value =
         RunFunction<WebrtcLoggingPrivateStopRtpDumpFunction>(params);
-    return value_expected == (value != nullptr);
+    return value_expected == value.has_value();
   }
 
   // This function implicitly expects the function to succeed (test failure
   // initiated otherwise).
   // Returns whether the function that was run returned a value, or avoided
   // returning a value, according to expectation.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   bool StoreLog(const std::string& log_id) {
-    base::ListValue params;
-    AppendTabIdAndUrl(&params);
-    params.AppendString(log_id);
+    base::Value::List params;
+    AppendTabIdAndUrl(params);
+    params.Append(log_id);
     constexpr bool value_expected = false;
-    std::unique_ptr<base::Value> value =
+    std::optional<base::Value> value =
         RunFunction<WebrtcLoggingPrivateStoreFunction>(params);
-    return value_expected == (value != nullptr);
+    return value_expected == value.has_value();
   }
 
   // This function implicitly expects the function to succeed (test failure
   // initiated otherwise).
   // Returns whether the function that was run returned a value, or avoided
   // returning a value, according to expectation.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   bool UploadStoredLog(const std::string& log_id, std::string* report_id) {
-    base::ListValue params;
-    AppendTabIdAndUrl(&params);
-    params.AppendString(log_id);
+    base::Value::List params;
+    AppendTabIdAndUrl(params);
+    params.Append(log_id);
     constexpr bool value_expected = true;
-    std::unique_ptr<base::Value> value =
+    std::optional<base::Value> value =
         RunFunction<WebrtcLoggingPrivateUploadStoredFunction>(params);
-    const bool value_returned = value != nullptr;
-    if (value_returned)
-      *report_id = *value->FindStringKey("reportId");
+    const bool value_returned = value.has_value();
+    if (value_returned) {
+      *report_id = *value->GetDict().FindString("reportId");
+    }
     return value_expected == value_returned;
   }
 
@@ -321,37 +336,37 @@ class WebrtcLoggingPrivateApiTest : public extensions::ExtensionApiTest {
   // initiated otherwise).
   // Returns whether the function that was run returned a value, or avoided
   // returning a value, according to expectation.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   bool StartAudioDebugRecordings(int seconds) {
-    base::ListValue params;
-    AppendTabIdAndUrl(&params);
-    params.AppendInteger(seconds);
+    base::Value::List params;
+    AppendTabIdAndUrl(params);
+    params.Append(seconds);
     constexpr bool value_expected = true;
-    std::unique_ptr<base::Value> value =
+    std::optional<base::Value> value =
         RunFunction<WebrtcLoggingPrivateStartAudioDebugRecordingsFunction>(
             params);
-    return value_expected == (value != nullptr);
+    return value_expected == value.has_value();
   }
 
   // This function implicitly expects the function to succeed (test failure
   // initiated otherwise).
   // Returns whether the function that was run returned a value, or avoided
   // returning a value, according to expectation.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   bool StopAudioDebugRecordings() {
-    base::ListValue params;
-    AppendTabIdAndUrl(&params);
+    base::Value::List params;
+    AppendTabIdAndUrl(params);
     constexpr bool value_expected = true;
-    std::unique_ptr<base::Value> value =
+    std::optional<base::Value> value =
         RunFunction<WebrtcLoggingPrivateStopAudioDebugRecordingsFunction>(
             params);
-    return value_expected == (value != nullptr);
+    return value_expected == value.has_value();
   }
 
   // This function expects the function to succeed or fail according to
   // |expect_success| (test failure initiated otherwise). It also implicitly
   // expects that no value would be returned.
-  // TODO(crbug.com/829419): Return success/failure of the executed function.
+  // TODO(crbug.com/41381060): Return success/failure of the executed function.
   void StartEventLogging(const std::string& session_id,
                          int max_log_size_bytes,
                          int output_period_ms,
@@ -360,32 +375,30 @@ class WebrtcLoggingPrivateApiTest : public extensions::ExtensionApiTest {
                          const std::string& expected_error = std::string()) {
     DCHECK_EQ(expect_success, expected_error.empty());
 
-    base::ListValue params;
-    AppendTabIdAndUrl(&params);
-    params.AppendString(session_id);
-    params.AppendInteger(max_log_size_bytes);
-    params.AppendInteger(output_period_ms);
-    params.AppendInteger(web_app_id);
+    base::Value::List params;
+    AppendTabIdAndUrl(params);
+    params.Append(session_id);
+    params.Append(max_log_size_bytes);
+    params.Append(output_period_ms);
+    params.Append(web_app_id);
 
     if (expect_success) {
       scoped_refptr<WebrtcLoggingPrivateStartEventLoggingFunction> function(
           CreateFunction<WebrtcLoggingPrivateStartEventLoggingFunction>());
 
-      std::unique_ptr<base::Value> result(
+      std::optional<base::Value> result =
           utils::RunFunctionAndReturnSingleResult(
-              function.get(), ParamsToString(params), GetBrowser()));
+              function.get(), ParamsToString(params), GetProfile());
 
       ASSERT_TRUE(result);
       ASSERT_TRUE(result->is_dict());
-      ASSERT_EQ(result->DictSize(), 1u);
+      const base::Value::Dict& result_dict = result->GetDict();
+      ASSERT_EQ(result_dict.size(), 1u);
 
-      const base::Value* val =
-          result->FindKeyOfType("logId", base::Value::Type::STRING);
-      ASSERT_TRUE(val);
-
-      const std::string& log_id = val->GetString();
-      EXPECT_EQ(log_id.size(), 32u);
-      EXPECT_EQ(log_id.find_first_not_of("0123456789ABCDEF"),
+      const std::string* log_id = result_dict.FindString("logId");
+      ASSERT_TRUE(log_id);
+      EXPECT_EQ(log_id->size(), 32u);
+      EXPECT_EQ(log_id->find_first_not_of("0123456789ABCDEF"),
                 std::string::npos);
     } else {
       RunFunctionAndExpectError<WebrtcLoggingPrivateStartEventLoggingFunction>(
@@ -393,22 +406,35 @@ class WebrtcLoggingPrivateApiTest : public extensions::ExtensionApiTest {
     }
   }
 
-  void SetUpPeerConnection(const std::string& session_id = "") {
+  // Sets up a simulated WebRTC peer connection. Registers the peer connection
+  // with the WebRtcEventLogManager using the primary main frame's
+  // RenderFrameHost and process ID. If a non-empty `session_id` is provided,
+  // it also associates this session ID with the newly added peer connection.
+  // Returns true on success.
+  bool SetUpPeerConnection(const std::string& session_id = "") {
     auto* manager = WebRtcEventLogManager::GetInstance();
-    auto* rph = web_contents()->GetRenderViewHost()->GetProcess();
 
-    const int render_process_id = rph->GetID();
+    content::RenderFrameHost* render_frame_host =
+        GetWebContents()->GetPrimaryMainFrame();
+    const content::GlobalRenderFrameHostId frame_id =
+        render_frame_host->GetGlobalId();
+    const base::Process& process =
+        render_frame_host->GetProcess()->GetProcess();
+    if (!process.IsValid()) {
+      return false;
+    }
+    const base::ProcessId pid = process.Pid();
     const int lid = 0;
 
-    manager->PeerConnectionAdded(render_process_id, lid, base::NullCallback());
+    manager->OnPeerConnectionAdded(frame_id, lid, pid, /*url=*/std::string(),
+                                   /*rtc_configuration=*/std::string());
 
     if (!session_id.empty()) {
-      manager->PeerConnectionSessionIdSet(render_process_id, lid, session_id,
-                                          base::NullCallback());
+      manager->OnPeerConnectionSessionIdSet(frame_id, lid, session_id);
     }
+    return true;
   }
 
-  base::test::ScopedFeatureList scoped_feature_list_;
   base::test::ScopedCommandLine scoped_command_line_;
   scoped_refptr<const Extension> extension_;
 
@@ -461,9 +487,9 @@ IN_PROC_BROWSER_TEST_F(WebrtcLoggingPrivateApiTest, TestStartStopDiscard) {
 IN_PROC_BROWSER_TEST_F(WebrtcLoggingPrivateApiTest, TestStartStopUpload) {
   ASSERT_TRUE(SetupTestServerLogUploading());
 
-  base::ListValue parameters;
-  AppendTabIdAndUrl(&parameters);
-  InitializeTestMetaData(&parameters);
+  base::Value::List parameters;
+  AppendTabIdAndUrl(parameters);
+  InitializeTestMetaData(parameters);
 
   std::string report_id;
 
@@ -571,13 +597,13 @@ IN_PROC_BROWSER_TEST_F(WebrtcLoggingPrivateApiTest, TestStartStopRtpDump) {
 // Tests trying to store a log when a log is not being captured.
 // We should get a failure callback in this case.
 IN_PROC_BROWSER_TEST_F(WebrtcLoggingPrivateApiTest, TestStoreWithoutLog) {
-  base::ListValue parameters;
-  AppendTabIdAndUrl(&parameters);
-  parameters.AppendString("MyLogId");
+  base::Value::List parameters;
+  AppendTabIdAndUrl(parameters);
+  parameters.Append("MyLogId");
   scoped_refptr<WebrtcLoggingPrivateStoreFunction> store(
       CreateFunction<WebrtcLoggingPrivateStoreFunction>());
   const std::string error = utils::RunFunctionAndReturnError(
-      store.get(), ParamsToString(parameters), GetBrowser());
+      store.get(), ParamsToString(parameters), GetProfile());
   ASSERT_FALSE(error.empty());
 }
 
@@ -628,9 +654,9 @@ IN_PROC_BROWSER_TEST_F(WebrtcLoggingPrivateApiTest,
   static const char kLogId[] = "TestStartStopStoreAndUploadWithRtp";
   ASSERT_TRUE(StartLogging());
 
-  base::ListValue parameters;
-  AppendTabIdAndUrl(&parameters);
-  InitializeTestMetaData(&parameters);
+  base::Value::List parameters;
+  AppendTabIdAndUrl(parameters);
+  InitializeTestMetaData(parameters);
   SetMetaData(parameters);
 
   ASSERT_TRUE(StopLogging());
@@ -662,8 +688,6 @@ IN_PROC_BROWSER_TEST_F(WebrtcLoggingPrivateApiTest,
   ASSERT_TRUE(StartAudioDebugRecordings(1));
 }
 
-#if !defined(OS_ANDROID)
-
 // Fixture for various tests over StartEventLogging. Intended to be sub-classed
 // to test different scenarios.
 class WebrtcLoggingPrivateApiStartEventLoggingTestBase
@@ -672,29 +696,10 @@ class WebrtcLoggingPrivateApiStartEventLoggingTestBase
   ~WebrtcLoggingPrivateApiStartEventLoggingTestBase() override = default;
 
  protected:
-  void SetUp() override {
-    SetUpFeatures();
-    WebrtcLoggingPrivateApiTest::SetUp();
-  }
-
-  void SetUpFeatures() {
-    std::vector<base::Feature> enabled;
-    std::vector<base::Feature> disabled;
-
-    if (WebRtcEventLogCollectionFeature()) {
-      enabled.push_back(features::kWebRtcRemoteEventLog);
-    } else {
-      disabled.push_back(features::kWebRtcRemoteEventLog);
-    }
-
-    enabled.push_back(features::kWebRtcRemoteEventLogGzipped);
-
-    scoped_feature_list_.InitWithFeatures(enabled, disabled);
-  }
-
   void SetUpInProcessBrowserTestFixture() override {
-    EXPECT_CALL(provider_, IsInitializationComplete(testing::_))
-        .WillRepeatedly(testing::Return(true));
+    provider_.SetDefaultReturns(
+        /*is_initialization_complete_return=*/true,
+        /*is_first_policy_load_complete_return=*/true);
 
     policy::BrowserPolicyConnector::SetPolicyProviderForTesting(&provider_);
     policy::PolicyMap values;
@@ -702,45 +707,37 @@ class WebrtcLoggingPrivateApiStartEventLoggingTestBase
     values.Set(policy::key::kWebRtcEventLogCollectionAllowed,
                policy::POLICY_LEVEL_MANDATORY, policy::POLICY_SCOPE_USER,
                policy::POLICY_SOURCE_ENTERPRISE_DEFAULT,
-               std::make_unique<base::Value>(WebRtcEventLogCollectionPolicy()),
-               nullptr);
+               base::Value(WebRtcEventLogCollectionPolicy()), nullptr);
 
     provider_.UpdateChromePolicy(values);
   }
 
-  // Whether the test should have WebRTC remote-bound event logging generally
-  // enabled (default behavior), or disabled (Finch kill-switch engaged).
-  virtual bool WebRtcEventLogCollectionFeature() const = 0;
-
   // Whether the test should simulate running on a user profile which
   // has the kWebRtcEventLogCollectionAllowed policy configured or not.
   virtual bool WebRtcEventLogCollectionPolicy() const = 0;
 
  private:
-  policy::MockConfigurationPolicyProvider provider_;
+  testing::NiceMock<policy::MockConfigurationPolicyProvider> provider_;
 };
 
-// Test StartEventLogging's behavior when the feature is active (kill-switch
-// from Finch *not* engaged, working in a profile where the policy is
-// configured).
-class WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled
+// Test StartEventLogging's behavior when the feature is active (non-Android,
+// working in a profile where the policy is configured).
+class WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled
     : public WebrtcLoggingPrivateApiStartEventLoggingTestBase,
       public testing::WithParamInterface<bool> {
  public:
-  ~WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled()
-      override = default;
-
-  bool WebRtcEventLogCollectionFeature() const override { return true; }
+  ~WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled() override =
+      default;
 
   bool WebRtcEventLogCollectionPolicy() const override { return true; }
 };
 
 // Also covers StartEventLoggingForLegalWebAppIdSucceeds scenario.
 IN_PROC_BROWSER_TEST_P(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForKnownPeerConnectionSucceeds) {
   const std::string session_id = "id";
-  SetUpPeerConnection(session_id);
+  ASSERT_TRUE(SetUpPeerConnection(session_id));
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
   constexpr bool expect_success = true;
   const int output_period_ms = GetParam() ? kMaxOutputPeriodMs : 0;
@@ -749,10 +746,10 @@ IN_PROC_BROWSER_TEST_P(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingWithUnlimitedSizeFails) {
   const std::string session_id = "id";
-  SetUpPeerConnection(session_id);
+  ASSERT_TRUE(SetUpPeerConnection(session_id));
   const int max_size_bytes = kWebRtcEventLogManagerUnlimitedFileSize;
   constexpr bool expect_success = false;
   const std::string error_message =
@@ -762,10 +759,10 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingWithTooSmallMaxSize) {
   const std::string session_id = "id";
-  SetUpPeerConnection(session_id);
+  ASSERT_TRUE(SetUpPeerConnection(session_id));
   const int max_size_bytes = 1;
   constexpr bool expect_success = false;
   const std::string error_message = kStartRemoteLoggingFailureMaxSizeTooSmall;
@@ -774,10 +771,10 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingWithExcessiveMaxSizeFails) {
   const std::string session_id = "id";
-  SetUpPeerConnection(session_id);
+  ASSERT_TRUE(SetUpPeerConnection(session_id));
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes + 1;
   constexpr bool expect_success = false;
   const std::string error_message = kStartRemoteLoggingFailureMaxSizeTooLarge;
@@ -786,10 +783,10 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingWithTooLargeOutputPeriodMsFails) {
   const std::string session_id = "id";
-  SetUpPeerConnection(session_id);
+  ASSERT_TRUE(SetUpPeerConnection(session_id));
   const int output_period_ms = kMaxOutputPeriodMs + 1;
   constexpr bool expect_success = false;
   const std::string error_message =
@@ -799,9 +796,9 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForNeverAddedPeerConnectionFails) {
-  // Note that manager->PeerConnectionAdded() is not called.
+  // Note that manager->OnPeerConnectionAdded() is not called.
   const std::string session_id = "id";
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
   constexpr bool expect_success = false;
@@ -812,12 +809,12 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForWrongSessionIdFails) {
   const std::string session_id_1 = "id1";
   const std::string session_id_2 = "id2";
 
-  SetUpPeerConnection(session_id_1);
+  ASSERT_TRUE(SetUpPeerConnection(session_id_1));
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
   constexpr bool expect_success = false;
   const std::string error_message =
@@ -827,9 +824,9 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingIfSessionIdNeverSetFails) {
-  SetUpPeerConnection();  // Note lack of session ID.
+  ASSERT_TRUE(SetUpPeerConnection());  // Note lack of session ID.
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
   constexpr bool expect_success = false;
   const std::string error_message =
@@ -839,9 +836,9 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingIfSessionIdNeverSetFailsForEmptySessionId) {
-  SetUpPeerConnection();  // Note lack of session ID.
+  ASSERT_TRUE(SetUpPeerConnection());  // Note lack of session ID.
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
   constexpr bool expect_success = false;
   const std::string error_message =
@@ -851,9 +848,9 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLogginWithEmptySessionIdFails) {
-  SetUpPeerConnection("session_id");
+  ASSERT_TRUE(SetUpPeerConnection("session_id"));
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
   constexpr bool expect_success = false;
   const std::string error_message =
@@ -863,10 +860,10 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForAlreadyLoggedPeerConnectionFails) {
   const std::string session_id = "id";
-  SetUpPeerConnection(session_id);
+  ASSERT_TRUE(SetUpPeerConnection(session_id));
 
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
 
@@ -886,10 +883,10 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForTooLowWebAppIdFails) {
   const std::string session_id = "id";
-  SetUpPeerConnection(session_id);
+  ASSERT_TRUE(SetUpPeerConnection(session_id));
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
   const size_t web_app_id =
       webrtc_event_logging::kMinWebRtcEventLogWebAppId - 1;
@@ -902,10 +899,10 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 IN_PROC_BROWSER_TEST_F(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     StartEventLoggingForTooHighWebAppIdFails) {
   const std::string session_id = "id";
-  SetUpPeerConnection(session_id);
+  ASSERT_TRUE(SetUpPeerConnection(session_id));
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
   const size_t web_app_id =
       webrtc_event_logging::kMaxWebRtcEventLogWebAppId + 1;
@@ -919,50 +916,43 @@ IN_PROC_BROWSER_TEST_F(
 
 INSTANTIATE_TEST_SUITE_P(
     _,
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureAndPolicyEnabled,
+    WebrtcLoggingPrivateApiStartEventLoggingTestPolicyEnabled,
     ::testing::Bool());
 
-// Testing with either the feature or the policy disabled (not both).
-class WebrtcLoggingPrivateApiStartEventLoggingTestFeatureOrPolicyDisabled
+// Testing with the policy enabled/disabled.
+class WebrtcLoggingPrivateApiStartEventLoggingTestPolicy
     : public WebrtcLoggingPrivateApiStartEventLoggingTestBase,
       public ::testing::WithParamInterface<bool> {
  public:
-  WebrtcLoggingPrivateApiStartEventLoggingTestFeatureOrPolicyDisabled()
-      : feature_enabled_(GetParam()), policy_enabled_(!feature_enabled_) {}
+  WebrtcLoggingPrivateApiStartEventLoggingTestPolicy()
+      : policy_enabled_(GetParam()) {}
 
-  ~WebrtcLoggingPrivateApiStartEventLoggingTestFeatureOrPolicyDisabled()
-      override = default;
+  ~WebrtcLoggingPrivateApiStartEventLoggingTestPolicy() override = default;
 
  protected:
-  bool WebRtcEventLogCollectionFeature() const override {
-    return feature_enabled_;
-  }
-
   bool WebRtcEventLogCollectionPolicy() const override {
     return policy_enabled_;
   }
 
  private:
-  const bool feature_enabled_;
   const bool policy_enabled_;
 };
 
-IN_PROC_BROWSER_TEST_P(
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureOrPolicyDisabled,
-    StartEventLoggingFails) {
+IN_PROC_BROWSER_TEST_P(WebrtcLoggingPrivateApiStartEventLoggingTestPolicy,
+                       StartEventLogging) {
   const std::string session_id = "id";
   SetUpPeerConnection(session_id);
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
-  constexpr bool expect_success = false;
-  const std::string error_message = kStartRemoteLoggingFailureFeatureDisabled;
+  bool expect_success = WebRtcEventLogCollectionPolicy();
+  const std::string error_message =
+      expect_success ? "" : kStartRemoteLoggingFailureFeatureDisabled;
   StartEventLogging(session_id, max_size_bytes, 0, kWebAppId, expect_success,
                     error_message);
 }
 
-INSTANTIATE_TEST_SUITE_P(
-    FeatureEnabled,
-    WebrtcLoggingPrivateApiStartEventLoggingTestFeatureOrPolicyDisabled,
-    ::testing::Bool());
+INSTANTIATE_TEST_SUITE_P(PolicyEnabled,
+                         WebrtcLoggingPrivateApiStartEventLoggingTestPolicy,
+                         ::testing::Bool());
 
 // Make sure that, even if both the feature and the policy enable remote-bound
 // event logging, it will be blocked for incognito sessions.
@@ -973,31 +963,38 @@ class WebrtcLoggingPrivateApiStartEventLoggingTestInIncognitoMode
       default;
 
  protected:
-  Browser* GetBrowser() override {
-    if (!browser_) {
-      browser_ = CreateIncognitoBrowser();
-    }
-    return browser_;
+  void SetUpOnMainThread() override {
+    WebrtcLoggingPrivateApiStartEventLoggingTestBase::SetUpOnMainThread();
+    // Android requires opening a new tab to create an incognito profile, and it
+    // doesn't hurt on other platforms. Must occur before SetUpPeerConnection()
+    // is called in the test because that uses GetWebContents().
+    incognito_web_contents_ =
+        PlatformOpenURLOffTheRecord(profile(), GURL("chrome://version"));
   }
 
-  bool WebRtcEventLogCollectionFeature() const override { return true; }
+  void TearDownOnMainThread() override {
+    incognito_web_contents_ = nullptr;
+    WebrtcLoggingPrivateApiStartEventLoggingTestBase::TearDownOnMainThread();
+  }
+
+  content::WebContents* GetWebContents() override {
+    return incognito_web_contents_;
+  }
 
   bool WebRtcEventLogCollectionPolicy() const override { return true; }
 
  private:
-  Browser* browser_{nullptr};  // Does not own the object.
+  raw_ptr<content::WebContents> incognito_web_contents_ = nullptr;
 };
 
 IN_PROC_BROWSER_TEST_F(
     WebrtcLoggingPrivateApiStartEventLoggingTestInIncognitoMode,
     StartEventLoggingFails) {
   const std::string session_id = "id";
-  SetUpPeerConnection(session_id);
+  ASSERT_TRUE(SetUpPeerConnection(session_id));
   const int max_size_bytes = kMaxRemoteLogFileSizeBytes;
   constexpr bool expect_success = false;
   const std::string error_message = kStartRemoteLoggingFailureFeatureDisabled;
   StartEventLogging(session_id, max_size_bytes, 0, kWebAppId, expect_success,
                     error_message);
 }
-
-#endif  // !defined(OS_ANDROID)
