@@ -4,10 +4,10 @@
 
 #include "chrome/browser/media/webrtc/desktop_media_picker.h"
 
-#if BUILDFLAG(IS_DESKTOP_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
 BASE_FEATURE(kAndroidMediaPicker,
              "AndroidMediaPicker",
-             base::FEATURE_ENABLED_BY_DEFAULT);
+             base::FEATURE_DISABLED_BY_DEFAULT);
 #endif
 
 DesktopMediaPicker::Params::Params(RequestSource request_source)
