@@ -11,10 +11,12 @@
 
 #include "base/memory/raw_ptr.h"
 #include "base/memory/weak_ptr.h"
+#include "base/types/expected.h"
 #include "chrome/browser/media/webrtc/desktop_media_list.h"
 #include "chrome/browser/media/webrtc/desktop_media_picker.h"
 #include "content/public/browser/desktop_media_id.h"
 #include "content/public/browser/web_contents_observer.h"
+#include "third_party/blink/public/mojom/mediastream/media_stream.mojom.h"
 #include "ui/base/ui_base_types.h"
 
 class DesktopMediaList;
@@ -89,8 +91,10 @@ class DesktopMediaPickerController : private content::WebContentsObserver {
   // This function is responsible to call |done_callback_| and after running the
   // callback |this| might be destroyed. Do **not** access fields after calling
   // this function.
-  void OnPickerDialogResults(const std::string& err,
-                             content::DesktopMediaID source);
+  void OnPickerDialogResults(
+      const std::string& err,
+      base::expected<content::DesktopMediaID,
+                     blink::mojom::MediaStreamRequestResult> result);
 
   Params params_;
   DoneCallback done_callback_;
