@@ -28,8 +28,8 @@
 #include "components/content_settings/browser/page_specific_content_settings.h"
 #include "components/content_settings/core/browser/host_content_settings_map.h"
 #include "components/content_settings/core/common/features.h"
+#include "components/permissions/content_setting_permission_context_base.h"
 #include "components/permissions/contexts/camera_pan_tilt_zoom_permission_context.h"
-#include "components/permissions/permission_context_base.h"
 #include "components/permissions/permission_manager.h"
 #include "components/permissions/permission_request.h"
 #include "components/permissions/permission_request_manager.h"
@@ -46,15 +46,14 @@
 #include "third_party/blink/public/common/mediastream/media_stream_request.h"
 #include "third_party/blink/public/mojom/mediastream/media_stream.mojom.h"
 
-using content_settings::PageSpecificContentSettings;
+using ::blink::mojom::MediaStreamRequestResult;
+using ::content_settings::PageSpecificContentSettings;
 
 class MediaStreamDevicesControllerTest : public WebRtcTestBase {
  public:
   MediaStreamDevicesControllerTest()
       : example_audio_id_("fake_audio_dev"),
-        example_video_id_("fake_video_dev"),
-        media_stream_result_(
-            blink::mojom::MediaStreamRequestResult::NUM_MEDIA_REQUEST_RESULTS) {
+        example_video_id_("fake_video_dev") {
     // `kLeftHandSideActivityIndicators` should be disabled as it changes the UI
     // of the camera/mic activity indicator. The new UI will be tested
     // separately.
@@ -64,7 +63,7 @@ class MediaStreamDevicesControllerTest : public WebRtcTestBase {
 
   void OnMediaStreamResponse(
       const blink::mojom::StreamDevicesSet& stream_devices_set,
-      blink::mojom::MediaStreamRequestResult result,
+      MediaStreamRequestResult result,
       std::unique_ptr<content::MediaStreamUI> ui) {
     blink::MediaStreamDevices devices_list =
         blink::ToMediaStreamDevicesList(stream_devices_set);
@@ -88,7 +87,7 @@ class MediaStreamDevicesControllerTest : public WebRtcTestBase {
   const std::string& example_audio_id() const { return example_audio_id_; }
   const std::string& example_video_id() const { return example_video_id_; }
 
-  blink::mojom::MediaStreamRequestResult media_stream_result() const {
+  std::optional<MediaStreamRequestResult> media_stream_result() const {
     return media_stream_result_;
   }
 
@@ -218,7 +217,7 @@ class MediaStreamDevicesControllerTest : public WebRtcTestBase {
     return prompt_factory_.get();
   }
 
-  void VerifyResultState(blink::mojom::MediaStreamRequestResult result,
+  void VerifyResultState(std::optional<MediaStreamRequestResult> result,
                          bool has_audio,
                          bool has_video) {
     EXPECT_EQ(result, media_stream_result());
@@ -246,8 +245,7 @@ class MediaStreamDevicesControllerTest : public WebRtcTestBase {
 
     // Cleanup.
     media_stream_devices_.clear();
-    media_stream_result_ =
-        blink::mojom::MediaStreamRequestResult::NUM_MEDIA_REQUEST_RESULTS;
+    media_stream_result_.reset();
 
     blink::MediaStreamDevices audio_devices;
     blink::MediaStreamDevice fake_audio_device(
@@ -279,7 +277,7 @@ class MediaStreamDevicesControllerTest : public WebRtcTestBase {
   const std::string example_video_id_;
 
   blink::MediaStreamDevices media_stream_devices_;
-  blink::mojom::MediaStreamRequestResult media_stream_result_;
+  std::optional<MediaStreamRequestResult> media_stream_result_;
 
   base::OnceClosure quit_closure_;
 
@@ -651,18 +649,18 @@ struct ContentSettingsTestData {
 
   // The expected media stream result after clicking accept/deny for the given
   // inputs.
-  blink::mojom::MediaStreamRequestResult ExpectedMediaStreamResult(
+  MediaStreamRequestResult ExpectedMediaStreamResult(
       const media::VideoCaptureControlSupport& control_support) const {
     if (ExpectMicAllowed() && ExpectCamAllowed()) {
       if (!control_support.pan && !control_support.tilt &&
           !control_support.zoom) {
-        return blink::mojom::MediaStreamRequestResult::OK;
+        return MediaStreamRequestResult::OK;
       }
       if (ptz != CONTENT_SETTING_BLOCK) {
-        return blink::mojom::MediaStreamRequestResult::OK;
+        return MediaStreamRequestResult::OK;
       }
     }
-    return blink::mojom::MediaStreamRequestResult::PERMISSION_DENIED;
+    return MediaStreamRequestResult::PERMISSION_DENIED;
   }
 };
 
@@ -797,7 +795,7 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
 
   ASSERT_EQ(0, prompt_factory()->TotalRequestCount());
 
-  VerifyResultState(blink::mojom::MediaStreamRequestResult::OK, false, true);
+  VerifyResultState(MediaStreamRequestResult::OK, false, true);
 }
 
 IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
@@ -818,7 +816,7 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
   ASSERT_TRUE(
       prompt_factory()->RequestTypeSeen(permissions::RequestType::kMicStream));
 
-  VerifyResultState(blink::mojom::MediaStreamRequestResult::OK, true, true);
+  VerifyResultState(MediaStreamRequestResult::OK, true, true);
 
   // Check that re-requesting allows without prompting.
   prompt_factory()->ResetCounts();
@@ -827,7 +825,7 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
       CreateRequest(example_audio_id(), example_video_id(), false));
   ASSERT_EQ(0, prompt_factory()->TotalRequestCount());
 
-  VerifyResultState(blink::mojom::MediaStreamRequestResult::OK, true, true);
+  VerifyResultState(MediaStreamRequestResult::OK, true, true);
 }
 
 IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
@@ -843,8 +841,7 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
                             blink::MEDIA_OPEN_DEVICE_PEPPER_ONLY));
   ASSERT_EQ(0, prompt_factory()->TotalRequestCount());
 
-  VerifyResultState(blink::mojom::MediaStreamRequestResult::PERMISSION_DENIED,
-                    false, false);
+  VerifyResultState(MediaStreamRequestResult::PERMISSION_DENIED, false, false);
 }
 
 IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest, WebContentsDestroyed) {
@@ -862,9 +859,8 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest, WebContentsDestroyed) {
   RequestPermissions(nullptr, request);
   ASSERT_EQ(0, prompt_factory()->TotalRequestCount());
 
-  VerifyResultState(
-      blink::mojom::MediaStreamRequestResult::FAILED_DUE_TO_SHUTDOWN, false,
-      false);
+  VerifyResultState(MediaStreamRequestResult::FAILED_DUE_TO_SHUTDOWN, false,
+                    false);
 }
 
 IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
@@ -888,13 +884,11 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
       CreateRequest(example_audio_id(), example_video_id(), false),
       base::BindOnce(
           [](const blink::mojom::StreamDevicesSet& stream_devices_set,
-             blink::mojom::MediaStreamRequestResult result,
+             MediaStreamRequestResult result,
              std::unique_ptr<content::MediaStreamUI> ui) {
             // The permission may be dismissed before we have a chance to delete
             // the request.
-            EXPECT_EQ(
-                blink::mojom::MediaStreamRequestResult::PERMISSION_DISMISSED,
-                result);
+            EXPECT_EQ(MediaStreamRequestResult::PERMISSION_DISMISSED, result);
           }),
       nullptr);
   // Since the mock prompt factory holds a reference to the
@@ -907,9 +901,7 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
   EXPECT_EQ(previous_tab_count - 1, browser()->tab_strip_model()->count());
   base::RunLoop().RunUntilIdle();
 
-  VerifyResultState(
-      blink::mojom::MediaStreamRequestResult::NUM_MEDIA_REQUEST_RESULTS, false,
-      false);
+  VerifyResultState(std::nullopt, false, false);
 }
 
 // Request and block microphone and camera access with kill switch.
@@ -917,16 +909,18 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
                        RequestAndKillSwitchMicCam) {
   std::map<std::string, std::string> params;
   params[permissions::PermissionUtil::GetPermissionString(
-      ContentSettingsType::MEDIASTREAM_MIC)] =
-      permissions::PermissionContextBase::kPermissionsKillSwitchBlockedValue;
+      ContentSettingsType::MEDIASTREAM_MIC)] = permissions::
+      ContentSettingPermissionContextBase::kPermissionsKillSwitchBlockedValue;
   params[permissions::PermissionUtil::GetPermissionString(
-      ContentSettingsType::MEDIASTREAM_CAMERA)] =
-      permissions::PermissionContextBase::kPermissionsKillSwitchBlockedValue;
+      ContentSettingsType::MEDIASTREAM_CAMERA)] = permissions::
+      ContentSettingPermissionContextBase::kPermissionsKillSwitchBlockedValue;
   base::AssociateFieldTrialParams(
-      permissions::PermissionContextBase::kPermissionsKillSwitchFieldStudy,
+      permissions::ContentSettingPermissionContextBase::
+          kPermissionsKillSwitchFieldStudy,
       "TestGroup", params);
   base::FieldTrialList::CreateFieldTrial(
-      permissions::PermissionContextBase::kPermissionsKillSwitchFieldStudy,
+      permissions::ContentSettingPermissionContextBase::
+          kPermissionsKillSwitchFieldStudy,
       "TestGroup");
   InitWithUrl(embedded_test_server()->GetURL("/simple.html"));
   SetDevicePolicy(DEVICE_TYPE_AUDIO, ACCESS_ALLOWED);
@@ -936,8 +930,7 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
       CreateRequest(example_audio_id(), example_video_id(), false));
 
   ASSERT_EQ(0, prompt_factory()->TotalRequestCount());
-  VerifyResultState(blink::mojom::MediaStreamRequestResult::KILL_SWITCH_ON,
-                    false, false);
+  VerifyResultState(MediaStreamRequestResult::KILL_SWITCH_ON, false, false);
 }
 
 IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
@@ -966,8 +959,7 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
 
   ASSERT_EQ(0, prompt_factory()->TotalRequestCount());
 
-  VerifyResultState(blink::mojom::MediaStreamRequestResult::PERMISSION_DENIED,
-                    false, false);
+  VerifyResultState(MediaStreamRequestResult::PERMISSION_DENIED, false, false);
   EXPECT_TRUE(GetContentSettings()->GetMicrophoneCameraState().empty());
 }
 
@@ -997,8 +989,7 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
 
   ASSERT_EQ(0, prompt_factory()->TotalRequestCount());
 
-  VerifyResultState(blink::mojom::MediaStreamRequestResult::PERMISSION_DENIED,
-                    false, false);
+  VerifyResultState(MediaStreamRequestResult::PERMISSION_DENIED, false, false);
   EXPECT_TRUE(GetContentSettings()->GetMicrophoneCameraState().empty());
 }
 
@@ -1010,7 +1001,7 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
       GetWebContents(),
       CreateRequestWithType(example_audio_id(), std::string(), false,
                             blink::MEDIA_OPEN_DEVICE_PEPPER_ONLY));
-  VerifyResultState(blink::mojom::MediaStreamRequestResult::OK, true, false);
+  VerifyResultState(MediaStreamRequestResult::OK, true, false);
 }
 
 IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
@@ -1021,5 +1012,5 @@ IN_PROC_BROWSER_TEST_F(MediaStreamDevicesControllerTest,
       GetWebContents(),
       CreateRequestWithType(std::string(), example_video_id(), false,
                             blink::MEDIA_OPEN_DEVICE_PEPPER_ONLY));
-  VerifyResultState(blink::mojom::MediaStreamRequestResult::OK, false, true);
+  VerifyResultState(MediaStreamRequestResult::OK, false, true);
 }
