@@ -41,9 +41,58 @@
 #include "components/onc/onc_constants.h"  // nogncheck
 #endif
 
+#if BUILDFLAG(CHROME_ROOT_STORE_CERT_MANAGEMENT_UI)
+#include "base/containers/span.h"
+#include "base/containers/to_vector.h"
+#include "base/test/test_future.h"
+#include "chrome/browser/net/profile_network_context_service.h"
+#include "chrome/browser/net/profile_network_context_service_factory.h"
+#include "chrome/browser/net/server_certificate_database_service_factory.h"  // nogncheck
+#include "chrome/browser/profiles/profile.h"
+#include "chrome/browser/ui/browser.h"
+#include "chrome/test/base/chrome_test_utils.h"
+#include "chrome/test/base/ui_test_utils.h"
+#include "components/server_certificate_database/server_certificate_database.h"  // nogncheck
+#include "components/server_certificate_database/server_certificate_database.pb.h"  // nogncheck
+#include "components/server_certificate_database/server_certificate_database_service.h"  // nogncheck
+#include "crypto/sha2.h"
+#endif  // BUILDFLAG(CHROME_ROOT_STORE_CERT_MANAGEMENT_UI)
+
+namespace {
+class CertVerifierServicePolicyTest : public policy::PolicyTest {
+ public:
+  // In some cases, we may need to wait until the certificate policy updates
+  // propagate.
+  void UpdateProviderPolicyAndWaitForUpdate(const policy::PolicyMap& policies) {
+    // If the ServerCertificateDatabaseService is enabled, the cert verifier
+    // service update is asynchronous and the test needs to wait for the update
+    // to complete.
+    // Otherwise, cert changes may not make it to the verifier in time to clear
+    // the cert verification cache.
+    // This is safe to do in other cases, as long as the test is expecting the
+    // cert verifier to get updated certificates.
+#if BUILDFLAG(CHROME_ROOT_STORE_CERT_MANAGEMENT_UI)
+    base::test::TestFuture<void> cert_verifier_service_update_waiter;
+    browser()
+        ->profile()
+        ->GetDefaultStoragePartition()
+        ->GetCertVerifierServiceUpdater()
+        ->WaitUntilNextUpdateForTesting(
+            cert_verifier_service_update_waiter.GetCallback());
+#endif  // BUILDFLAG(CHROME_ROOT_STORE_CERT_MANAGEMENT_UI)
+
+    // Update policy with root
+    UpdateProviderPolicy(policies);
+#if BUILDFLAG(CHROME_ROOT_STORE_CERT_MANAGEMENT_UI)
+    ASSERT_TRUE(cert_verifier_service_update_waiter.Wait());
+#endif  // BUILDFLAG(CHROME_ROOT_STORE_CERT_MANAGEMENT_UI)
+  }
+};
+}  // namespace
+
 // Testing the CACertificates policy
 class CertVerifierServiceCACertificatesPolicyTest
-    : public policy::PolicyTest,
+    : public CertVerifierServicePolicyTest,
       public testing::WithParamInterface<bool> {
  public:
   void SetUpInProcessBrowserTestFixture() override {
@@ -94,7 +143,7 @@ INSTANTIATE_TEST_SUITE_P(All,
 // Test update of CACertificates policy after verifier is already
 // created.
 class CertVerifierServiceCACertificatesUpdatePolicyTest
-    : public policy::PolicyTest {
+    : public CertVerifierServicePolicyTest {
  public:
   void SetUpInProcessBrowserTestFixture() override {
     policy::PolicyTest::SetUpInProcessBrowserTestFixture();
@@ -134,7 +183,7 @@ IN_PROC_BROWSER_TEST_F(CertVerifierServiceCACertificatesUpdatePolicyTest,
     policy::PolicyMap policies;
     SetPolicy(&policies, policy::key::kCACertificates,
               std::make_optional(std::move(certs_value)));
-    UpdateProviderPolicy(policies);
+    UpdateProviderPolicyAndWaitForUpdate(policies);
 
     ASSERT_TRUE(NavigateToUrl(https_test_server_.GetURL("/simple.html"), this));
     // Updated with policy, root should be trusted.
@@ -145,7 +194,7 @@ IN_PROC_BROWSER_TEST_F(CertVerifierServiceCACertificatesUpdatePolicyTest,
 
 // Testing the CADistrutedCertificates policy
 class CertVerifierServiceCADistrustedCertificatesPolicyTest
-    : public policy::PolicyTest {
+    : public CertVerifierServicePolicyTest {
  public:
   void SetUpInProcessBrowserTestFixture() override {
     policy::PolicyTest::SetUpInProcessBrowserTestFixture();
@@ -185,7 +234,7 @@ IN_PROC_BROWSER_TEST_F(CertVerifierServiceCADistrustedCertificatesPolicyTest,
 }
 
 class CertVerifierServiceCATrustedDistrustedCertificatesPolicyTest
-    : public policy::PolicyTest {
+    : public CertVerifierServicePolicyTest {
  public:
   void SetUpInProcessBrowserTestFixture() override {
     policy::PolicyTest::SetUpInProcessBrowserTestFixture();
@@ -237,7 +286,7 @@ IN_PROC_BROWSER_TEST_F(
 // Test update of CADistrustedCertificates policy after verifier is already
 // created.
 class CertVerifierServiceCADistrustedCertificatesUpdatePolicyTest
-    : public policy::PolicyTest {
+    : public CertVerifierServicePolicyTest {
  public:
   void SetUpInProcessBrowserTestFixture() override {
     policy::PolicyTest::SetUpInProcessBrowserTestFixture();
@@ -273,7 +322,7 @@ IN_PROC_BROWSER_TEST_F(
     certs_value.GetList().Append(std::move(b64_cert));
     SetPolicy(&policies, policy::key::kCADistrustedCertificates,
               std::make_optional(std::move(certs_value)));
-    UpdateProviderPolicy(policies);
+    UpdateProviderPolicyAndWaitForUpdate(policies);
 
     ASSERT_TRUE(NavigateToUrl(https_test_server_.GetURL("/simple.html"), this));
     // Updated with policy, root should no longer be trusted.
@@ -284,7 +333,7 @@ IN_PROC_BROWSER_TEST_F(
 
 // Testing the CAHintCertificate policy
 class CertVerifierServiceCAHintCertificatesPolicyTest
-    : public policy::PolicyTest,
+    : public CertVerifierServicePolicyTest,
       public testing::WithParamInterface<bool> {
  public:
   void SetUpInProcessBrowserTestFixture() override {
@@ -338,7 +387,7 @@ INSTANTIATE_TEST_SUITE_P(All,
 // Test update of CAHintCertificates policy after verifier is already
 // created.
 class CertVerifierServiceCAHintCertificatesUpdatePolicyTest
-    : public policy::PolicyTest {
+    : public CertVerifierServicePolicyTest {
  public:
   void SetUpInProcessBrowserTestFixture() override {
     policy::PolicyTest::SetUpInProcessBrowserTestFixture();
@@ -378,7 +427,7 @@ IN_PROC_BROWSER_TEST_F(CertVerifierServiceCAHintCertificatesUpdatePolicyTest,
     policy::PolicyMap policies;
     SetPolicy(&policies, policy::key::kCAHintCertificates,
               std::make_optional(std::move(certs_value)));
-    UpdateProviderPolicy(policies);
+    UpdateProviderPolicyAndWaitForUpdate(policies);
 
     ASSERT_TRUE(NavigateToUrl(https_test_server_.GetURL("/simple.html"), this));
     // Updated with policy, intermediate is used so chain can be built.
@@ -395,7 +444,7 @@ IN_PROC_BROWSER_TEST_F(CertVerifierServiceCAHintCertificatesUpdatePolicyTest,
 // store in an integration test without possibly messing up other tests.
 // Except on Linux.
 class CertVerifierServiceCAPlatformIntegrationPolicyBaseTest
-    : public policy::PolicyTest {
+    : public CertVerifierServicePolicyTest {
  public:
   void SetUpOnMainThread() override {
     policy::PolicyTest::SetUpOnMainThread();
@@ -442,7 +491,7 @@ IN_PROC_BROWSER_TEST_P(CertVerifierServiceCAPlatformIntegrationPolicyTest,
   policy::PolicyMap policies;
   SetPolicy(&policies, policy::key::kCAPlatformIntegrationEnabled,
             std::optional<base::Value>(platform_root_store_enabled()));
-  UpdateProviderPolicy(policies);
+  UpdateProviderPolicyAndWaitForUpdate(policies);
 
   net::EmbeddedTestServer https_test_server(
       net::EmbeddedTestServer::TYPE_HTTPS);
@@ -490,7 +539,7 @@ IN_PROC_BROWSER_TEST_F(CertVerifierServiceCAPlatformIntegrationPolicyBaseTest,
   policy::PolicyMap policies;
   SetPolicy(&policies, policy::key::kCAPlatformIntegrationEnabled,
             std::optional<base::Value>(false));
-  UpdateProviderPolicy(policies);
+  UpdateProviderPolicyAndWaitForUpdate(policies);
 
   ASSERT_TRUE(NavigateToUrl(https_test_server.GetURL("/simple.html"), this));
   // Platform integration is false, request should fail to verify cert.
@@ -502,7 +551,7 @@ IN_PROC_BROWSER_TEST_F(CertVerifierServiceCAPlatformIntegrationPolicyBaseTest,
 
 // Test the CACertificatesWithConstraints policy
 class CertVerifierServiceCACertsWithConstraintsPolicyTest
-    : public policy::PolicyTest,
+    : public CertVerifierServicePolicyTest,
       public testing::WithParamInterface<bool> {
  public:
   void SetUpInProcessBrowserTestFixture() override {
@@ -563,7 +612,7 @@ INSTANTIATE_TEST_SUITE_P(All,
                          ::testing::Bool());
 
 class CertVerifierServiceCACertsWithCIDRConstraintsPolicyTest
-    : public policy::PolicyTest,
+    : public CertVerifierServicePolicyTest,
       public testing::WithParamInterface<bool> {
  public:
   void SetUpInProcessBrowserTestFixture() override {
@@ -622,7 +671,7 @@ INSTANTIATE_TEST_SUITE_P(
     ::testing::Bool());
 
 class CertVerifierServiceCACertsWithInvalidCIDRConstraintsPolicyTest
-    : public policy::PolicyTest {
+    : public CertVerifierServicePolicyTest {
  public:
   void SetUpInProcessBrowserTestFixture() override {
     policy::PolicyTest::SetUpInProcessBrowserTestFixture();
@@ -673,7 +722,7 @@ IN_PROC_BROWSER_TEST_F(
 }
 
 class CertVerifierServiceCACertsWithConstraintsUpdatePolicyTest
-    : public policy::PolicyTest {
+    : public CertVerifierServicePolicyTest {
  public:
   void SetUpInProcessBrowserTestFixture() override {
     policy::PolicyTest::SetUpInProcessBrowserTestFixture();
@@ -716,7 +765,7 @@ IN_PROC_BROWSER_TEST_F(
     SetPolicy(&policies, policy::key::kCACertificatesWithConstraints,
               std::make_optional(
                   base::Value(std::move(certs_with_constraints_value))));
-    UpdateProviderPolicy(policies);
+    UpdateProviderPolicyAndWaitForUpdate(policies);
 
     ASSERT_TRUE(NavigateToUrl(https_test_server_.GetURL("/simple.html"), this));
     // invalid CIDR constraint means the root cert isn't trusted.
@@ -739,7 +788,7 @@ IN_PROC_BROWSER_TEST_F(
     SetPolicy(&policies, policy::key::kCACertificatesWithConstraints,
               std::make_optional(
                   base::Value(std::move(certs_with_constraints_value))));
-    UpdateProviderPolicy(policies);
+    UpdateProviderPolicyAndWaitForUpdate(policies);
 
     ASSERT_TRUE(NavigateToUrl(https_test_server_.GetURL("/simple.html"), this));
     // Updated with a valid CIDR constraint, cert should be trusted.
@@ -753,7 +802,7 @@ IN_PROC_BROWSER_TEST_F(
 // and the new CACertificates/CAHintCertificates policies, that they are both
 // honored.
 class CertVerifierServiceNewAndOncCertificatePoliciesTest
-    : public policy::PolicyTest,
+    : public CertVerifierServicePolicyTest,
       public testing::WithParamInterface<bool> {
  public:
   bool add_cert_to_policy() const { return GetParam(); }
@@ -834,7 +883,7 @@ IN_PROC_BROWSER_TEST_P(CertVerifierServiceNewAndOncCertificatePoliciesTest,
               std::make_optional(base::Value(std::move(new_ca_certs))));
     SetPolicy(&policies, policy::key::kCAHintCertificates,
               std::make_optional(base::Value(std::move(new_hint_certs))));
-    UpdateProviderPolicy(policies);
+    UpdateProviderPolicyAndWaitForUpdate(policies);
   }
 
   ASSERT_TRUE(
@@ -854,3 +903,107 @@ INSTANTIATE_TEST_SUITE_P(All,
                          CertVerifierServiceNewAndOncCertificatePoliciesTest,
                          ::testing::Bool());
 #endif  // BUILDFLAG(IS_CHROMEOS)
+
+#if BUILDFLAG(CHROME_ROOT_STORE_CERT_MANAGEMENT_UI)
+// Tests that when certificates are simultaneously added to both the user
+// added certs database and the new CACertificates/CAHintCertificates policies,
+// that they are both honored.
+class CertVerifierServicePolicyAndUserRootsTest
+    : public CertVerifierServicePolicyTest,
+      public testing::WithParamInterface<bool> {
+ public:
+  bool add_certs() const { return GetParam(); }
+};
+
+IN_PROC_BROWSER_TEST_P(CertVerifierServicePolicyAndUserRootsTest,
+                       UserRootsAndPolicyCombined) {
+  net::EmbeddedTestServer test_server_for_user_added{
+      net::EmbeddedTestServer::TYPE_HTTPS};
+  net::EmbeddedTestServer test_server_for_policy{
+      net::EmbeddedTestServer::TYPE_HTTPS};
+  // Configure both test servers to serve chains with unique roots and with
+  // an intermediate that is not sent by the testserver nor available via
+  // AIA. Neither server should be trusted unless its intermediate is
+  // supplied as a hint via policy and its root is trusted via policy.
+  net::EmbeddedTestServer::ServerCertificateConfig test_cert_config;
+  test_cert_config.intermediate =
+      net::EmbeddedTestServer::IntermediateType::kMissing;
+  test_cert_config.root = net::EmbeddedTestServer::RootType::kUniqueRoot;
+  test_server_for_user_added.SetSSLConfig(test_cert_config);
+  test_server_for_policy.SetSSLConfig(test_cert_config);
+  test_server_for_user_added.ServeFilesFromSourceDirectory("chrome/test/data");
+  test_server_for_policy.ServeFilesFromSourceDirectory("chrome/test/data");
+
+  ASSERT_TRUE(test_server_for_user_added.Start());
+  ASSERT_TRUE(test_server_for_policy.Start());
+  if (add_certs()) {
+    net::ServerCertificateDatabaseService* server_certificate_database_service =
+        net::ServerCertificateDatabaseServiceFactory::GetForBrowserContext(
+            browser()->profile());
+    {
+      scoped_refptr<net::X509Certificate> root_cert =
+          test_server_for_user_added.GetRoot();
+      net::ServerCertificateDatabase::CertInformation user_root_info(
+          root_cert->cert_span());
+      user_root_info.cert_metadata.mutable_trust()->set_trust_type(
+          chrome_browser_server_certificate_database::CertificateTrust::
+              CERTIFICATE_TRUST_TYPE_TRUSTED);
+
+      base::test::TestFuture<bool> future;
+      std::vector<net::ServerCertificateDatabase::CertInformation> cert_infos;
+      cert_infos.push_back(std::move(user_root_info));
+      server_certificate_database_service->AddOrUpdateUserCertificates(
+          std::move(cert_infos), future.GetCallback());
+      ASSERT_TRUE(future.Get());
+    }
+    {
+      scoped_refptr<net::X509Certificate> hint_cert =
+          test_server_for_user_added.GetGeneratedIntermediate();
+
+      net::ServerCertificateDatabase::CertInformation user_hint_info(
+          hint_cert->cert_span());
+      user_hint_info.cert_metadata.mutable_trust()->set_trust_type(
+          chrome_browser_server_certificate_database::CertificateTrust::
+              CERTIFICATE_TRUST_TYPE_UNSPECIFIED);
+
+      base::test::TestFuture<bool> future;
+      std::vector<net::ServerCertificateDatabase::CertInformation> cert_infos;
+      cert_infos.push_back(std::move(user_hint_info));
+      server_certificate_database_service->AddOrUpdateUserCertificates(
+          std::move(cert_infos), future.GetCallback());
+      ASSERT_TRUE(future.Get());
+    }
+
+    auto policy_ca_certs = base::Value::List().Append(
+        base::Base64Encode(net::x509_util::CryptoBufferAsStringPiece(
+            test_server_for_policy.GetRoot()->cert_buffer())));
+
+    auto policy_hint_certs = base::Value::List().Append(
+        base::Base64Encode(net::x509_util::CryptoBufferAsStringPiece(
+            test_server_for_policy.GetGeneratedIntermediate()->cert_buffer())));
+
+    policy::PolicyMap policies;
+    SetPolicy(&policies, policy::key::kCACertificates,
+              std::make_optional(base::Value(std::move(policy_ca_certs))));
+    SetPolicy(&policies, policy::key::kCAHintCertificates,
+              std::make_optional(base::Value(std::move(policy_hint_certs))));
+    // Policy updates will also trigger an update to the Cert Verifier, pulling
+    // in the certs from ServerCertificateDatabase.
+    UpdateProviderPolicyAndWaitForUpdate(policies);
+  }
+
+  ASSERT_TRUE(
+      NavigateToUrl(test_server_for_policy.GetURL("/simple.html"), this));
+  EXPECT_NE(add_certs(), chrome_browser_interstitials::IsShowingInterstitial(
+                             chrome_test_utils::GetActiveWebContents(this)));
+
+  ASSERT_TRUE(
+      NavigateToUrl(test_server_for_user_added.GetURL("/simple.html"), this));
+  EXPECT_NE(add_certs(), chrome_browser_interstitials::IsShowingInterstitial(
+                             chrome_test_utils::GetActiveWebContents(this)));
+}
+
+INSTANTIATE_TEST_SUITE_P(All,
+                         CertVerifierServicePolicyAndUserRootsTest,
+                         ::testing::Bool());
+#endif  // BUILDFLAG(CHROME_ROOT_STORE_CERT_MANAGEMENT_UI)
