@@ -11,6 +11,7 @@
 #include "base/files/file_path.h"
 #include "base/functional/bind.h"
 #include "base/functional/callback_forward.h"
+#include "base/process/process.h"
 #include "base/run_loop.h"
 #include "base/strings/strcat.h"
 #include "base/test/bind.h"
@@ -41,7 +42,6 @@
 #include "content/public/browser/service_process_info.h"
 #include "content/public/browser/web_contents_observer.h"
 #include "content/public/common/content_features.h"
-#include "content/public/common/user_agent.h"
 #include "content/public/test/browser_test.h"
 #include "content/public/test/browser_test_utils.h"
 #include "content/public/test/content_browser_test_utils.h"
@@ -65,6 +65,14 @@
 #include "testing/gtest/include/gtest/gtest.h"
 #include "third_party/blink/public/common/features.h"
 
+#if BUILDFLAG(IS_WIN)
+#include "base/process/process_info.h"
+#include "base/test/metrics/histogram_tester.h"
+#include "chrome/browser/browser_features.h"
+#include "chrome/common/chrome_version.h"
+#include "content/public/browser/storage_partition.h"
+#endif  // BUILDFLAG(IS_WIN)
+
 #if BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_LINUX)
 #include "sandbox/policy/linux/sandbox_seccomp_bpf_linux.h"
 #endif  // BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_LINUX)
@@ -402,6 +410,212 @@ INSTANTIATE_TEST_SUITE_P(
 
 #endif  // BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_LINUX)
 
+#if BUILDFLAG(IS_WIN)
+
+class SystemNetworkContextManagerNetworkServiceSandboxBrowsertest
+    : public SystemNetworkContextManagerBrowsertest,
+      public content::ServiceProcessHost::Observer {
+ public:
+  SystemNetworkContextManagerNetworkServiceSandboxBrowsertest() {
+    scoped_feature_list_.InitWithFeatures(
+        {sandbox::policy::features::kNetworkServiceSandbox,
+         features::kRestartNetworkServiceUnsandboxedForFailedLaunch},
+        {});
+  }
+
+  void SetUpOnMainThread() override {
+    SystemNetworkContextManagerBrowsertest::SetUpOnMainThread();
+    launch_run_loop_.emplace();
+    content::ServiceProcessHost::AddObserver(this);
+    auto running_processes =
+        content::ServiceProcessHost::GetRunningProcessInfo();
+    for (const auto& info : running_processes) {
+      if (info.IsService<network::mojom::NetworkService>()) {
+        RecordProcessSandboxState(info.GetProcess());
+        break;
+      }
+    }
+  }
+
+  void TearDownOnMainThread() override {
+    content::ServiceProcessHost::RemoveObserver(this);
+  }
+
+ protected:
+  size_t launches_seen_ = 0;
+  bool network_service_sandboxed_;
+  std::optional<base::RunLoop> launch_run_loop_;
+
+ private:
+  void RecordProcessSandboxState(const base::Process& process) {
+    const auto integrity_level = base::GetProcessIntegrityLevel(process.Pid());
+    CHECK_NE(base::INTEGRITY_UNKNOWN, integrity_level);
+    network_service_sandboxed_ = integrity_level < base::MEDIUM_INTEGRITY;
+  }
+
+  void OnServiceProcessLaunched(
+      const content::ServiceProcessInfo& info) override {
+    if (!info.IsService<network::mojom::NetworkService>()) {
+      return;
+    }
+    RecordProcessSandboxState(info.GetProcess());
+    // Expect two launches, first for the restart due to intentional crash, then
+    // for the restart after the intentional crash at startup.
+    if (++launches_seen_ >= 2u) {
+      launch_run_loop_->Quit();
+    }
+  }
+
+  base::test::ScopedFeatureList scoped_feature_list_;
+};
+
+// This is a four stage test to verify the early launch crash behavior for the
+// network service sandbox on Windows.
+//
+// In the first stage, the network service is already started as normal during
+// browser launch. The test verifies that the service is currently sandboxed.
+//
+// In the second stage, the artificial early crash is added, then the service is
+// crashed to cause a restart. This results in the service starting, crashing
+// immediately then starting again unsandboxed. The test verifies that the
+// service is now unsandboxed and the pref has been set to mark the sandbox as
+// being disabled.
+//
+// In the third stage, a crash is induced again and it's checked that the
+// unsandboxed state is correctly persisted and used on the second restart.
+//
+// In the fourth stage, the crashing milestone is set to one milestone previous
+// to current, and then the service then crashed again to cause a restart. This
+// time the service will start sandboxed again because the early crash was in a
+// previous milestone.
+IN_PROC_BROWSER_TEST_F(
+    SystemNetworkContextManagerNetworkServiceSandboxBrowsertest,
+    NetworkServiceRestartsFailingLaunches) {
+  if (!sandbox::policy::features::IsNetworkSandboxSupported()) {
+    GTEST_SKIP() << "This test requires platform sandbox support.";
+  }
+
+  // Check network service is sandboxed initially.
+  EXPECT_TRUE(network_service_sandboxed_);
+
+  {
+    base::HistogramTester histograms;
+
+    // The next restart will fail to bootstrap correctly.
+    content::SetNetworkServiceCrashOnNextStartupForTesting();
+    // Cause a crash in the network service, which will cause it to restart,
+    // then fail to start, then restart again unsandboxed.
+    SimulateNetworkServiceCrash();
+    // The second restart (unsandboxed) must be ignored otherwise the test will
+    // fail.
+    IgnoreNetworkServiceCrashes();
+    // Make sure the network service is fully up and running after having to
+    // restart twice.
+    browser()
+        ->profile()
+        ->GetDefaultStoragePartition()
+        ->FlushNetworkInterfaceForTesting();
+
+    launch_run_loop_->Run();
+    EXPECT_FALSE(network_service_sandboxed_);
+    EXPECT_TRUE(SystemNetworkContextManager::GetInstance()
+                    ->HasFailedPreviousRecentLaunch());
+    int crashing_major_version = g_browser_process->local_state()->GetInteger(
+        prefs::kNetworkServiceFailedLaunchMajorVersion);
+    CHECK_EQ(crashing_major_version, CHROME_VERSION_MAJOR);
+    histograms.ExpectUniqueSample(
+        "Chrome.SystemNetworkContextManager.NetworkSandboxEarlyLaunchCrashed",
+        true, 1u);
+    // Two sets of histograms are emitted in this part: first the network
+    // service is launched with sandbox enabled, then the second re-launch is
+    // with sandbox disabled because of failed launch. Note these histograms
+    // have varied counts. This is because
+    // Chrome.SystemNetworkContextManager.NetworkSandboxState is logged from
+    // SystemNetworkContextManager::IsNetworkSandboxEnabled which is called from
+    // various places in mojo and service manager. This test merely has to
+    // verify that there exist only entries in the two buckets and no other
+    // bucket.
+    const auto enabled_count = histograms.GetBucketCount(
+        "Chrome.SystemNetworkContextManager.NetworkSandboxState",
+        /*kEnabledByPlatform*/ 1);
+    const auto disabled_because_of_failed_launch_count =
+        histograms.GetBucketCount(
+            "Chrome.SystemNetworkContextManager.NetworkSandboxState",
+            /*kDisabledBecauseOfFailedLaunch*/ 4);
+    CHECK_GT(disabled_because_of_failed_launch_count, 1u);
+    CHECK_GT(enabled_count, 1u);
+    histograms.ExpectTotalCount(
+        "Chrome.SystemNetworkContextManager.NetworkSandboxState",
+        enabled_count + disabled_because_of_failed_launch_count);
+  }
+
+  {
+    base::HistogramTester histograms;
+    // Crash again, this time to verify that the pref persists and causes the
+    // network service to remain unsandboxed even on a second restart.
+    SimulateNetworkServiceCrash();
+
+    // Make sure the network service is fully up and running after having to
+    // restart.
+    browser()
+        ->profile()
+        ->GetDefaultStoragePartition()
+        ->FlushNetworkInterfaceForTesting();
+
+    // Sandbox should still be disabled as the pref stored the state.
+    EXPECT_FALSE(network_service_sandboxed_);
+    EXPECT_TRUE(SystemNetworkContextManager::GetInstance()
+                    ->HasFailedPreviousRecentLaunch());
+    histograms.ExpectTotalCount(
+        "Chrome.SystemNetworkContextManager.NetworkSandboxEarlyLaunchCrashed",
+        0);
+    const auto disabled_because_of_failed_launch_count =
+        histograms.GetBucketCount(
+            "Chrome.SystemNetworkContextManager.NetworkSandboxState",
+            /*kDisabledBecauseOfFailedLaunch*/ 4);
+    CHECK_GT(disabled_because_of_failed_launch_count, 1u);
+    histograms.ExpectTotalCount(
+        "Chrome.SystemNetworkContextManager.NetworkSandboxState",
+        disabled_because_of_failed_launch_count);
+  }
+
+  {
+    base::HistogramTester histograms;
+    // Simulate that a previous milestone was crashing.
+    g_browser_process->local_state()->SetInteger(
+        prefs::kNetworkServiceFailedLaunchMajorVersion,
+        CHROME_VERSION_MAJOR - 1);
+
+    // Crash again, this time to get a sandboxed service again.
+    SimulateNetworkServiceCrash();
+
+    // Make sure the network service is fully up and running after having to
+    // restart.
+    browser()
+        ->profile()
+        ->GetDefaultStoragePartition()
+        ->FlushNetworkInterfaceForTesting();
+
+    // Sandbox should now be engaged again because the major version
+    // incremented.
+    EXPECT_TRUE(network_service_sandboxed_);
+    EXPECT_FALSE(SystemNetworkContextManager::GetInstance()
+                     ->HasFailedPreviousRecentLaunch());
+    histograms.ExpectTotalCount(
+        "Chrome.SystemNetworkContextManager.NetworkSandboxEarlyLaunchCrashed",
+        0);
+    const auto enabled_count = histograms.GetBucketCount(
+        "Chrome.SystemNetworkContextManager.NetworkSandboxState",
+        /*kEnabledByPlatform*/ 1);
+    CHECK_GT(enabled_count, 1u);
+    histograms.ExpectTotalCount(
+        "Chrome.SystemNetworkContextManager.NetworkSandboxState",
+        enabled_count);
+  }
+}
+
+#endif  // BUILDFLAG(IS_WIN)
+
 #if BUILDFLAG(IS_LINUX)
 class SystemNetworkContextManagerHttpNegotiateHeader
     : public SystemNetworkContextManagerBrowsertest {
@@ -649,7 +863,7 @@ IN_PROC_BROWSER_TEST_F(
               /*warnings=*/{net::CookieInclusionStatus::WarningReason::
                                 WARN_PORT_MISMATCH}),
           net::CookieAccessSemantics::NONLEGACY,
-          net::CookieScopeSemantics::UNKNOWN, true)};
+          net::CookieScopeSemantics::NONLEGACY, true)};
   EXPECT_THAT(cookie_tracker.cookie_accesses(),
               testing::ElementsAre(
                   // a.test/title1.html
@@ -678,7 +892,7 @@ IN_PROC_BROWSER_TEST_F(
       net::CookieAccessResult(net::CookieEffectiveSameSite::NO_RESTRICTION,
                               expected_third_party_inclusion_status,
                               net::CookieAccessSemantics::NONLEGACY,
-                              net::CookieScopeSemantics::UNKNOWN, true)};
+                              net::CookieScopeSemantics::NONLEGACY, true)};
   EXPECT_THAT(cookie_tracker.cookie_accesses(),
               testing::ElementsAre(
                   // a.test iframe under b.test
@@ -764,17 +978,3 @@ IN_PROC_BROWSER_TEST_P(SystemNetworkContextManagerWPADQuickCheckBrowsertest,
 INSTANTIATE_TEST_SUITE_P(All,
                          SystemNetworkContextManagerWPADQuickCheckBrowsertest,
                          ::testing::Bool());
-
-class SystemNetworkContextManagerCertificateTransparencyBrowsertest
-    : public SystemNetworkContextManagerBrowsertest,
-      public testing::WithParamInterface<std::optional<bool>> {
- public:
-  SystemNetworkContextManagerCertificateTransparencyBrowsertest() {
-    SystemNetworkContextManager::SetEnableCertificateTransparencyForTesting(
-        GetParam());
-  }
-  ~SystemNetworkContextManagerCertificateTransparencyBrowsertest() override {
-    SystemNetworkContextManager::SetEnableCertificateTransparencyForTesting(
-        std::nullopt);
-  }
-};
