@@ -7,6 +7,12 @@
 
 #include <string>
 
+#include "content/public/common/buildflags.h"
+
+#if !BUILDFLAG(ENABLE_PLUGINS)
+#error "Plugins should be enabled"
+#endif
+
 // TODO(crbug.com/40123808): Remove this class.
 class PluginMetadata {
  public:
