@@ -28,7 +28,6 @@
 #include "base/test/scoped_feature_list.h"
 #include "base/threading/thread_restrictions.h"
 #include "build/build_config.h"
-#include "build/chromeos_buildflags.h"
 #include "chrome/app/chrome_command_ids.h"
 #include "chrome/browser/extensions/extension_browsertest.h"
 #include "chrome/browser/printing/browser_printing_context_factory_for_test.h"
@@ -517,8 +516,7 @@ void PrintBrowserTest::AddPrinter(const std::string& printer_name) {
       printer_name,
       /*display_name=*/"test printer",
       /*printer_description=*/"A printer for testing.",
-      /*printer_status=*/0,
-      /*is_default=*/true, test::kPrintInfoOptions);
+      test::kPrintInfoOptions);
 
   auto default_caps = std::make_unique<PrinterSemanticCapsAndDefaults>();
   default_caps->copies_max = kTestPrinterCapabilitiesMaxCopies;
@@ -529,6 +527,7 @@ void PrintBrowserTest::AddPrinter(const std::string& printer_name) {
   test_print_backend_->AddValidPrinter(
       printer_name, std::move(default_caps),
       std::make_unique<PrinterBasicInfo>(printer_info));
+  test_print_backend_->SetDefaultPrinterName(printer_name);
 }
 
 void PrintBrowserTest::SetPrinterNameForSubsequentContexts(
@@ -596,7 +595,7 @@ PrintBrowserTest::PrintAndWaitUntilPreviewIsReadyAndMaybeLoaded(
   switch (params.invoke_method) {
     case InvokePrintMethod::kStartPrint:
       StartPrint(web_contents,
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
                  /*print_renderer=*/mojo::NullAssociatedRemote(),
 #endif
                  /*print_preview_disabled=*/false, params.print_only_selection);
@@ -728,6 +727,7 @@ class SitePerProcessPrintBrowserTest : public PrintBrowserTest {
 
   // content::BrowserTestBase
   void SetUpCommandLine(base::CommandLine* command_line) override {
+    PrintBrowserTest::SetUpCommandLine(command_line);
     content::IsolateAllSitesForTesting(command_line);
   }
 };
@@ -862,6 +862,7 @@ class SitePerProcessPrintExtensionBrowserTest
  public:
   // content::BrowserTestBase
   void SetUpCommandLine(base::CommandLine* command_line) override {
+    PrintExtensionBrowserTest::SetUpCommandLine(command_line);
     content::IsolateAllSitesForTesting(command_line);
   }
 };
