@@ -10,5 +10,11 @@ const char kPushMessagingGcmEndpoint[] =
 const char kPushMessagingStagingGcmEndpoint[] =
     "https://jmt17.google.com/fcm/send/";
 
+const char kPushMessagingWebpushEndpoint[] =
+    "https://fcm.googleapis.com/wp/";
+
+const char kPushMessagingStagingWebpushEndpoint[] =
+    "https://fcm.googleapis.com/preprod/wp/";
+
 const char kPushMessagingForcedNotificationTag[] =
     "user_visible_auto_notification";
