@@ -5,12 +5,18 @@
 import './iframe.js';
 import './logo.js';
 import '/strings.m.js';
+import 'chrome://new-tab-page/shared/customize_buttons/customize_buttons.js';
 import 'chrome://resources/cr_components/searchbox/searchbox.js';
 import 'chrome://resources/cr_elements/cr_button/cr_button.js';
+import 'chrome://resources/cr_components/composebox/composebox.js';
 
+import type {CustomizeButtonsElement} from 'chrome://new-tab-page/shared/customize_buttons/customize_buttons.js';
 import {ColorChangeUpdater} from 'chrome://resources/cr_components/color_change_listener/colors_css_updater.js';
+import type {ComposeboxElement} from 'chrome://resources/cr_components/composebox/composebox.js';
 import {HelpBubbleMixinLit} from 'chrome://resources/cr_components/help_bubble/help_bubble_mixin_lit.js';
+import type {SearchboxElement} from 'chrome://resources/cr_components/searchbox/searchbox.js';
 import type {CrToastElement} from 'chrome://resources/cr_elements/cr_toast/cr_toast.js';
+import {assert} from 'chrome://resources/js/assert.js';
 import type {ClickInfo} from 'chrome://resources/js/browser_command.mojom-webui.js';
 import {Command} from 'chrome://resources/js/browser_command.mojom-webui.js';
 import {BrowserCommandProxy} from 'chrome://resources/js/browser_command/browser_command_proxy.js';
@@ -26,13 +32,16 @@ import type {SkColor} from 'chrome://resources/mojo/skia/public/mojom/skcolor.mo
 import {getCss} from './app.css.js';
 import {getHtml} from './app.html.js';
 import {BackgroundManager} from './background_manager.js';
+import type {CustomizeButtonsDocumentCallbackRouter, CustomizeButtonsHandlerRemote} from './customize_buttons.mojom-webui.js';
+import {CustomizeChromeSection, SidePanelOpenTrigger} from './customize_buttons.mojom-webui.js';
+import {CustomizeButtonsProxy} from './customize_buttons_proxy.js';
 import {CustomizeDialogPage} from './customize_dialog_types.js';
 import type {IframeElement} from './iframe.js';
 import type {LogoElement} from './logo.js';
-import {recordDuration, recordLoadDuration} from './metrics_utils.js';
+import {recordBoolean, recordDuration, recordEnumeration, recordLoadDuration, recordSparseValueWithPersistentHash, recordValue} from './metrics_utils.js';
 import {ParentTrustedDocumentProxy} from './modules/microsoft_auth_frame_connector.js';
 import type {PageCallbackRouter, PageHandlerRemote, Theme} from './new_tab_page.mojom-webui.js';
-import {CustomizeChromeSection, IphFeature, NtpBackgroundImageSource} from './new_tab_page.mojom-webui.js';
+import {IphFeature, NtpBackgroundImageSource} from './new_tab_page.mojom-webui.js';
 import {NewTabPageProxy} from './new_tab_page_proxy.js';
 import type {MicrosoftAuthUntrustedDocumentRemote} from './ntp_microsoft_auth_shared_ui.mojom-webui.js';
 import {$$} from './utils.js';
@@ -107,12 +116,11 @@ const realboxCanShowSecondarySideMediaQueryList =
     window.matchMedia('(min-width: 900px)');
 
 function recordClick(element: NtpElement) {
-  chrome.metricsPrivate.recordEnumerationValue(
-      'NewTabPage.Click', element, NtpElement.MAX_VALUE + 1);
+  recordEnumeration('NewTabPage.Click', element, NtpElement.MAX_VALUE + 1);
 }
 
 function recordCustomizeChromeOpen(element: NtpCustomizeChromeEntryPoint) {
-  chrome.metricsPrivate.recordEnumerationValue(
+  recordEnumeration(
       'NewTabPage.CustomizeChromeOpened', element,
       NtpCustomizeChromeEntryPoint.MAX_VALUE + 1);
 }
@@ -129,8 +137,11 @@ const AppElementBase = HelpBubbleMixinLit(CrLitElement);
 
 export interface AppElement {
   $: {
+    customizeButtons: CustomizeButtonsElement,
     oneGoogleBarClipPath: HTMLElement,
     logo: LogoElement,
+    searchbox: SearchboxElement,
+    composebox: ComposeboxElement,
   };
 }
 
@@ -156,10 +167,9 @@ export class AppElement extends AppElementBase {
       showCustomize_: {type: Boolean},
       showCustomizeChromeText_: {type: Boolean},
 
-      showWallpaperSearch_: {
-        type: Boolean,
-        reflect: true,
-      },
+      showWallpaperSearch_: {type: Boolean},
+
+      isFooterVisible_: {type: Boolean},
 
       selectedCustomizeDialogPage_: {type: String},
       showVoiceSearchOverlay_: {type: Boolean},
@@ -172,7 +182,6 @@ export class AppElement extends AppElementBase {
       backgroundImageAttribution1_: {type: String},
       backgroundImageAttribution2_: {type: String},
       backgroundImageAttributionUrl_: {type: String},
-      backgroundColor_: {type: Object},
 
       // Used in cr-searchbox component via host-context.
       colorSourceIsBaseline: {type: Boolean},
@@ -198,6 +207,15 @@ export class AppElement extends AppElementBase {
         notify: true,
       },
 
+      closingComposebox: {
+        type: Boolean,
+        reflect: true,
+      },
+      composeboxCloseByClickOutside_: {type: Boolean},
+      composeboxEnabled: {type: Boolean},
+      composeButtonEnabled: {type: Boolean},
+
+      browserPromosEnabled_: {type: Boolean},
       realboxShown_: {type: Boolean},
       logoEnabled_: {type: Boolean},
       oneGoogleBarEnabled_: {type: Boolean},
@@ -222,6 +240,11 @@ export class AppElement extends AppElementBase {
        */
       promoAndModulesLoaded_: {type: Boolean},
 
+      showComposebox_: {
+        type: Boolean,
+        reflect: true,
+      },
+
       showLensUploadDialog_: {type: Boolean},
 
       /**
@@ -232,78 +255,91 @@ export class AppElement extends AppElementBase {
 
       scrolledToTop_: {type: Boolean},
 
-      wallpaperSearchButtonAnimationEnabled_: {
-        type: Boolean,
-        reflect: true,
-      },
+      wallpaperSearchButtonAnimationEnabled_: {type: Boolean},
 
-      wallpaperSearchButtonEnabled_: {
-        type: Boolean,
-      },
+      wallpaperSearchButtonEnabled_: {type: Boolean},
 
-      showWallpaperSearchButton_: {
-        type: Boolean,
-        reflect: true,
-      },
+      showWallpaperSearchButton_: {type: Boolean},
+
+      /**
+       * Whether the composebox has been opened at least once.
+       */
+      wasComposeboxOpened_: {type: Boolean},
     };
   }
 
-  protected oneGoogleBarIframeOrigin_: string = OGB_IFRAME_ORIGIN;
-  protected oneGoogleBarIframePath_: string;
-  protected oneGoogleBarLoaded_: boolean;
-  protected theme_?: Theme;
-  protected showCustomize_: boolean;
-  protected showCustomizeChromeText_: boolean;
-  protected showWallpaperSearch_: boolean = false;
-  private selectedCustomizeDialogPage_: string|null;
-  protected showVoiceSearchOverlay_: boolean = false;
-  protected showBackgroundImage_: boolean;
-  protected backgroundImageAttribution1_: string;
-  protected backgroundImageAttribution2_: string;
-  protected backgroundImageAttributionUrl_: string;
-  protected backgroundColor_: SkColor|null;
-  protected colorSourceIsBaseline: boolean;
-  protected logoColor_: SkColor|null = null;
-  protected singleColoredLogo_: boolean;
-  realboxCanShowSecondarySide: boolean;
-  realboxHadSecondarySide: boolean;
-  protected realboxShown_: boolean;
-  protected showLensUploadDialog_: boolean = false;
-  protected logoEnabled_: boolean = loadTimeData.getBoolean('logoEnabled');
-  protected oneGoogleBarEnabled_: boolean =
+  protected accessor oneGoogleBarIframeOrigin_: string = OGB_IFRAME_ORIGIN;
+  protected accessor oneGoogleBarIframePath_: string|undefined;
+  protected accessor oneGoogleBarLoaded_: boolean = false;
+  protected accessor theme_: Theme|null = null;
+  protected accessor showCustomize_: boolean = false;
+  protected accessor showCustomizeChromeText_: boolean = false;
+  protected accessor showWallpaperSearch_: boolean = false;
+  private accessor selectedCustomizeDialogPage_: string|null = null;
+  protected accessor showVoiceSearchOverlay_: boolean = false;
+  protected accessor showBackgroundImage_: boolean = false;
+  protected accessor backgroundImageAttribution1_: string = '';
+  protected accessor backgroundImageAttribution2_: string = '';
+  protected accessor backgroundImageAttributionUrl_: string = '';
+  protected accessor colorSourceIsBaseline: boolean = false;
+  protected accessor logoColor_: SkColor|null = null;
+  protected accessor singleColoredLogo_: boolean = false;
+  accessor realboxCanShowSecondarySide: boolean = false;
+  accessor realboxHadSecondarySide: boolean = false;
+  protected accessor realboxShown_: boolean = false;
+  protected accessor wasComposeboxOpened_: boolean = false;
+  protected accessor showLensUploadDialog_: boolean = false;
+  protected accessor showComposebox_: boolean = false;
+  protected accessor logoEnabled_: boolean =
+      loadTimeData.getBoolean('logoEnabled');
+  protected accessor oneGoogleBarEnabled_: boolean =
       loadTimeData.getBoolean('oneGoogleBarEnabled');
-  protected shortcutsEnabled_: boolean =
+  protected accessor shortcutsEnabled_: boolean =
       loadTimeData.getBoolean('shortcutsEnabled');
-  private modulesFreShown: boolean;
-  protected middleSlotPromoEnabled_: boolean =
+  protected accessor middleSlotPromoEnabled_: boolean =
       loadTimeData.getBoolean('middleSlotPromoEnabled');
-  protected modulesEnabled_: boolean =
+  protected accessor modulesEnabled_: boolean =
       loadTimeData.getBoolean('modulesEnabled');
-  private middleSlotPromoLoaded_: boolean = false;
-  private modulesLoaded_: boolean = false;
-  protected modulesShownToUser: boolean;
-  protected microsoftModuleEnabled_: boolean =
+  protected accessor browserPromosEnabled_: boolean =
+      loadTimeData.getBoolean('browserPromosEnabled');
+  private accessor middleSlotPromoLoaded_: boolean = false;
+  private accessor modulesLoaded_: boolean = false;
+  protected accessor modulesShownToUser: boolean = false;
+  protected accessor microsoftModuleEnabled_: boolean =
       loadTimeData.getBoolean('microsoftModuleEnabled');
-  protected microsoftAuthIframePath_: string = MSAL_IFRAME_ORIGIN;
-  protected promoAndModulesLoaded_: boolean = false;
-  protected lazyRender_: boolean;
-  protected scrolledToTop_: boolean = document.documentElement.scrollTop <= 0;
-  private wallpaperSearchButtonAnimationEnabled_: boolean =
+  protected accessor microsoftAuthIframePath_: string = MSAL_IFRAME_ORIGIN;
+  protected accessor promoAndModulesLoaded_: boolean = false;
+  protected accessor lazyRender_: boolean = false;
+  protected accessor scrolledToTop_: boolean =
+      document.documentElement.scrollTop <= 0;
+  protected accessor wallpaperSearchButtonAnimationEnabled_: boolean =
       loadTimeData.getBoolean('wallpaperSearchButtonAnimationEnabled');
-  protected wallpaperSearchButtonEnabled_: boolean =
+  protected accessor wallpaperSearchButtonEnabled_: boolean =
       loadTimeData.getBoolean('wallpaperSearchButtonEnabled');
-  protected showWallpaperSearchButton_: boolean;
+  protected accessor showWallpaperSearchButton_: boolean = false;
+  accessor closingComposebox: boolean = false;
+  accessor composeButtonEnabled: boolean =
+      loadTimeData.getBoolean('searchboxShowComposeEntrypoint');
+  protected accessor composeboxCloseByClickOutside_: boolean =
+      loadTimeData.getBoolean('composeboxCloseByClickOutside');
+  accessor composeboxEnabled: boolean =
+      loadTimeData.getBoolean('searchboxShowComposebox');
+  protected accessor isFooterVisible_: boolean = false;
 
   private callbackRouter_: PageCallbackRouter;
   private pageHandler_: PageHandlerRemote;
+  private customizeButtonsCallbackRouter_:
+      CustomizeButtonsDocumentCallbackRouter;
+  private customizeButtonsHandler_: CustomizeButtonsHandlerRemote;
   private backgroundManager_: BackgroundManager;
   private connectMicrosoftAuthToParentDocumentListenerId_: number|null = null;
   private setThemeListenerId_: number|null = null;
   private setCustomizeChromeSidePanelVisibilityListener_: number|null = null;
   private setWallpaperSearchButtonVisibilityListener_: number|null = null;
+  private footerVisibilityUpdatedListener_: number|null = null;
   private eventTracker_: EventTracker = new EventTracker();
-  private shouldPrintPerformance_: boolean;
-  private backgroundImageLoadStartEpoch_: number;
+  private shouldPrintPerformance_: boolean = false;
+  private backgroundImageLoadStartEpoch_: number = 0;
   private backgroundImageLoadStart_: number = 0;
   private showWebstoreToastListenerId_: number|null = null;
 
@@ -312,6 +348,9 @@ export class AppElement extends AppElementBase {
     super();
     this.callbackRouter_ = NewTabPageProxy.getInstance().callbackRouter;
     this.pageHandler_ = NewTabPageProxy.getInstance().handler;
+    this.customizeButtonsCallbackRouter_ =
+        CustomizeButtonsProxy.getInstance().callbackRouter;
+    this.customizeButtonsHandler_ = CustomizeButtonsProxy.getInstance().handler;
     this.backgroundManager_ = BackgroundManager.getInstance();
     this.shouldPrintPerformance_ =
         new URLSearchParams(location.search).has('print_perf');
@@ -338,7 +377,7 @@ export class AppElement extends AppElementBase {
      */
     this.backgroundImageLoadStartEpoch_ = performance.timeOrigin;
 
-    chrome.metricsPrivate.recordValue(
+    recordValue(
         {
           metricName: 'NewTabPage.Height',
           type: chrome.metricsPrivate.MetricTypeType.HISTOGRAM_LINEAR,
@@ -347,7 +386,7 @@ export class AppElement extends AppElementBase {
           buckets: 200,
         },
         Math.floor(window.innerHeight));
-    chrome.metricsPrivate.recordValue(
+    recordValue(
         {
           metricName: 'NewTabPage.Width',
           type: chrome.metricsPrivate.MetricTypeType.HISTOGRAM_LINEAR,
@@ -382,20 +421,21 @@ export class AppElement extends AppElementBase {
           this.theme_ = theme;
         });
     this.setCustomizeChromeSidePanelVisibilityListener_ =
-        this.callbackRouter_.setCustomizeChromeSidePanelVisibility.addListener(
-            (visible: boolean) => {
-              this.showCustomize_ = visible;
-              if (!visible) {
-                this.showWallpaperSearch_ = false;
-              }
-            });
+        this.customizeButtonsCallbackRouter_
+            .setCustomizeChromeSidePanelVisibility.addListener(
+                (visible: boolean) => {
+                  this.showCustomize_ = visible;
+                  if (!visible) {
+                    this.showWallpaperSearch_ = false;
+                  }
+                });
     this.showWebstoreToastListenerId_ =
         this.callbackRouter_.showWebstoreToast.addListener(() => {
           if (this.showCustomize_) {
             const toast = $$<CrToastElement>(this, '#webstoreToast');
             if (toast) {
-              toast!.hidden = false;
-              toast!.show();
+              toast.hidden = false;
+              toast.show();
             }
           }
         });
@@ -412,6 +452,13 @@ export class AppElement extends AppElementBase {
               }
             });
 
+    this.footerVisibilityUpdatedListener_ =
+        this.callbackRouter_.footerVisibilityUpdated.addListener(
+            (visible: boolean) => {
+              this.isFooterVisible_ = visible;
+            });
+    this.pageHandler_.updateFooterVisibility();
+
     // Open Customize Chrome if there are Customize Chrome URL params.
     if (this.showCustomize_) {
       this.setCustomizeChromeSidePanelVisible_(this.showCustomize_);
@@ -454,6 +501,10 @@ export class AppElement extends AppElementBase {
           });
     }
     FocusOutlineManager.forDocument(document);
+    if (this.composeButtonEnabled) {
+      recordBoolean('NewTabPage.ComposeEntrypoint.Shown', true);
+      this.pageHandler_.incrementComposeButtonShownCount();
+    }
   }
 
   override disconnectedCallback() {
@@ -463,11 +514,12 @@ export class AppElement extends AppElementBase {
     this.callbackRouter_.removeListener(
         this.connectMicrosoftAuthToParentDocumentListenerId_!);
     this.callbackRouter_.removeListener(this.setThemeListenerId_!);
-    this.callbackRouter_.removeListener(
-        this.setCustomizeChromeSidePanelVisibilityListener_!);
     this.callbackRouter_.removeListener(this.showWebstoreToastListenerId_!);
     this.callbackRouter_.removeListener(
         this.setWallpaperSearchButtonVisibilityListener_!);
+    this.customizeButtonsCallbackRouter_.removeListener(
+        this.setCustomizeChromeSidePanelVisibilityListener_!);
+    this.callbackRouter_.removeListener(this.footerVisibilityUpdatedListener_!);
     this.eventTracker_.removeAll();
   }
 
@@ -501,8 +553,10 @@ export class AppElement extends AppElementBase {
       this.singleColoredLogo_ = this.computeSingleColoredLogo_();
     }
 
-    // theme_, showBackgroundImage_
-    this.backgroundColor_ = this.computeBackgroundColor_();
+    if (changedPrivateProperties.has('showComposebox_')) {
+      this.logoColor_ = this.computeLogoColor_();
+      this.singleColoredLogo_ = this.computeSingleColoredLogo_();
+    }
 
     // theme_, showLensUploadDialog_
     this.realboxShown_ = this.computeRealboxShown_();
@@ -545,16 +599,35 @@ export class AppElement extends AppElementBase {
     }
 
     if (changedPrivateProperties.has('oneGoogleBarLoaded_') ||
-        changedPrivateProperties.has('theme_')) {
+        changedPrivateProperties.has('theme_') ||
+        changedPrivateProperties.has('showComposebox_')) {
       this.updateOneGoogleBarAppearance_();
     }
+
+    if (changedPrivateProperties.has('showComposebox_')) {
+      if (this.showComposebox_) {
+        // Set Timeout since browser needs time to render the initial
+        // state before the final state is applied to run the transition.
+        setTimeout(() => {
+          const composeboxScrim =
+              this.shadowRoot.querySelector<HTMLElement>('#composeboxScrim');
+          assert(composeboxScrim);
+          composeboxScrim.classList.add('fade');
+        }, 0);
+      }
+    }
   }
 
   // Called to update the OGB of relevant NTP state changes.
   private updateOneGoogleBarAppearance_() {
     if (this.oneGoogleBarLoaded_) {
-      const isNtpDarkTheme =
-          this.theme_ && (!!this.theme_.backgroundImage || this.theme_.isDark);
+      let isNtpDarkTheme;
+      if (this.isComposeboxVisible_()) {
+        isNtpDarkTheme = this.theme_ && this.theme_.isDark;
+      } else {
+        isNtpDarkTheme = this.theme_ &&
+            (!!this.theme_.backgroundImage || this.theme_.isDark);
+      }
       $$<IframeElement>(this, '#oneGoogleBar')!.postMessage({
         type: 'updateAppearance',
         // We should be using a light OGB for dark themes and vice versa.
@@ -586,7 +659,8 @@ export class AppElement extends AppElementBase {
 
   private computeRealboxShown_(): boolean {
     // Do not show the realbox if the upload dialog is showing.
-    return !!this.theme_ && !this.showLensUploadDialog_;
+    return !!this.theme_ && !this.showLensUploadDialog_ &&
+        !this.isComposeboxVisible_();
   }
 
   private computePromoAndModulesLoaded_(): boolean {
@@ -599,16 +673,79 @@ export class AppElement extends AppElementBase {
     this.realboxCanShowSecondarySide = e.matches;
   }
 
-  private async onLazyRendered_() {
+  private onLazyRendered_() {
     // Integration tests use this attribute to determine when lazy load has
     // completed.
     document.documentElement.setAttribute('lazy-loaded', String(true));
-    this.registerHelpBubble(
-        CUSTOMIZE_CHROME_BUTTON_ELEMENT_ID, '#customizeButton', {fixed: true});
-    this.pageHandler_.maybeShowFeaturePromo(IphFeature.kCustomizeChrome);
-    if (this.showWallpaperSearchButton_) {
-      this.pageHandler_.incrementWallpaperSearchButtonShownCount();
+    if (!this.isFooterVisible_) {
+      this.registerHelpBubble(
+          CUSTOMIZE_CHROME_BUTTON_ELEMENT_ID,
+          ['ntp-customize-buttons', '#customizeButton'], {fixed: true});
+      this.pageHandler_.maybeShowFeaturePromo(IphFeature.kCustomizeChrome);
     }
+    if (this.showWallpaperSearchButton_) {
+      this.customizeButtonsHandler_.incrementWallpaperSearchButtonShownCount();
+    }
+  }
+
+  protected toggleComposebox_() {
+    this.showComposebox_ = !this.showComposebox_;
+    if (!this.wasComposeboxOpened_) {
+      recordLoadDuration(
+          'NewTabPage.Composebox.FromNTPLoadToSessionStart',
+          WindowProxy.getInstance().now());
+      this.wasComposeboxOpened_ = true;
+    }
+  }
+
+  protected onComposeboxClickOutside_() {
+    const composebox =
+        this.shadowRoot.querySelector<ComposeboxElement>('#composebox');
+    assert(composebox);
+    const closeComposebox = new CustomEvent('closeComposebox', {
+      detail: {composeboxText: composebox.getText()},
+      bubbles: true,
+      cancelable: true,
+    });
+
+    this.closeComposebox_(closeComposebox);
+  }
+
+  protected closeComposebox_(e: CustomEvent) {
+    const composeboxText = e.detail.composeboxText;
+
+    if (composeboxText && composeboxText.trim()) {
+      this.$.searchbox.setInputText(composeboxText);
+    }
+    const composebox =
+        this.shadowRoot.querySelector<ComposeboxElement>('#composebox');
+    assert(composebox);
+    composebox.resetText();
+    this.fadeoutScrim_();
+  }
+
+  private fadeoutScrim_() {
+    const composeboxScrim =
+        this.shadowRoot.querySelector<HTMLElement>('#composeboxScrim');
+    assert(composeboxScrim);
+    composeboxScrim.addEventListener('transitionend', (e: TransitionEvent) => {
+      if (e.propertyName === 'opacity') {  // Match the animation name
+        this.toggleComposebox_();
+        this.closingComposebox = false;
+      }
+    });
+    composeboxScrim.classList.remove('fade');
+    const composebox = this.shadowRoot.querySelector('#composebox');
+    assert(composebox);
+    composebox.classList.add('fade-out');
+    this.closingComposebox = true;
+    this.logoColor_ = this.computeLogoColor_();
+    this.singleColoredLogo_ = this.computeSingleColoredLogo_();
+    this.updateOneGoogleBarAppearance_();
+  }
+
+  private isComposeboxVisible_() {
+    return this.showComposebox_ && !this.closingComposebox;
   }
 
   protected onOpenVoiceSearch_() {
@@ -629,7 +766,7 @@ export class AppElement extends AppElementBase {
     this.selectedCustomizeDialogPage_ = null;
     this.setCustomizeChromeSidePanelVisible_(!this.showCustomize_);
     if (!this.showCustomize_) {
-      this.pageHandler_.incrementCustomizeChromeButtonOpenCount();
+      this.customizeButtonsHandler_.incrementCustomizeChromeButtonOpenCount();
       recordCustomizeChromeOpen(NtpCustomizeChromeEntryPoint.CUSTOMIZE_BUTTON);
     }
   }
@@ -664,7 +801,7 @@ export class AppElement extends AppElementBase {
     this.showWallpaperSearch_ = true;
     this.setCustomizeChromeSidePanelVisible_(this.showWallpaperSearch_);
     if (!this.showCustomize_) {
-      this.pageHandler_.incrementCustomizeChromeButtonOpenCount();
+      this.customizeButtonsHandler_.incrementCustomizeChromeButtonOpenCount();
       recordCustomizeChromeOpen(
           NtpCustomizeChromeEntryPoint.WALLPAPER_SEARCH_BUTTON);
     }
@@ -715,16 +852,16 @@ export class AppElement extends AppElementBase {
   }
 
   private onThemeLoaded_(theme: Theme) {
-    chrome.metricsPrivate.recordSparseValueWithPersistentHash(
+    recordSparseValueWithPersistentHash(
         'NewTabPage.Collections.IdOnLoad',
         theme.backgroundImageCollectionId ?? '');
 
     if (!theme.backgroundImage) {
-      chrome.metricsPrivate.recordEnumerationValue(
+      recordEnumeration(
           'NewTabPage.BackgroundImageSource', NtpBackgroundImageSource.kNoImage,
           NtpBackgroundImageSource.MAX_VALUE + 1);
     } else {
-      chrome.metricsPrivate.recordEnumerationValue(
+      recordEnumeration(
           'NewTabPage.BackgroundImageSource', theme.backgroundImage.imageSource,
           NtpBackgroundImageSource.MAX_VALUE + 1);
     }
@@ -763,14 +900,6 @@ export class AppElement extends AppElementBase {
     }
   }
 
-  private computeBackgroundColor_(): SkColor|null {
-    if (this.showBackgroundImage_ || !this.theme_) {
-      return null;
-    }
-
-    return this.theme_.backgroundColor;
-  }
-
   private computeColorSourceIsBaseline(): boolean {
     return !!this.theme_ && this.theme_.isBaseline;
   }
@@ -780,11 +909,18 @@ export class AppElement extends AppElementBase {
       return null;
     }
 
+    if (this.isComposeboxVisible_()) {
+      return this.theme_.isDark ? hexColorToSkColor('#ffffff') : null;
+    }
+
     return this.theme_.logoColor ||
         (this.theme_.isDark ? hexColorToSkColor('#ffffff') : null);
   }
 
   private computeSingleColoredLogo_(): boolean {
+    if (this.isComposeboxVisible_()) {
+      return !!this.theme_ && this.theme_.isDark;
+    }
     return !!this.theme_ && (!!this.theme_.logoColor || this.theme_.isDark);
   }
 
@@ -915,7 +1051,8 @@ export class AppElement extends AppElementBase {
         section = CustomizeChromeSection.kWallpaperSearch;
         break;
     }
-    this.pageHandler_.setCustomizeChromeSidePanelVisible(visible, section);
+    this.customizeButtonsHandler_.setCustomizeChromeSidePanelVisible(
+        visible, section, SidePanelOpenTrigger.kNewTabPage);
   }
 
   private printPerformanceDatum_(
@@ -984,14 +1121,24 @@ export class AppElement extends AppElementBase {
         case $$(this, '#modules'):
           recordClick(NtpElement.MODULE);
           return;
-        case $$(this, '#customizeButton'):
-          recordClick(NtpElement.CUSTOMIZE_BUTTON);
-          return;
-        case $$(this, '#wallpaperSearchButton'):
-          recordClick(NtpElement.WALLPAPER_SEARCH_BUTTON);
-          return;
       }
     }
+
+    const customizeButtonsElement =
+        this.shadowRoot.querySelector('ntp-customize-buttons');
+    if (customizeButtonsElement) {
+      for (const target of e.composedPath()) {
+        switch (target) {
+          case $$(customizeButtonsElement, '#customizeButton'):
+            recordClick(NtpElement.CUSTOMIZE_BUTTON);
+            return;
+          case $$(customizeButtonsElement, '#wallpaperSearchButton'):
+            recordClick(NtpElement.WALLPAPER_SEARCH_BUTTON);
+            return;
+        }
+      }
+    }
+
     recordClick(NtpElement.OTHER);
   }
 
