@@ -4,13 +4,20 @@
 
 /**
  * @fileoverview PasswordManagerProxy is an abstraction over
- * chrome.passwordsPrivate which facilitates testing.
+ * chrome.passwordsPrivate and a Mojo remote. It is intended to facilitate
+ * testing. The chrome.passwordsPrivate API is being migrated to use Mojo.
  */
 
+import {loadTimeData} from 'chrome://resources/js/load_time_data.js';
+
+import {PageCallbackRouter, PageHandlerFactory, PageHandlerRemote} from './password_manager.mojom-webui.js';
+
 export type BlockedSite = chrome.passwordsPrivate.ExceptionEntry;
 
 export type AccountStorageEnabledStateChangedListener =
     (enabledState: boolean) => void;
+export type ShouldShowAccountStorageToggleChangedListener = (show: boolean) =>
+    void;
 export type CredentialsChangedListener =
     (credentials: chrome.passwordsPrivate.PasswordUiEntry[]) => void;
 export type PasswordCheckStatusChangedListener =
@@ -27,8 +34,7 @@ export type PasswordManagerAuthTimeoutListener = () => void;
  * These values are persisted to logs. Entries should not be renumbered and
  * numeric values should never be reused.
  *
- * Needs to stay in sync with PasswordCheckInteraction in enums.xml and
- * password_manager_metrics_util.h.
+ * Needs to stay in sync with PasswordCheckInteraction in enums.xml.
  */
 export enum PasswordCheckInteraction {
   START_CHECK_AUTOMATICALLY = 0,
@@ -46,8 +52,7 @@ export enum PasswordCheckInteraction {
 }
 
 /**
- * Should be kept in sync with
- * |password_manager::metrics_util::PasswordViewPageInteractions|.
+ * Should be kept in sync with PasswordViewPageInteractions in enums.xml.
  * These values are persisted to logs. Entries should not be renumbered and
  * numeric values should never be reused.
  */
@@ -192,6 +197,14 @@ export interface PasswordManagerProxy {
       id: number,
       reason: chrome.passwordsPrivate.PlaintextReason): Promise<string>;
 
+  /**
+   * Copies the backup password for a specific ID to the clipboard.
+   * @param id The id for the password entry being being retrieved.
+   * @return A promise that resolves to `true` if the copy was successful, and
+   *     `false` otherwise.
+   */
+  copyPlaintextBackupPassword(id: number): Promise<boolean>;
+
   /**
    * Saves a new password entry described by the given |options|.
    * @param options Details about a new password and storage to be used.
@@ -232,6 +245,14 @@ export interface PasswordManagerProxy {
   removeCredential(
       id: number, fromStores: chrome.passwordsPrivate.PasswordStoreSet): void;
 
+  /**
+   * Should remove the backup password of a credential and notify that the list
+   * has changed.
+   * @param id The id for the credential being updated. No-op if |id| is not in
+   *     the list.
+   */
+  removeBackupPassword(id: number): void;
+
   /**
    * Should remove the blocked site and notify that the list has changed.
    * @param id The id for the blocked url entry being removed. No-op if |id|
@@ -353,6 +374,19 @@ export interface PasswordManagerProxy {
   removeAccountStorageEnabledStateListener(
       listener: AccountStorageEnabledStateChangedListener): void;
 
+  /**
+   * Add an observer to the account storage toggle visibility state.
+   */
+  addShouldShowAccountStorageSettingToggleListener(
+      listener: ShouldShowAccountStorageToggleChangedListener): void;
+
+
+  /**
+   * Remove an observer to the account storage toggle visibility state.
+   */
+  removeShouldShowAccountStorageSettingToggleListener(
+      listener: ShouldShowAccountStorageToggleChangedListener): void;
+
   /**
    * Requests the account-storage enabled state of the current user.
    * @return A promise that resolves to the enabled state.
@@ -365,6 +399,13 @@ export interface PasswordManagerProxy {
    */
   setAccountStorageEnabled(enabled: boolean): void;
 
+  /**
+   * Requests whether the account storage toggle should be shown.
+   * @return A promise that resolves to whether the toggle should be shown.
+   */
+  shouldShowAccountStorageSettingToggle(): Promise<boolean>;
+
+
   /**
    * Moves a list of passwords from the device to the account
    * @param ids The ids for the password entries being moved.
@@ -402,6 +443,16 @@ export interface PasswordManagerProxy {
  * Implementation that accesses the private API.
  */
 export class PasswordManagerImpl implements PasswordManagerProxy {
+  callbackRouter: PageCallbackRouter = new PageCallbackRouter();
+  handler: PageHandlerRemote = new PageHandlerRemote();
+
+  constructor() {
+    const factory = PageHandlerFactory.getRemote();
+    factory.createPageHandler(
+        this.callbackRouter.$.bindNewPipeAndPassRemote(),
+        this.handler.$.bindNewPipeAndPassReceiver());
+  }
+
   addSavedPasswordListChangedListener(listener: CredentialsChangedListener) {
     chrome.passwordsPrivate.onSavedPasswordsListChanged.addListener(listener);
   }
@@ -495,6 +546,11 @@ export class PasswordManagerImpl implements PasswordManagerProxy {
     return chrome.passwordsPrivate.requestPlaintextPassword(id, reason);
   }
 
+  copyPlaintextBackupPassword(id: number) {
+    return this.handler.copyPlaintextBackupPassword(id).then(
+        result => result.success);
+  }
+
   addPassword(options: chrome.passwordsPrivate.AddPasswordOptions) {
     return chrome.passwordsPrivate.addPassword(options);
   }
@@ -508,6 +564,10 @@ export class PasswordManagerImpl implements PasswordManagerProxy {
     chrome.passwordsPrivate.removeCredential(id, fromStores);
   }
 
+  removeBackupPassword(id: number) {
+    this.handler.removeBackupPassword(id);
+  }
+
   removeBlockedSite(id: number) {
     chrome.passwordsPrivate.removePasswordException(id);
   }
@@ -605,6 +665,18 @@ export class PasswordManagerImpl implements PasswordManagerProxy {
         listener);
   }
 
+  addShouldShowAccountStorageSettingToggleListener(
+      listener: ShouldShowAccountStorageToggleChangedListener) {
+    chrome.passwordsPrivate.onShouldShowAccountStorageSettingToggleChanged
+        .addListener(listener);
+  }
+
+  removeShouldShowAccountStorageSettingToggleListener(
+      listener: ShouldShowAccountStorageToggleChangedListener) {
+    chrome.passwordsPrivate.onShouldShowAccountStorageSettingToggleChanged
+        .removeListener(listener);
+  }
+
   isAccountStorageEnabled() {
     return chrome.passwordsPrivate.isAccountStorageEnabled();
   }
@@ -613,6 +685,10 @@ export class PasswordManagerImpl implements PasswordManagerProxy {
     chrome.passwordsPrivate.setAccountStorageEnabled(enabled);
   }
 
+  shouldShowAccountStorageSettingToggle() {
+    return chrome.passwordsPrivate.shouldShowAccountStorageSettingToggle();
+  }
+
   movePasswordsToAccount(ids: number[]) {
     chrome.passwordsPrivate.movePasswordsToAccount(ids);
   }
@@ -638,15 +714,18 @@ export class PasswordManagerImpl implements PasswordManagerProxy {
   }
 
   deleteAllPasswordManagerData() {
-    return chrome.passwordsPrivate.deleteAllPasswordManagerData();
+    return loadTimeData.getBoolean('enablePasswordManagerMojoApi') ?
+        this.handler.deleteAllPasswordManagerData().then(
+            result => result.success) :
+        chrome.passwordsPrivate.deleteAllPasswordManagerData();
   }
 
   static getInstance(): PasswordManagerProxy {
     return instance || (instance = new PasswordManagerImpl());
   }
 
-  static setInstance(obj: PasswordManagerProxy) {
-    instance = obj;
+  static setInstance(proxy: PasswordManagerProxy) {
+    instance = proxy;
   }
 }
 
