@@ -8,7 +8,6 @@ import './shared_style.css.js';
 import './prefs/pref_toggle_button.js';
 import './user_utils_mixin.js';
 import '/shared/settings/controls/extension_controlled_indicator.js';
-import './dialogs/move_passwords_dialog.js';
 import './dialogs/disconnect_cloud_authenticator_dialog.js';
 
 import {PrefsMixin} from '/shared/settings/prefs/prefs_mixin.js';
@@ -24,27 +23,27 @@ import {PluralStringProxyImpl} from 'chrome://resources/js/plural_string_proxy.j
 import type {DomRepeatEvent} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 import {PolymerElement} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 
-import {MoveToAccountStoreTrigger} from './dialogs/move_passwords_dialog.js';
 // <if expr="is_win or is_macosx">
 import {PasskeysBrowserProxyImpl} from './passkeys_browser_proxy.js';
 // </if>
-import type {BlockedSite, BlockedSitesListChangedListener, CredentialsChangedListener} from './password_manager_proxy.js';
+import type {BlockedSite, BlockedSitesListChangedListener, CredentialsChangedListener, ShouldShowAccountStorageToggleChangedListener} from './password_manager_proxy.js';
 import {PasswordManagerImpl} from './password_manager_proxy.js';
 import type {PrefToggleButtonElement} from './prefs/pref_toggle_button.js';
 import type {Route} from './router.js';
-import {RouteObserverMixin, Router, UrlParam} from './router.js';
+import {Page, RouteObserverMixin, Router, UrlParam} from './router.js';
 import {getTemplate} from './settings_section.html.js';
 import {BatchUploadPasswordsEntryPoint, SyncBrowserProxyImpl, TrustedVaultBannerState} from './sync_browser_proxy.js';
 import {UserUtilMixin} from './user_utils_mixin.js';
 
 export interface SettingsSectionElement {
   $: {
+    accountStorageToggle: PrefToggleButtonElement,
     autosigninToggle: PrefToggleButtonElement,
     blockedSitesList: HTMLElement,
+    passkeyUpgradeToggle: PrefToggleButtonElement,
     passwordToggle: PrefToggleButtonElement,
-    trustedVaultBanner: CrLinkRowElement,
-    accountStorageToggle: PrefToggleButtonElement,
     toast: CrToastElement,
+    trustedVaultBanner: CrLinkRowElement,
   };
 }
 
@@ -85,6 +84,20 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
       },
       // </if>
 
+      isPasskeyUpgradeSettingsToggleVisible_: {
+        type: Boolean,
+        value() {
+          return loadTimeData.getBoolean('passkeyUpgradeSettingsToggleVisible');
+        },
+      },
+
+      isAutomatedPasswordChangeVisible_: {
+        type: Boolean,
+        value() {
+          return loadTimeData.getBoolean('passwordChangeAvailable');
+        },
+      },
+
       hasPasswordsToExport_: {
         type: Boolean,
         value: false,
@@ -108,6 +121,11 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
         value: TrustedVaultBannerState.NOT_SHOWN,
       },
 
+      movePasswordsLabel_: {
+        type: String,
+        value: '',
+      },
+
       canAddShortcut_: {
         type: Boolean,
         value() {
@@ -115,12 +133,6 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
         },
       },
 
-      showMovePasswordsDialog_: Boolean,
-
-      passwordsOnDevice_: {
-        type: Array,
-      },
-
       isPasswordManagerPinAvailable_: {
         type: Boolean,
         value: false,
@@ -136,54 +148,65 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
         value: false,
       },
 
+      toastMessage_: {
+        type: String,
+        value: '',
+      },
+
       showDisconnectCloudAuthenticatorDialog_: {
         type: Boolean,
         value: false,
       },
 
-      isDeleteAllPasswordManagerDataRowAvailable_: {
-        type: Boolean,
-        value() {
-          return loadTimeData.getBoolean('enableWebAuthnGpmPin');
-        },
-      },
-
       localPasswordCount_: {
         type: Number,
         value: 0,
       },
+
+      shouldShowAccountStorageSettingToggle_: {
+        type: Boolean,
+        value: false,
+      },
     };
   }
 
   static get observers() {
     return [
-      'updateIsPasswordManagerPinAvailable_(isSyncingPasswords)',
-      'updateIsCloudAuthenticatorConnected_(isSyncingPasswords)',
+      'updateIsPasswordManagerPinAvailable_(' +
+          'isSyncingPasswords, isAccountStoreUser)',
+      'updateIsCloudAuthenticatorConnected_(' +
+          'isSyncingPasswords, isAccountStoreUser)',
     ];
   }
 
-  private blockedSites_: BlockedSite[];
-  private hasPasskeys_: boolean;
-  private hasPasswordsToExport_: boolean;
-  private showPasswordsImporter_: boolean;
-  private showMovePasswordsDialog_: boolean;
-  private trustedVaultBannerState_: TrustedVaultBannerState;
-  private movePasswordsLabel_: string;
-  private passwordsOnDevice_: chrome.passwordsPrivate.PasswordUiEntry[] = [];
-  private isPasswordManagerPinAvailable_: boolean = false;
-  private isConnectedToCloudAuthenticator_: boolean = false;
-  private isDisconnectCloudAuthenticatorInProgress_: boolean = false;
-  private toastMessage_: string = '';
-  private showDisconnectCloudAuthenticatorDialog_: boolean = false;
-  private isDeleteAllPasswordManagerDataRowAvailable_: boolean;
+  declare private blockedSites_: BlockedSite[];
+  // <if expr="is_win or is_macosx or is_chromeos">
+  declare private isBiometricAuthenticationForFillingToggleVisible_: boolean;
+  // </if>
+  declare private hasPasskeys_: boolean;
+  declare private passwordManagerDisabled_: boolean;
+  declare private hasPasswordsToExport_: boolean;
+  declare private isPasskeyUpgradeSettingsToggleVisible_: boolean;
+  declare private isAutomatedPasswordChangeVisible_: boolean;
+  declare private canAddShortcut_: boolean;
+  declare private trustedVaultBannerState_: TrustedVaultBannerState;
+  declare private movePasswordsLabel_: string;
+  declare private isPasswordManagerPinAvailable_: boolean;
+  declare private isConnectedToCloudAuthenticator_: boolean;
+  declare private isDisconnectCloudAuthenticatorInProgress_: boolean;
+  declare private toastMessage_: string;
+  declare private showDisconnectCloudAuthenticatorDialog_: boolean;
   // This variable depend on the sync service API, which the Batch Upload Dialog
   // uses.
-  private localPasswordCount_: number = 0;
+  declare private localPasswordCount_: number;
+  declare private shouldShowAccountStorageSettingToggle_: boolean;
 
   private setBlockedSitesListListener_: BlockedSitesListChangedListener|null =
       null;
   private setCredentialsChangedListener_: CredentialsChangedListener|null =
       null;
+  private shouldShowAccountStorageSettingToggleListener_:
+      ShouldShowAccountStorageToggleChangedListener|null = null;
 
   override ready() {
     super.ready();
@@ -200,11 +223,7 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
       this.updateLocalPasswordCount_(localPasswordCount);
     };
     const syncBrowserProxy = SyncBrowserProxyImpl.getInstance();
-    if (loadTimeData.getBoolean('isBatchUploadDesktopEnabled')) {
-      syncBrowserProxy.getLocalPasswordCount().then(updateLocalPasswordCount);
-    } else {
-      this.updatePasswordsOnDevice_();
-    }
+    syncBrowserProxy.getLocalPasswordCount().then(updateLocalPasswordCount);
 
     this.setBlockedSitesListListener_ = blockedSites => {
       this.blockedSites_ = blockedSites;
@@ -214,31 +233,34 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
     PasswordManagerImpl.getInstance().addBlockedSitesListChangedListener(
         this.setBlockedSitesListListener_);
 
-    if (loadTimeData.getBoolean('isBatchUploadDesktopEnabled')) {
-      this.addWebUiListener(
-          'sync-service-local-password-count', updateLocalPasswordCount);
-    }
+    this.addWebUiListener(
+        'sync-service-local-password-count', updateLocalPasswordCount);
 
     this.setCredentialsChangedListener_ =
         (passwords: chrome.passwordsPrivate.PasswordUiEntry[]) => {
           this.hasPasswordsToExport_ = passwords.length > 0;
-
-          if (loadTimeData.getBoolean('isBatchUploadDesktopEnabled')) {
-            // Update the local password count based on the SyncService API
-            // whenever the password list was modified.
-            syncBrowserProxy.getLocalPasswordCount().then(
-                (localPasswordCount: number) => {
-                  this.updateLocalPasswordCount_(localPasswordCount);
-                });
-          } else {
-            this.updatePasswordsOnDevice_();
-          }
+          // Update the local password count based on the SyncService API
+          // whenever the password list was modified.
+          syncBrowserProxy.getLocalPasswordCount().then(
+              (localPasswordCount: number) => {
+                this.updateLocalPasswordCount_(localPasswordCount);
+              });
         };
     PasswordManagerImpl.getInstance().getSavedPasswordList().then(
         this.setCredentialsChangedListener_);
     PasswordManagerImpl.getInstance().addSavedPasswordListChangedListener(
         this.setCredentialsChangedListener_);
 
+    this.shouldShowAccountStorageSettingToggleListener_ = show => {
+      this.shouldShowAccountStorageSettingToggle_ = show;
+    };
+    PasswordManagerImpl.getInstance()
+        .shouldShowAccountStorageSettingToggle()
+        .then(this.shouldShowAccountStorageSettingToggleListener_);
+    PasswordManagerImpl.getInstance()
+        .addShouldShowAccountStorageSettingToggleListener(
+            this.shouldShowAccountStorageSettingToggleListener_);
+
     const trustedVaultStateChanged = (state: TrustedVaultBannerState) => {
       this.trustedVaultBannerState_ = state;
     };
@@ -277,6 +299,13 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
     PasswordManagerImpl.getInstance().removeSavedPasswordListChangedListener(
         this.setCredentialsChangedListener_);
     this.setCredentialsChangedListener_ = null;
+
+    assert(this.shouldShowAccountStorageSettingToggleListener_);
+    PasswordManagerImpl.getInstance()
+        .removeShouldShowAccountStorageSettingToggleListener(
+            this.shouldShowAccountStorageSettingToggleListener_);
+    this.shouldShowAccountStorageSettingToggleListener_ = null;
+
     this.$.toast.hide();
   }
 
@@ -322,7 +351,7 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
   // <if expr="is_win or is_macosx or is_chromeos">
   private switchBiometricAuthBeforeFillingState_(e: Event) {
     const biometricAuthenticationForFillingToggle =
-        e!.target as PrefToggleButtonElement;
+        e.target as PrefToggleButtonElement;
     assert(biometricAuthenticationForFillingToggle);
     PasswordManagerImpl.getInstance().switchBiometricAuthBeforeFillingState();
   }
@@ -380,7 +409,7 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
   }
 
   private changeAccountStorageEnabled_() {
-    if (this.isAccountStorageEnabled) {
+    if (this.isAccountStoreUser) {
       this.disableAccountStorage();
     } else {
       this.enableAccountStorage();
@@ -415,33 +444,15 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
 
   private onMovePasswordsClicked_(e: Event) {
     e.preventDefault();
-    if (loadTimeData.getBoolean('isBatchUploadDesktopEnabled')) {
-      SyncBrowserProxyImpl.getInstance().openBatchUpload(
-          BatchUploadPasswordsEntryPoint.PASSWORD_MANAGER);
-      return;
-    }
-
-    this.showMovePasswordsDialog_ = true;
-  }
-
-  private onMovePasswordsDialogClose_() {
-    this.showMovePasswordsDialog_ = false;
-  }
-
-  private getMovePasswordsDialogTrigger_(): MoveToAccountStoreTrigger {
-    return MoveToAccountStoreTrigger
-        .EXPLICITLY_TRIGGERED_FOR_MULTIPLE_PASSWORDS_IN_SETTINGS;
+    SyncBrowserProxyImpl.getInstance().openBatchUpload(
+        BatchUploadPasswordsEntryPoint.PASSWORD_MANAGER);
   }
 
   private shouldShowMovePasswordsEntry_(): boolean {
-    if (loadTimeData.getBoolean('isBatchUploadDesktopEnabled')) {
-      // Only show the move password entry if there are passwords returned from
-      // the sync service API. This is needed to be consistent with the
-      // availability of data in the dialog which uses the same API.
-      return this.localPasswordCount_ > 0;
-    }
-
-    return this.isAccountStoreUser && this.passwordsOnDevice_.length > 0;
+    // Only show the move password entry if there are passwords returned from
+    // the sync service API. This is needed to be consistent with the
+    // availability of data in the dialog which uses the same API.
+    return this.localPasswordCount_ > 0;
   }
 
   private getAriaLabelMovePasswordsButton_(): string {
@@ -461,28 +472,10 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
             'deviceOnlyPasswordsIconTooltip', this.localPasswordCount_);
   }
 
-  private async updatePasswordsOnDevice_() {
-    const groups =
-        await PasswordManagerImpl.getInstance().getCredentialGroups();
-    const localStorage = [
-      chrome.passwordsPrivate.PasswordStoreSet.DEVICE_AND_ACCOUNT,
-      chrome.passwordsPrivate.PasswordStoreSet.DEVICE,
-    ];
-
-    this.passwordsOnDevice_ =
-        groups.map(group => group.entries)
-            .flat()
-            .filter(entry => localStorage.includes(entry.storedIn));
-
-    this.movePasswordsLabel_ =
-        await PluralStringProxyImpl.getInstance().getPluralString(
-            'deviceOnlyPasswordsIconTooltip', this.passwordsOnDevice_.length);
-  }
-
   private updateIsPasswordManagerPinAvailable_() {
     PasswordManagerImpl.getInstance().isPasswordManagerPinAvailable().then(
         available => this.isPasswordManagerPinAvailable_ =
-            available && this.isSyncingPasswords);
+            available && (this.isSyncingPasswords || this.isAccountStoreUser));
   }
 
   private onChangePasswordManagerPinRowClick_() {
@@ -493,7 +486,7 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
   private updateIsCloudAuthenticatorConnected_() {
     PasswordManagerImpl.getInstance().isConnectedToCloudAuthenticator().then(
         connected => this.isConnectedToCloudAuthenticator_ =
-            connected && this.isSyncingPasswords);
+            connected && (this.isSyncingPasswords || this.isAccountStoreUser));
   }
 
   private onDisconnectCloudAuthenticatorClick_() {
@@ -532,6 +525,17 @@ export class SettingsSectionElement extends SettingsSectionElementBase {
     this.toastMessage_ = this.i18n('passwordManagerPinChanged');
     this.$.toast.show();
   }
+
+  private onAutomatedPasswordChangeClick_() {
+    Router.getInstance().navigateTo(Page.PASSWORD_CHANGE);
+  }
+
+  private getAriaLabelForAutomatedPasswordChange_(): string {
+    return [
+      this.i18n('automatedPasswordChangeTitle'),
+      this.i18n('automatedPasswordChangeDescription'),
+    ].join('. ');
+  }
 }
 
 declare global {
