@@ -8,6 +8,9 @@ import 'chrome://resources/cr_elements/cr_progress/cr_progress.js';
 import './icons.html.js';
 import './viewer_download_controls.js';
 import './viewer_page_selector.js';
+// <if expr="enable_pdf_save_to_drive">
+import './viewer_save_to_drive_controls.js';
+// </if>
 import './shared_vars.css.js';
 // <if expr="enable_ink">
 import './viewer_annotations_bar.js';
@@ -22,9 +25,13 @@ import {assert} from 'chrome://resources/js/assert.js';
 import {EventTracker} from 'chrome://resources/js/event_tracker.js';
 // </if>
 import {loadTimeData} from 'chrome://resources/js/load_time_data.js';
+import type {LoadTimeDataRaw} from 'chrome://resources/js/load_time_data.js';
 import {CrLitElement} from 'chrome://resources/lit/v3_0/lit.rollup.js';
 import type {PropertyValues} from 'chrome://resources/lit/v3_0/lit.rollup.js';
 
+// <if expr="enable_pdf_ink2 or enable_ink">
+import {AnnotationMode} from '../constants.js';
+// </if>
 import {FittingType, FormFieldFocusType} from '../constants.js';
 // <if expr="enable_pdf_ink2">
 import {PluginController, PluginControllerEventType} from '../controller.js';
@@ -36,7 +43,9 @@ import {getHtml} from './viewer_toolbar.html.js';
 
 declare global {
   interface HTMLElementEventMap {
-    'annotation-mode-toggled': CustomEvent<boolean>;
+    // <if expr="enable_pdf_ink2 or enable_ink">
+    'annotation-mode-updated': CustomEvent<AnnotationMode>;
+    // </if>
     'display-annotations-changed': CustomEvent<boolean>;
     'fit-to-changed': CustomEvent<FittingType>;
   }
@@ -66,27 +75,11 @@ export class ViewerToolbarElement extends CrLitElement {
 
   static override get properties() {
     return {
-      // <if expr="enable_ink or enable_pdf_ink2">
-      annotationAvailable: {type: Boolean},
-      annotationMode: {
-        type: Boolean,
-        reflect: true,
-      },
-      // </if>
-
-      // <if expr="enable_pdf_ink2">
-      canRedoAnnotation_: {type: Boolean},
-      canUndoAnnotation_: {type: Boolean},
-      // </if>
-
       docTitle: {type: String},
       docLength: {type: Number},
       embeddedViewer: {type: Boolean},
       hasEdits: {type: Boolean},
       hasEnteredAnnotationMode: {type: Boolean},
-      // <if expr="enable_pdf_ink2">
-      hasInk2Edits: {type: Boolean},
-      // </if>
       formFieldFocus: {type: String},
       loadProgress: {type: Number},
 
@@ -96,13 +89,7 @@ export class ViewerToolbarElement extends CrLitElement {
       },
 
       pageNo: {type: Number},
-      pdfAnnotationsEnabled: {type: Boolean},
-      pdfCr23Enabled: {type: Boolean},
-      // <if expr="enable_pdf_ink2">
-      pdfInk2Enabled: {type: Boolean},
-      // </if>
 
-      printingEnabled: {type: Boolean},
       rotated: {type: Boolean},
       strings: {type: Object},
       viewportZoom: {type: Number},
@@ -115,57 +102,90 @@ export class ViewerToolbarElement extends CrLitElement {
         reflect: true,
       },
 
+      displayAnnotations_: {type: Boolean},
       fittingType_: {type: Number},
+      printingEnabled_: {type: Boolean},
       viewportZoomPercent_: {type: Number},
 
+      // <if expr="enable_ink or enable_pdf_ink2">
+      annotationAvailable: {type: Boolean},
+      annotationMode: {
+        type: String,
+        reflect: true,
+      },
+      // </if>
+
       // <if expr="enable_ink">
+      pdfInk1AnnotationsEnabled_: {type: Boolean},
       showAnnotationsModeDialog_: {type: Boolean},
-      // </if> enable_ink
+      // </if>
+
+      // <if expr="enable_pdf_ink2">
+      enableUndoRedo: {type: Boolean},
+      hasInk2Edits: {type: Boolean},
+      pdfInk2Enabled: {type: Boolean},
+      canRedoAnnotation_: {type: Boolean},
+      canUndoAnnotation_: {type: Boolean},
+      pdfTextAnnotationsEnabled_: {type: Boolean},
+      // </if>
+
+      // <if expr="enable_pdf_save_to_drive">
+      pdfSaveToDriveEnabled: {type: Boolean},
+      // </if> enable_pdf_save_to_drive
     };
   }
 
-  docTitle: string = '';
-  docLength: number = 0;
-  embeddedViewer: boolean = false;
-  hasEdits: boolean = false;
-  hasEnteredAnnotationMode: boolean = false;
-  // <if expr="enable_pdf_ink2">
-  hasInk2Edits: boolean = false;
-  // </if>
-  formFieldFocus: FormFieldFocusType = FormFieldFocusType.NONE;
-  loadProgress: number = 0;
-  pageNo: number = 0;
-  pdfAnnotationsEnabled: boolean = false;
-  pdfCr23Enabled: boolean = false;
-  printingEnabled: boolean = false;
-  rotated: boolean = false;
-  strings?: {[key: string]: string};
-  viewportZoom: number = 0;
-  zoomBounds: {min: number, max: number} = {min: 0, max: 0};
-  sidenavCollapsed: boolean = false;
-  twoUpViewEnabled: boolean = false;
-  protected displayAnnotations_: boolean = true;
-  private fittingType_: FittingType = FittingType.FIT_TO_PAGE;
-  protected moreMenuOpen_: boolean = false;
-  protected loading_: boolean = true;
-  private viewportZoomPercent_: number = 0;
+  accessor docTitle: string = '';
+  accessor docLength: number = 0;
+  accessor embeddedViewer: boolean = false;
+  accessor hasEdits: boolean = false;
+  accessor hasEnteredAnnotationMode: boolean = false;
+  accessor formFieldFocus: FormFieldFocusType = FormFieldFocusType.NONE;
+  accessor loadProgress: number = 0;
+  accessor pageNo: number = 0;
+  accessor rotated: boolean = false;
+  accessor strings: LoadTimeDataRaw|undefined;
+  accessor viewportZoom: number = 0;
+  accessor zoomBounds: {min: number, max: number} = {min: 0, max: 0};
+  accessor sidenavCollapsed: boolean = false;
+  accessor twoUpViewEnabled: boolean = false;
+  protected accessor displayAnnotations_: boolean = true;
+  private accessor fittingType_: FittingType = FittingType.FIT_TO_PAGE;
+  protected accessor moreMenuOpen_: boolean = false;
+  protected accessor loading_: boolean = true;
+  protected accessor printingEnabled_: boolean = false;
+  private accessor viewportZoomPercent_: number = 0;
 
   // <if expr="enable_ink or enable_pdf_ink2">
-  annotationAvailable: boolean = false;
-  annotationMode: boolean = false;
+  // Reactive properties common to ink and ink2
+  accessor annotationAvailable: boolean = false;
+  accessor annotationMode: AnnotationMode = AnnotationMode.OFF;
   // </if>
 
   // <if expr="enable_ink">
-  protected showAnnotationsModeDialog_: boolean = false;
+  // Ink reactive properties
+  private accessor pdfInk1AnnotationsEnabled_: boolean = false;
+  protected accessor showAnnotationsModeDialog_: boolean = false;
   // </if>
 
+  // <if expr="enable_pdf_save_to_drive">
+  accessor pdfSaveToDriveEnabled: boolean = false;
+  // </if> enable_pdf_save_to_drive
+
   // <if expr="enable_pdf_ink2">
-  pdfInk2Enabled: boolean = false;
-  protected canRedoAnnotation_: boolean = false;
-  protected canUndoAnnotation_: boolean = false;
+  // Ink2 reactive properties
+  accessor enableUndoRedo: boolean = true;
+  accessor hasInk2Edits: boolean = false;
+  accessor pdfInk2Enabled: boolean = false;
+  protected accessor canRedoAnnotation_: boolean = false;
+  protected accessor canUndoAnnotation_: boolean = false;
+  protected accessor pdfTextAnnotationsEnabled_: boolean = false;
+
+  // Ink2 class members
   private currentStroke: number = 0;
   private mostRecentStroke: number = 0;
   private pluginController_: PluginController = PluginController.getInstance();
+  private strokeInProgress_: boolean = false;
   private tracker_: EventTracker = new EventTracker();
 
   constructor() {
@@ -175,6 +195,10 @@ export class ViewerToolbarElement extends CrLitElement {
         this.pluginController_.getEventTarget(),
         PluginControllerEventType.FINISH_INK_STROKE,
         this.handleFinishInkStroke_.bind(this));
+    this.tracker_.add(
+        this.pluginController_.getEventTarget(),
+        PluginControllerEventType.START_INK_STROKE,
+        this.handleStartInkStroke_.bind(this));
   }
   // </if>
 
@@ -185,6 +209,10 @@ export class ViewerToolbarElement extends CrLitElement {
       this.loading_ = this.loadProgress < 100;
     }
 
+    if (changedProperties.has('strings') && this.strings) {
+      this.updateLoadTimeData_();
+    }
+
     if (changedProperties.has('viewportZoom')) {
       this.viewportZoomPercent_ = Math.round(100 * this.viewportZoom);
     }
@@ -205,35 +233,29 @@ export class ViewerToolbarElement extends CrLitElement {
     }
   }
 
+  private updateLoadTimeData_() {
+    this.printingEnabled_ = loadTimeData.getBoolean('printingEnabled');
+    // <if expr="enable_ink">
+    this.pdfInk1AnnotationsEnabled_ =
+        loadTimeData.getBoolean('pdfInk1AnnotationsEnabled');
+    // </if>
+    // <if expr="enable_pdf_ink2">
+    this.pdfTextAnnotationsEnabled_ =
+        loadTimeData.getBoolean('pdfTextAnnotationsEnabled');
+    // </if>
+  }
+
   protected onSidenavToggleClick_() {
     record(UserAction.TOGGLE_SIDENAV);
     this.dispatchEvent(new CustomEvent('sidenav-toggle-click'));
   }
 
-  protected iconsetName_(): string {
-    return this.pdfCr23Enabled ? 'pdf-cr23' : 'pdf';
-  }
-
   protected fitToButtonIcon_(): string {
-    return this.iconsetName_() +
+    return 'pdf' +
         (this.fittingType_ === FittingType.FIT_TO_PAGE ? ':fit-to-height' :
                                                          ':fit-to-width');
   }
 
-  // TODO(crbug.com/360265881): Remove conditional icons after the UI refresh
-  // fully launches.
-  protected menuIcon_(): string {
-    return this.pdfCr23Enabled ? 'pdf-cr23:menu' : 'cr20:menu';
-  }
-
-  protected moreIcon_(): string {
-    return this.pdfCr23Enabled ? 'pdf-cr23:more' : 'cr:more-vert';
-  }
-
-  protected printIcon_(): string {
-    return this.pdfCr23Enabled ? 'pdf-cr23:print' : 'cr:print';
-  }
-
   /** @return The appropriate tooltip for the current state. */
   protected getFitToButtonTooltip_() {
     if (!this.strings) {
@@ -252,19 +274,19 @@ export class ViewerToolbarElement extends CrLitElement {
     }
     // </if> enable_pdf_ink2
 
-    return this.pdfAnnotationsEnabled;
+    return this.pdfInk1AnnotationsEnabled_;
   }
   // </if> enable_ink
 
   // <if expr="enable_pdf_ink2">
   protected showInk2Buttons_(): boolean {
-    return this.pdfInk2Enabled && this.pdfAnnotationsEnabled;
+    return this.pdfInk2Enabled;
   }
   // </if>
 
   // <if expr="enable_ink">
   protected showAnnotationsBar_(): boolean {
-    return this.pdfAnnotationsEnabled && !this.loading_ &&
+    return this.pdfInk1AnnotationsEnabled_ && !this.loading_ &&
         this.isInInk1AnnotationMode_();
   }
 
@@ -275,7 +297,7 @@ export class ViewerToolbarElement extends CrLitElement {
     }
     // </if> enable_pdf_ink2
 
-    return this.annotationMode;
+    return this.annotationMode === AnnotationMode.DRAW;
   }
   // </if> enable_ink
 
@@ -295,8 +317,9 @@ export class ViewerToolbarElement extends CrLitElement {
     this.$.menu.close();
 
     // <if expr="enable_ink">
-    if (!this.displayAnnotations_ && this.annotationMode) {
-      this.toggleAnnotation();
+    if (!this.displayAnnotations_ &&
+        this.annotationMode === AnnotationMode.DRAW) {
+      this.setAnnotationMode(AnnotationMode.OFF);
     }
     // </if>
   }
@@ -358,7 +381,7 @@ export class ViewerToolbarElement extends CrLitElement {
   }
 
   private getZoomInput_(): HTMLInputElement {
-    return this.shadowRoot!.querySelector('#zoom-controls input')!;
+    return this.shadowRoot.querySelector('#zoom-controls input')!;
   }
 
   protected onZoomChange_() {
@@ -396,7 +419,7 @@ export class ViewerToolbarElement extends CrLitElement {
   }
 
   protected onMoreClick_() {
-    const anchor = this.shadowRoot!.querySelector<HTMLElement>('#more')!;
+    const anchor = this.shadowRoot.querySelector<HTMLElement>('#more')!;
     this.$.menu.showAt(anchor, {
       anchorAlignmentX: AnchorAlignment.CENTER,
       anchorAlignmentY: AnchorAlignment.AFTER_END,
@@ -420,29 +443,41 @@ export class ViewerToolbarElement extends CrLitElement {
 
   // <if expr="enable_ink">
   protected onDialogClose_() {
+    // The dialog should only show if we are not in annotation mode and the
+    // user wants to transition to drawing annotations.
+    assert(this.annotationMode === AnnotationMode.OFF);
     const confirmed =
-        this.shadowRoot!.querySelector(
-                            'viewer-annotations-mode-dialog')!.wasConfirmed();
+        this.shadowRoot.querySelector(
+                           'viewer-annotations-mode-dialog')!.wasConfirmed();
     this.showAnnotationsModeDialog_ = false;
     if (confirmed) {
       this.dispatchEvent(new CustomEvent('annotation-mode-dialog-confirmed'));
-      this.toggleAnnotation();
+      this.setAnnotationMode(AnnotationMode.DRAW);
     }
   }
   // </if>
 
   // <if expr="enable_ink or enable_pdf_ink2">
+  // Gets a CSS class of "active" if `mode` is the active annotation mode.
+  protected getActive_(mode: AnnotationMode): string {
+    return mode === this.annotationMode ? 'active' : '';
+  }
+
   protected onAnnotationClick_() {
+    const newAnnotationMode = this.annotationMode === AnnotationMode.DRAW ?
+        AnnotationMode.OFF :
+        AnnotationMode.DRAW;
+
     // <if expr="enable_pdf_ink2">
     if (this.pdfInk2Enabled) {
-      this.toggleAnnotation();
+      this.setAnnotationMode(newAnnotationMode);
       return;
     }
     // </if> enable_pdf_ink2
 
     // <if expr="enable_ink">
     if (!this.rotated && !this.twoUpViewEnabled) {
-      this.toggleAnnotation();
+      this.setAnnotationMode(newAnnotationMode);
       return;
     }
 
@@ -450,10 +485,9 @@ export class ViewerToolbarElement extends CrLitElement {
     // </if> enable_ink
   }
 
-  toggleAnnotation() {
-    const newAnnotationMode = !this.annotationMode;
-    this.dispatchEvent(new CustomEvent(
-        'annotation-mode-toggled', {detail: newAnnotationMode}));
+  setAnnotationMode(annotationMode: AnnotationMode) {
+    this.dispatchEvent(
+        new CustomEvent('annotation-mode-updated', {detail: annotationMode}));
 
     // <if expr="enable_pdf_ink2">
     // Don't toggle display annotations for Ink2.
@@ -462,32 +496,63 @@ export class ViewerToolbarElement extends CrLitElement {
     }
     // </if> enable_pdf_ink2
 
-    if (newAnnotationMode && !this.displayAnnotations_) {
+    if (annotationMode !== AnnotationMode.OFF && !this.displayAnnotations_) {
       this.toggleDisplayAnnotations_();
     }
   }
   // </if> enable_ink or enable_pdf_ink2
 
   // <if expr="enable_pdf_ink2">
+  protected onTextAnnotationClick_() {
+    this.setAnnotationMode(
+        this.annotationMode === AnnotationMode.TEXT ? AnnotationMode.OFF :
+                                                      AnnotationMode.TEXT);
+  }
+
+  /**
+   * Handles when the user starts a stroke. While the stroke is in progress,
+   * disallow undo/redo operations.
+   */
+  private handleStartInkStroke_() {
+    this.strokeInProgress_ = true;
+  }
+
   /**
    * Handles whether the undo and redo buttons should be enabled or disabled
-   * when a new ink stroke is added to the page.
+   * when a new Ink stroke is added to or erased from the page. This event
+   * fires when stroking finishes, but not all strokes (e.g. eraser strokes)
+   * actually modify the page.
    */
-  private handleFinishInkStroke_() {
-    this.currentStroke++;
-    this.mostRecentStroke = this.currentStroke;
+  private handleFinishInkStroke_(e: CustomEvent<boolean>) {
+    const modified = e.detail;
+    if (modified) {
+      this.currentStroke++;
+      this.mostRecentStroke = this.currentStroke;
 
-    // When a new stroke is added, it can always be undone. Since it's the most
-    // recent stroke, the redo action cannot be performed.
-    this.canUndoAnnotation_ = true;
-    this.canRedoAnnotation_ = false;
+      // When a new stroke modification occurs, it can always be undone. Since
+      // it's the most recent modification, the redo action cannot be performed.
+      this.canUndoAnnotation_ = true;
+      this.canRedoAnnotation_ = false;
+    }
+
+    this.strokeInProgress_ = false;
+  }
+
+  protected computeEnableUndo_(): boolean {
+    return this.canUndoAnnotation_ && !this.strokeInProgress_ &&
+        this.enableUndoRedo;
+  }
+
+  protected computeEnableRedo_(): boolean {
+    return this.canRedoAnnotation_ && !this.strokeInProgress_ &&
+        this.enableUndoRedo;
   }
 
   /**
    * Undo an annotation stroke, if possible.
    */
   undo() {
-    if (!this.canUndoAnnotation_) {
+    if (!this.computeEnableUndo_()) {
       return;
     }
 
@@ -508,7 +573,7 @@ export class ViewerToolbarElement extends CrLitElement {
    * Redo an annotation stroke, if possible.
    */
   redo() {
-    if (!this.canRedoAnnotation_) {
+    if (!this.computeEnableRedo_()) {
       return;
     }
 
@@ -561,7 +626,7 @@ export class ViewerToolbarElement extends CrLitElement {
    */
   protected presentationModeAvailable_(): boolean {
     // <if expr="enable_ink">
-    return !this.annotationMode && !this.embeddedViewer;
+    return this.annotationMode === AnnotationMode.OFF && !this.embeddedViewer;
     // </if>
     // <if expr="not enable_ink">
     return !this.embeddedViewer;
