@@ -11,7 +11,7 @@ import {getHtml} from './hover_button.html.js';
 
 export interface HoverButtonElement {
   $: {
-    hoverButton: HTMLDivElement,
+    hoverButton: HTMLElement,
   };
 }
 
@@ -30,13 +30,15 @@ export class HoverButtonElement extends CrLitElement {
 
   static override get properties() {
     return {
+      ariaButtonLabel: {type: String},
       label: {type: String},
       labelDescription: {type: String},
     };
   }
 
-  label: string = '';
-  labelDescription: string|null = null;
+  accessor ariaButtonLabel: string|null = null;
+  accessor label: string = '';
+  accessor labelDescription: string|null = null;
 
   constructor() {
     super();
