@@ -21,6 +21,7 @@
 #include "base/notreached.h"
 #include "base/strings/string_split.h"
 #include "base/strings/string_util.h"
+#include "chrome/browser/metrics/chrome_metrics_service_accessor.h"
 #include "chrome/browser/signin/bound_session_credentials/bound_session_cookie_controller.h"
 #include "chrome/browser/signin/bound_session_credentials/bound_session_cookie_controller_impl.h"
 #include "chrome/browser/signin/bound_session_credentials/bound_session_debug_info.h"
@@ -33,6 +34,7 @@
 #include "chrome/common/google_url_loader_throttle.h"
 #include "chrome/common/renderer_configuration.mojom.h"
 #include "components/signin/public/base/signin_switches.h"
+#include "components/variations/synthetic_trials.h"
 #include "content/public/browser/storage_partition.h"
 #include "net/base/schemeful_site.h"
 #include "services/network/public/cpp/shared_url_loader_factory.h"
@@ -143,21 +145,58 @@ GetThrottlerParamsForRequestCoverage(
       controller->scope_url().host(), controller->scope_url().path(),
       base::Time());
 }
+
+bool IsNewSessionRegistrationEnabled(const PrefService* profile_prefs,
+                                     bool is_wsbeta) {
+  return switches::IsBoundSessionCredentialsEnabled(profile_prefs) ||
+         (is_wsbeta && base::FeatureList::IsEnabled(
+                           kEnableBoundSessionCredentialsWsbetaBypass));
+}
+
+bool IsSessionInitializationEnabled(const PrefService* profile_prefs,
+                                    bool is_wsbeta) {
+  // It should always be possible to initialize a session if the registration is
+  // enabled.
+  return IsNewSessionRegistrationEnabled(profile_prefs, is_wsbeta) ||
+         base::FeatureList::IsEnabled(kEnableBoundSessionCredentialsContinuity);
+}
+
 }  // namespace
 
+BASE_FEATURE(kEnableBoundSessionCredentialsWsbetaBypass,
+             "EnableBoundSessionCredentialsWsbetaBypass",
+#if BUILDFLAG(IS_WIN)
+             base::FEATURE_ENABLED_BY_DEFAULT
+#else
+             base::FEATURE_DISABLED_BY_DEFAULT
+#endif
+);
+
+BASE_FEATURE(kEnableBoundSessionCredentialsContinuity,
+             "EnableBoundSessionCredentialsContinuity",
+#if BUILDFLAG(IS_WIN)
+             base::FEATURE_ENABLED_BY_DEFAULT
+#else
+             base::FEATURE_DISABLED_BY_DEFAULT
+#endif
+);
+
 BoundSessionCookieRefreshServiceImpl::BoundSessionCookieRefreshServiceImpl(
     unexportable_keys::UnexportableKeyService& key_service,
     std::unique_ptr<BoundSessionParamsStorage> session_params_storage,
     content::StoragePartition* storage_partition,
     network::NetworkConnectionTracker* network_connection_tracker,
+    const PrefService* profile_prefs,
     bool is_off_the_record_profile)
     : key_service_(key_service),
       session_params_storage_(std::move(session_params_storage)),
       storage_partition_(storage_partition),
       network_connection_tracker_(network_connection_tracker),
+      profile_prefs_(profile_prefs),
       is_off_the_record_profile_(is_off_the_record_profile) {
   CHECK(session_params_storage_);
   CHECK(storage_partition_);
+  CHECK(profile_prefs_);
   data_removal_observation_.Observe(storage_partition_);
 }
 
@@ -179,13 +218,17 @@ void BoundSessionCookieRefreshServiceImpl::Initialize() {
   }
 
   for (const auto& params : bound_session_params) {
-    InitializeBoundSession(params);
+    if (IsSessionInitializationEnabled(profile_prefs_, params.is_wsbeta())) {
+      InitializeBoundSession(params, /*is_new_session=*/false);
+    }
   }
   UpdateAllRenderers();
 }
 
 void BoundSessionCookieRefreshServiceImpl::RegisterNewBoundSession(
     const bound_session_credentials::BoundSessionParams& params) {
+  CHECK(IsNewSessionRegistrationEnabled(profile_prefs_, params.is_wsbeta()));
+
   if (!session_params_storage_->SaveParams(params)) {
     DVLOG(1) << "Invalid session params or failed to serialize session params.";
     return;
@@ -201,7 +244,7 @@ void BoundSessionCookieRefreshServiceImpl::RegisterNewBoundSession(
     // starting with the same scope.
   }
 
-  InitializeBoundSession(params);
+  InitializeBoundSession(params, /*is_new_session=*/true);
   UpdateAllRenderers();
 }
 
@@ -332,6 +375,11 @@ void BoundSessionCookieRefreshServiceImpl::HandleRequestBlockedOnCookie(
 
 void BoundSessionCookieRefreshServiceImpl::CreateRegistrationRequest(
     BoundSessionRegistrationFetcherParam registration_params) {
+  if (!IsNewSessionRegistrationEnabled(profile_prefs_,
+                                       registration_params.is_wsbeta())) {
+    return;
+  }
+
   // Guardrail against registering non-SIDTS DBSC sessions while the client
   // lacks support for running multiple sessions at the same time. Can be
   // overridden with a Finch config parameter.
@@ -477,7 +525,18 @@ BoundSessionCookieRefreshServiceImpl::CreateBoundSessionCookieController(
 }
 
 void BoundSessionCookieRefreshServiceImpl::InitializeBoundSession(
-    const bound_session_credentials::BoundSessionParams& bound_session_params) {
+    const bound_session_credentials::BoundSessionParams& bound_session_params,
+    bool is_new_session) {
+  CHECK(IsSessionInitializationEnabled(profile_prefs_,
+                                       bound_session_params.is_wsbeta()));
+  if (bound_session_params.is_wsbeta()) {
+    // It's unusual to register a synthetic trial with a single group. The
+    // purpose of this trial is to be able to filter out the users having
+    // "wsbeta" sessions (thus ignoring the main experiment).
+    ChromeMetricsServiceAccessor::RegisterSyntheticFieldTrial(
+        "BoundSessionCredentialsWsbetaSyntheticTrial", "Enabled",
+        variations::SyntheticTrialAnnotationMode::kCurrentLog);
+  }
   std::unique_ptr<BoundSessionCookieController> controller =
       CreateBoundSessionCookieController(bound_session_params,
                                          is_off_the_record_profile_);
@@ -485,7 +544,7 @@ void BoundSessionCookieRefreshServiceImpl::InitializeBoundSession(
   auto [it, inserted] =
       cookie_controllers_.emplace(std::move(key), std::move(controller));
   CHECK(inserted);
-  it->second->Initialize();
+  it->second->Initialize(is_new_session);
 }
 
 void BoundSessionCookieRefreshServiceImpl::UpdateAllRenderers() {
