@@ -35,7 +35,9 @@
 #include "chrome/browser/signin/bound_session_credentials/fake_bound_session_refresh_cookie_fetcher.h"
 #include "chrome/browser/signin/bound_session_credentials/rotation_debug_info.pb.h"
 #include "chrome/common/renderer_configuration.mojom.h"
+#include "components/prefs/testing_pref_service.h"
 #include "components/signin/public/base/signin_switches.h"
+#include "components/signin/public/identity_manager/tribool.h"
 #include "components/sync_preferences/testing_pref_service_syncable.h"
 #include "components/unexportable_keys/fake_unexportable_key_service.h"
 #include "content/public/browser/network_service_instance.h"
@@ -118,8 +120,16 @@ class FakeBoundSessionCookieController : public BoundSessionCookieController {
     }
   }
 
+  void Initialize(bool is_new_session) override {
+    was_new_session_at_init_ = signin::TriboolFromBool(is_new_session);
+  }
+
   const std::vector<uint8_t>& wrapped_key() const { return wrapped_key_; }
 
+  // `signin::Tribool::kUnknown` means that the controller hasn't been
+  // initialized yet.
+  signin::Tribool was_new_session_at_init() { return was_new_session_at_init_; }
+
   void HandleRequestBlockedOnCookie(
       chrome::mojom::BoundSessionRequestThrottledHandler::
           HandleRequestBlockedOnCookieCallback resume_blocked_request)
@@ -179,6 +189,7 @@ class FakeBoundSessionCookieController : public BoundSessionCookieController {
                   HandleRequestBlockedOnCookieCallback>
       resume_blocked_requests_;
   std::vector<uint8_t> wrapped_key_;
+  signin::Tribool was_new_session_at_init_ = signin::Tribool::kUnknown;
   bool throttling_requests_paused_ = false;
   base::WeakPtrFactory<FakeBoundSessionCookieController> weak_ptr_factory_{
       this};
@@ -301,6 +312,7 @@ class FakeBoundSessionDebugReportFetcher
   base::flat_set<std::string> GetNonRefreshedCookieNames() override {
     return {};
   }
+  Trigger GetTrigger() const override { return Trigger::kOther; }
 };
 
 class MockObserver : public BoundSessionCookieRefreshService::Observer {
@@ -332,7 +344,8 @@ bound_session_credentials::Credential CreateCookieCredential(
 bound_session_credentials::BoundSessionParams CreateBoundSessionParams(
     const GURL& site,
     const std::string& session_id,
-    const std::vector<std::string>& cookie_names) {
+    const std::vector<std::string>& cookie_names,
+    bool is_wsbeta = false) {
   bound_session_credentials::BoundSessionParams params;
   params.set_site(site.spec());
   params.set_session_id(session_id);
@@ -343,13 +356,16 @@ bound_session_credentials::BoundSessionParams CreateBoundSessionParams(
   for (const auto& cookie_name : cookie_names) {
     *params.add_credentials() = CreateCookieCredential(cookie_name, site);
   }
+  params.set_is_wsbeta(is_wsbeta);
   return params;
 }
 
 bound_session_credentials::BoundSessionParams CreateBoundSessionParams(
     const BoundSessionKey& key,
-    const std::vector<std::string>& cookie_names) {
-  return CreateBoundSessionParams(key.site, key.session_id, cookie_names);
+    const std::vector<std::string>& cookie_names,
+    bool is_wsbeta = false) {
+  return CreateBoundSessionParams(key.site, key.session_id, cookie_names,
+                                  is_wsbeta);
 }
 
 }  // namespace
@@ -451,11 +467,12 @@ class BoundSessionCookieRefreshServiceImplTestBase : public testing::Test {
   void RunUntilIdle() { task_environment_.RunUntilIdle(); }
 
   BoundSessionRegistrationFetcherParam CreateTestRegistrationFetcherParams(
-      std::string_view registration_path) {
+      std::string_view registration_path,
+      bool is_wsbeta = false) {
     return BoundSessionRegistrationFetcherParam::CreateInstanceForTesting(
         kTestGoogleURL.Resolve(registration_path),
         {crypto::SignatureVerifier::SignatureAlgorithm::ECDSA_SHA256},
-        "test_challenge");
+        "test_challenge", is_wsbeta);
   }
 
   base::HistogramTester& histogram_tester() { return histogram_tester_; }
@@ -472,6 +489,7 @@ class BoundSessionCookieRefreshServiceImplTestBase : public testing::Test {
             fake_unexportable_key_service_,
             BoundSessionParamsStorage::CreatePrefsStorageForTesting(prefs_),
             &storage_partition_, content::GetNetworkConnectionTracker(),
+            &pref_service_,
             /*is_off_the_record_profile=*/false);
     cookie_refresh_service->set_controller_factory_for_testing(
         base::BindRepeating(&BoundSessionCookieRefreshServiceImplTestBase::
@@ -490,12 +508,15 @@ class BoundSessionCookieRefreshServiceImplTestBase : public testing::Test {
     return cookie_refresh_service;
   }
 
+  base::test::ScopedFeatureList scoped_feature_list_{
+      switches::kEnableBoundSessionCredentials};
   base::test::TaskEnvironment task_environment_{
       base::test::TaskEnvironment::TimeSource::MOCK_TIME};
   base::HistogramTester histogram_tester_;
   sync_preferences::TestingPrefServiceSyncable prefs_;
   std::unique_ptr<BoundSessionParamsStorage> test_storage_;
   content::TestStoragePartition storage_partition_;
+  TestingPrefServiceSimple pref_service_;
   ::testing::StrictMock<MockObserver> mock_observer_;
   std::unique_ptr<BoundSessionCookieRefreshServiceImpl> cookie_refresh_service_;
   unexportable_keys::FakeUnexportableKeyService fake_unexportable_key_service_;
@@ -584,6 +605,8 @@ TEST_F(BoundSessionCookieRefreshServiceImplTest, VerifyControllerParams) {
   SetupPreConditionForBoundSession();
   GetCookieRefreshServiceImpl();
   VerifyBoundSession(CreateTestBoundSessionParams());
+  EXPECT_EQ(cookie_controller()->was_new_session_at_init(),
+            signin::Tribool::kFalse);
 }
 
 TEST_F(BoundSessionCookieRefreshServiceImplTest,
@@ -990,6 +1013,8 @@ TEST_F(BoundSessionCookieRefreshServiceImplTest, RegisterNewBoundSession) {
   auto params = CreateTestBoundSessionParams();
   service->RegisterNewBoundSession(params);
   VerifyBoundSession(params);
+  EXPECT_EQ(cookie_controller()->was_new_session_at_init(),
+            signin::Tribool::kTrue);
 }
 
 TEST_F(BoundSessionCookieRefreshServiceImplTest,
@@ -1108,14 +1133,19 @@ TEST_F(BoundSessionCookieRefreshServiceImplTest, CreateRegistrationRequest) {
   registration_fetcher()->SimulateRegistrationFetchCompleted(params);
   EXPECT_FALSE(registration_fetcher());
   VerifyBoundSession(params);
+  EXPECT_EQ(cookie_controller()->was_new_session_at_init(),
+            signin::Tribool::kTrue);
 }
 
 TEST_F(BoundSessionCookieRefreshServiceImplTest,
        CreateRegistrationRequestNonDefaultPath) {
+  const std::string kNonDefaultRegistrationPath = "/NonDefaultPath";
   BoundSessionCookieRefreshServiceImpl* service = GetCookieRefreshServiceImpl();
   service->CreateRegistrationRequest(
-      CreateTestRegistrationFetcherParams("/NonDefaultPath"));
-  EXPECT_FALSE(registration_fetcher());
+      CreateTestRegistrationFetcherParams(kNonDefaultRegistrationPath));
+  ASSERT_TRUE(registration_fetcher());
+  EXPECT_THAT(registration_fetcher(), IsBoundSessionRegistrationFetcher(
+                                          kNonDefaultRegistrationPath, true));
 }
 
 TEST_F(BoundSessionCookieRefreshServiceImplTest,
@@ -1214,7 +1244,8 @@ class BoundSessionCookieRefreshServiceImplMultiSessionTest
 
   void VerifyBoundSessions(
       const std::vector<bound_session_credentials::BoundSessionParams>&
-          all_expected_params) {
+          all_expected_params,
+      bool verify_storage = true) {
     CHECK(cookie_refresh_service());
 
     // Verify throttler params.
@@ -1222,9 +1253,11 @@ class BoundSessionCookieRefreshServiceImplMultiSessionTest
                 UnorderedPointwise(IsThrottlerParams(), all_expected_params));
 
     // Verify storage.
-    EXPECT_THAT(
-        storage()->ReadAllParamsAndCleanStorageIfNecessary(),
-        UnorderedPointwise(base::test::EqualsProto(), all_expected_params));
+    if (verify_storage) {
+      EXPECT_THAT(
+          storage()->ReadAllParamsAndCleanStorageIfNecessary(),
+          UnorderedPointwise(base::test::EqualsProto(), all_expected_params));
+    }
 
     // Verify controllers.
     EXPECT_THAT(cookie_controllers_,
@@ -1648,3 +1681,92 @@ TEST_F(BoundSessionCookieRefreshServiceImplMultiSessionTest, ReportsCountUma) {
       "Signin.BoundSessionCredentials.SessionCountOnInit", all_params.size(),
       /*expected_bucket_count=*/1);
 }
+
+// Testing params:
+// - bool controlling `kEnableBoundSessionCredentialsWsbetaBypass` feature state
+// - bool controlling `kEnableBoundSessionCredentialsContinuity` feature state
+class BoundSessionCookieRefreshServiceImplFeatureDisabledTest
+    : public testing::WithParamInterface<std::tuple<bool, bool>>,
+      public BoundSessionCookieRefreshServiceImplMultiSessionTest {
+ public:
+  BoundSessionCookieRefreshServiceImplFeatureDisabledTest() {
+    std::vector<base::test::FeatureRef> enabled_features;
+    std::vector<base::test::FeatureRef> disabled_features;
+
+    auto& wsbeta_container =
+        IsWsbetaEnabled() ? enabled_features : disabled_features;
+    wsbeta_container.push_back(kEnableBoundSessionCredentialsWsbetaBypass);
+
+    auto& continuity_container =
+        IsContinuityEnabled() ? enabled_features : disabled_features;
+    continuity_container.push_back(kEnableBoundSessionCredentialsContinuity);
+
+    disabled_features.push_back(switches::kEnableBoundSessionCredentials);
+
+    scoped_feature_list_.InitWithFeatures(enabled_features, disabled_features);
+  }
+
+  bool IsWsbetaEnabled() { return std::get<0>(GetParam()); }
+
+  bool IsContinuityEnabled() { return std::get<1>(GetParam()); }
+
+ private:
+  base::test::ScopedFeatureList scoped_feature_list_;
+};
+
+TEST_P(BoundSessionCookieRefreshServiceImplFeatureDisabledTest,
+       InitializeSession) {
+  std::vector<bound_session_credentials::BoundSessionParams> all_params = {
+      CreateBoundSessionParams(kGoogleSessionKeyOne, {"cookieA", "cookieB"}),
+      CreateBoundSessionParams(kGoogleSessionKeyTwo, {"cookieC"},
+                               /*is_wsbeta=*/true),
+      CreateBoundSessionParams(kYoutubeSessionKeyOne, {"cookieA"})};
+  for (const auto& params : all_params) {
+    ASSERT_TRUE(storage()->SaveParams(params));
+  }
+  GetCookieRefreshServiceImpl();
+  std::vector<bound_session_credentials::BoundSessionParams> expected_sessions;
+  if (IsContinuityEnabled()) {
+    // All sessions are expected to run.
+    expected_sessions = all_params;
+  } else if (IsWsbetaEnabled()) {
+    // Only a session with `is_wsbeta` will run.
+    expected_sessions = {all_params[1]};
+  }
+  VerifyBoundSessions(expected_sessions, /*verify_storage=*/false);
+}
+
+TEST_P(BoundSessionCookieRefreshServiceImplFeatureDisabledTest,
+       CreateRegistrationRequest) {
+  BoundSessionCookieRefreshServiceImpl* service = GetCookieRefreshServiceImpl();
+  service->CreateRegistrationRequest(
+      CreateTestRegistrationFetcherParams("/RegisterSession"));
+  // New sessions shouldn't be registered no matter the extra feature state.
+  EXPECT_THAT(registration_fetchers(), IsEmpty());
+}
+
+TEST_P(BoundSessionCookieRefreshServiceImplFeatureDisabledTest,
+       CreateRegistrationRequestWithWsbeta) {
+  BoundSessionCookieRefreshServiceImpl* service = GetCookieRefreshServiceImpl();
+  service->CreateRegistrationRequest(CreateTestRegistrationFetcherParams(
+      "/RegisterSession", /*is_wsbeta=*/true));
+  if (IsWsbetaEnabled()) {
+    EXPECT_THAT(registration_fetchers(),
+                ElementsAre(IsBoundSessionRegistrationFetcher(
+                    "/RegisterSession", true)));
+  } else {
+    EXPECT_THAT(registration_fetchers(), IsEmpty());
+  }
+}
+
+INSTANTIATE_TEST_SUITE_P(
+    ,
+    BoundSessionCookieRefreshServiceImplFeatureDisabledTest,
+    testing::Combine(testing::Bool(), testing::Bool()),
+    [](const auto& info) {
+      bool wsbeta_enabled = std::get<0>(info.param);
+      bool continuity_enabled = std::get<1>(info.param);
+      return base::StrCat({wsbeta_enabled ? "With" : "Without", "Wsbeta",
+                           continuity_enabled ? "With" : "Without",
+                           "Continuity"});
+    });
