@@ -5,11 +5,15 @@
 #include <optional>
 
 #include "base/strings/stringprintf.h"
+#include "base/task/current_thread.h"
 #include "base/test/bind.h"
 #include "base/test/test_future.h"
-#include "build/chromeos_buildflags.h"
+#include "base/test/with_feature_override.h"
+#include "build/build_config.h"
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/profiles/profile_manager.h"
+#include "chrome/browser/signin/dice_web_signin_interceptor.h"
+#include "chrome/browser/signin/dice_web_signin_interceptor_factory.h"
 #include "chrome/browser/signin/e2e_tests/account_capabilities_observer.h"
 #include "chrome/browser/signin/e2e_tests/accounts_removed_waiter.h"
 #include "chrome/browser/signin/e2e_tests/live_test.h"
@@ -20,15 +24,18 @@
 #include "chrome/browser/ui/browser_finder.h"
 #include "chrome/browser/ui/profiles/profile_picker.h"
 #include "chrome/browser/ui/profiles/profile_ui_test_utils.h"
+#include "chrome/browser/ui/views/profiles/dice_web_signin_interception_bubble_view.h"
 #include "chrome/browser/ui/webui/signin/login_ui_service.h"
 #include "chrome/browser/ui/webui/signin/login_ui_service_factory.h"
 #include "chrome/browser/ui/webui/signin/login_ui_test_utils.h"
 #include "chrome/browser/ui/webui/signin/signin_email_confirmation_dialog.h"
 #include "chrome/browser/ui/webui/signin/signin_url_utils.h"
 #include "chrome/test/base/ui_test_utils.h"
+#include "chrome/test/interaction/interactive_browser_test.h"
 #include "components/signin/core/browser/account_reconcilor.h"
 #include "components/signin/public/base/consent_level.h"
 #include "components/signin/public/base/signin_buildflags.h"
+#include "components/signin/public/base/signin_switches.h"
 #include "components/signin/public/identity_manager/account_info.h"
 #include "components/signin/public/identity_manager/accounts_in_cookie_jar_info.h"
 #include "components/signin/public/identity_manager/identity_manager.h"
@@ -42,12 +49,13 @@
 #include "google_apis/gaia/gaia_auth_util.h"
 #include "google_apis/gaia/gaia_urls.h"
 #include "third_party/skia/include/core/SkColor.h"
+#include "ui/base/page_transition_types.h"
 #include "ui/compositor/scoped_animation_duration_scale_mode.h"
 #include "ui/views/controls/webview/webview.h"
 
-#if !BUILDFLAG(IS_CHROMEOS_ASH)
+#if !BUILDFLAG(IS_CHROMEOS)
 #include "chrome/browser/sync/sync_ui_util.h"
-#endif  // !BUILDFLAG(IS_CHROMEOS_ASH)
+#endif  // !BUILDFLAG(IS_CHROMEOS)
 
 namespace signin::test {
 namespace {
@@ -144,10 +152,10 @@ IN_PROC_BROWSER_TEST_F(LiveSignInTest, MANUAL_WebSignOut) {
   EXPECT_TRUE(
       identity_manager()->HasAccountWithRefreshTokenInPersistentErrorState(
           primary_account.account_id));
-#if !BUILDFLAG(IS_CHROMEOS_ASH)
+#if !BUILDFLAG(IS_CHROMEOS)
   EXPECT_EQ(GetAvatarSyncErrorType(browser()->profile()),
             AvatarSyncErrorType::kSyncPaused);
-#endif  // !BUILDFLAG(IS_CHROMEOS_ASH)
+#endif  // !BUILDFLAG(IS_CHROMEOS)
 }
 
 // This test can pass. Marked as manual because it TIMED_OUT on Win7.
@@ -172,8 +180,9 @@ IN_PROC_BROWSER_TEST_F(LiveSignInTest, MANUAL_WebSignInAndSignOut) {
       accounts_in_cookie_jar_1.GetPotentiallyInvalidSignedInAccounts()[0];
   EXPECT_TRUE(gaia::AreEmailsSame(test_account->user, account_1.email));
   EXPECT_TRUE(identity_manager()->HasAccountWithRefreshToken(account_1.id));
+  // Web signin does not automatically propagate to Chrome.
   EXPECT_FALSE(
-      identity_manager()->HasPrimaryAccount(signin::ConsentLevel::kSync));
+      identity_manager()->HasPrimaryAccount(signin::ConsentLevel::kSignin));
 
   std::optional<TestAccountSigninCredentials> test_account_2 =
       GetTestAccounts()->GetAccount("TEST_ACCOUNT_2");
@@ -195,7 +204,7 @@ IN_PROC_BROWSER_TEST_F(LiveSignInTest, MANUAL_WebSignInAndSignOut) {
   EXPECT_TRUE(gaia::AreEmailsSame(test_account_2->user, account_2.email));
   EXPECT_TRUE(identity_manager()->HasAccountWithRefreshToken(account_2.id));
   EXPECT_FALSE(
-      identity_manager()->HasPrimaryAccount(signin::ConsentLevel::kSync));
+      identity_manager()->HasPrimaryAccount(signin::ConsentLevel::kSignin));
 
   sign_in_functions.SignOutFromWeb();
 
@@ -319,26 +328,33 @@ IN_PROC_BROWSER_TEST_F(LiveSignInTest, MANUAL_CancelSyncWithWebAccount) {
 // See crbug.com/1025335.
 // Starts the sign in flow from the settings page, enters credentials on the
 // login page but cancels the Sync confirmation dialog. Checks that Sync is
-// disabled and no account was added to Chrome.
+// disabled but the account is still signed in to Chrome.
 IN_PROC_BROWSER_TEST_F(LiveSignInTest, MANUAL_CancelSync) {
   std::optional<TestAccountSigninCredentials> test_account =
       GetTestAccounts()->GetAccount("TEST_ACCOUNT_1");
   CHECK(test_account.has_value());
   sign_in_functions.SignInFromSettings(*test_account, 0);
 
-  SignInTestObserver observer(identity_manager(), account_reconcilor());
   EXPECT_TRUE(login_ui_test_utils::CancelSyncConfirmationDialog(
       browser(), kDialogTimeout));
-  observer.WaitForAccountChanges(0, PrimarySyncAccountWait::kWaitForCleared);
+  // The account is still signed in, but not syncing.
+  EXPECT_FALSE(
+      identity_manager()->HasPrimaryAccount(signin::ConsentLevel::kSync));
+  EXPECT_TRUE(
+      identity_manager()->HasPrimaryAccount(signin::ConsentLevel::kSignin));
 
   const AccountsInCookieJarInfo& accounts_in_cookie_jar =
       identity_manager()->GetAccountsInCookieJar();
   EXPECT_TRUE(accounts_in_cookie_jar.AreAccountsFresh());
-  EXPECT_TRUE(
-      accounts_in_cookie_jar.GetPotentiallyInvalidSignedInAccounts().empty());
-  EXPECT_TRUE(identity_manager()->GetAccountsWithRefreshTokens().empty());
-  EXPECT_FALSE(
-      identity_manager()->HasPrimaryAccount(signin::ConsentLevel::kSync));
+  ASSERT_EQ(
+      1u,
+      accounts_in_cookie_jar.GetPotentiallyInvalidSignedInAccounts().size());
+  EXPECT_TRUE(accounts_in_cookie_jar.GetSignedOutAccounts().empty());
+  const gaia::ListedAccount& account =
+      accounts_in_cookie_jar.GetPotentiallyInvalidSignedInAccounts()[0];
+  EXPECT_TRUE(gaia::AreEmailsSame(test_account->user, account.email));
+  EXPECT_TRUE(identity_manager()->HasAccountWithRefreshToken(account.id));
+  EXPECT_FALSE(sync_service()->IsSyncFeatureEnabled());
 }
 
 // This test can pass. Marked as manual because it TIMED_OUT on Win7.
@@ -487,8 +503,8 @@ IN_PROC_BROWSER_TEST_F(LiveSignInTest,
 // This test can pass. Marked as manual because it TIMED_OUT on Win7.
 // See crbug.com/1025335.
 // Enables and disables sync to account 1. Enables sync to account 2 and clicks
-// on "Cancel" in the email confirmation dialog. Checks that the signin flow is
-// canceled and no accounts are added to Chrome.
+// on "Cancel" in the email confirmation dialog. Checks that the account is left
+// signed in without syncing.
 IN_PROC_BROWSER_TEST_F(LiveSignInTest,
                        MANUAL_SyncSecondAccount_CancelOnEmailConfirmation) {
   // Enable and disable sync for the first account.
@@ -509,26 +525,35 @@ IN_PROC_BROWSER_TEST_F(LiveSignInTest,
   EXPECT_EQ(profile_manager->GetNumberOfProfiles(), 1U);
   EXPECT_EQ(chrome::GetTotalBrowserCount(), 1U);
 
-  // Click "Cancel" on the email confirmation dialog and wait for an account to
-  // removed from Chrome.
-  SignInTestObserver observer(identity_manager(), account_reconcilor());
+  // Click "Cancel" on the email confirmation dialog.
   EXPECT_TRUE(login_ui_test_utils::CompleteSigninEmailConfirmationDialog(
       browser(), kDialogTimeout, SigninEmailConfirmationDialog::CLOSE));
-  observer.WaitForAccountChanges(0, PrimarySyncAccountWait::kWaitForCleared);
 
   // Check no profile was created.
   EXPECT_EQ(profile_manager->GetNumberOfProfiles(), 1U);
   EXPECT_EQ(chrome::GetTotalBrowserCount(), 1U);
 
-  // Check Chrome has no accounts.
+  // The account is still signed in, but not syncing.
+  EXPECT_FALSE(
+      identity_manager()->HasPrimaryAccount(signin::ConsentLevel::kSync));
+  EXPECT_TRUE(
+      identity_manager()->HasPrimaryAccount(signin::ConsentLevel::kSignin));
+
   const AccountsInCookieJarInfo& accounts_in_cookie_jar =
       identity_manager()->GetAccountsInCookieJar();
   EXPECT_TRUE(accounts_in_cookie_jar.AreAccountsFresh());
-  EXPECT_TRUE(
-      accounts_in_cookie_jar.GetPotentiallyInvalidSignedInAccounts().empty());
-  EXPECT_TRUE(identity_manager()->GetAccountsWithRefreshTokens().empty());
-  EXPECT_FALSE(
-      identity_manager()->HasPrimaryAccount(signin::ConsentLevel::kSync));
+  ASSERT_EQ(
+      1u,
+      accounts_in_cookie_jar.GetPotentiallyInvalidSignedInAccounts().size());
+  ASSERT_EQ(1u, accounts_in_cookie_jar.GetSignedOutAccounts().size());
+  EXPECT_TRUE(gaia::AreEmailsSame(
+      test_account_1->user,
+      accounts_in_cookie_jar.GetSignedOutAccounts()[0].email));
+  const gaia::ListedAccount& account =
+      accounts_in_cookie_jar.GetPotentiallyInvalidSignedInAccounts()[0];
+  EXPECT_TRUE(gaia::AreEmailsSame(test_account_2->user, account.email));
+  EXPECT_TRUE(identity_manager()->HasAccountWithRefreshToken(account.id));
+  EXPECT_FALSE(sync_service()->IsSyncFeatureEnabled());
 }
 
 IN_PROC_BROWSER_TEST_F(LiveSignInTest,
@@ -587,6 +612,7 @@ IN_PROC_BROWSER_TEST_F(LiveSignInTest,
 
 #if BUILDFLAG(ENABLE_DICE_SUPPORT)
 IN_PROC_BROWSER_TEST_F(LiveSignInTest, MANUAL_CreateSignedInProfile) {
+  base::HistogramTester histogram_tester;
   std::optional<TestAccountSigninCredentials> test_account =
       GetTestAccounts()->GetAccount("TEST_ACCOUNT_1");
   CHECK(test_account.has_value());
@@ -604,7 +630,7 @@ IN_PROC_BROWSER_TEST_F(LiveSignInTest, MANUAL_CreateSignedInProfile) {
 
   // Simulate a click on the signin button.
   base::test::TestFuture<bool> proceed_future;
-  ProfilePicker::SwitchToDiceSignIn(SK_ColorRED, proceed_future.GetCallback());
+  ProfilePicker::SwitchToSignIn(SK_ColorRED, proceed_future.GetCallback());
   EXPECT_TRUE(proceed_future.Get());
 
   // Signin on Gaia.
@@ -620,15 +646,17 @@ IN_PROC_BROWSER_TEST_F(LiveSignInTest, MANUAL_CreateSignedInProfile) {
   // User is signed in, but Sync is off.
   signin::IdentityManager* identity_manager =
       IdentityManagerFactory::GetForProfile(new_profile);
-  EXPECT_EQ(GetPrimaryAccountConsentLevel(identity_manager),
-            signin::ConsentLevel::kSignin);
+  base::test::RunUntil([&identity_manager]() {
+    return GetPrimaryAccountConsentLevel(identity_manager) ==
+           signin::ConsentLevel::kSignin;
+  });
 
   // Confirm Sync.
   ui_test_utils::BrowserChangeObserver browser_added_observer(
       nullptr, ui_test_utils::BrowserChangeObserver::ChangeType::kAdded);
-  GURL sync_confirmation_url = AppendSyncConfirmationQueryParams(
-      GURL("chrome://sync-confirmation/"), SyncConfirmationStyle::kWindow,
-      /*is_sync_promo=*/true);
+  GURL sync_confirmation_url =
+      AppendSyncConfirmationQueryParams(GURL("chrome://sync-confirmation/"),
+                                        SyncConfirmationStyle::kWindow, true);
   profiles::testing::WaitForPickerLoadStop(sync_confirmation_url);
   LoginUIServiceFactory::GetForProfile(new_profile)
       ->SyncConfirmationUIClosed(LoginUIService::SYNC_WITH_DEFAULT_SETTINGS);
@@ -639,7 +667,66 @@ IN_PROC_BROWSER_TEST_F(LiveSignInTest, MANUAL_CreateSignedInProfile) {
   EXPECT_EQ(new_browser->profile(), new_profile);
   EXPECT_EQ(GetPrimaryAccountConsentLevel(identity_manager),
             signin::ConsentLevel::kSync);
+
+  // Both LST and Sync Header are received so their time difference must be
+  // recorded.
+  histogram_tester.ExpectTotalCount(
+      "Signin.SigninManager.SyncHeaderArrivalTimeWindowAfterLst", 1);
 }
+
+class LiveSignInGaiaIntegrationTest
+    : public base::test::WithFeatureOverride,
+      public InteractiveBrowserTestT<LiveSignInTest> {
+ public:
+  LiveSignInGaiaIntegrationTest()
+      : base::test::WithFeatureOverride(
+            switches::kBrowserSigninInSyncHeaderOnGaiaIntegration) {}
+
+  bool IsFixGaiaIntegrationEnabled() const { return IsParamFeatureEnabled(); }
+};
+
+// Regression test for crbug.com/420635510.
+// Tests that a doing a web signin from a tab that was previously opened for
+// a browser signin, does not sign in the user in the browser.
+IN_PROC_BROWSER_TEST_P(LiveSignInGaiaIntegrationTest,
+                       MANUAL_WebSignInFromExistingChromeSignInTab) {
+  base::HistogramTester histogram_tester;
+  sign_in_functions.StartSignInFromSettings();
+  int current_tab_count = browser()->tab_strip_model()->GetTabCount();
+
+  std::optional<TestAccountSigninCredentials> test_account =
+      GetTestAccounts()->GetAccount("TEST_ACCOUNT_1");
+  CHECK(test_account.has_value());
+  // Use the same tab for a web sign-in.
+  content::OpenURLParams params(
+      GaiaUrls::GetInstance()->add_account_url(), content::Referrer(),
+      WindowOpenDisposition::CURRENT_TAB, ui::PAGE_TRANSITION_TYPED, false);
+  browser()->tab_strip_model()->GetActiveWebContents()->OpenURL(
+      params, /*navigation_handle_callback=*/{});
+  ASSERT_EQ(current_tab_count, browser()->tab_strip_model()->GetTabCount());
+
+  sign_in_functions.SignInFromCurrentPage(
+      browser()->tab_strip_model()->GetActiveWebContents(), *test_account, 0);
+  ASSERT_EQ(current_tab_count, browser()->tab_strip_model()->GetTabCount());
+
+  // When the updated Gaia integration is used, the user should not be signed-in
+  // in the browser.
+  EXPECT_EQ(IsFixGaiaIntegrationEnabled(),
+            !identity_manager()->HasPrimaryAccount(ConsentLevel::kSignin));
+
+  if (IsFixGaiaIntegrationEnabled()) {
+    RunTestSequence(WaitForShow(
+        DiceWebSigninInterceptionBubbleView::kDiceWebSigninInterceptionBubble));
+  }
+
+  histogram_tester.ExpectBucketCount(
+      "Signin.Intercept.HeuristicOutcome",
+      SigninInterceptionHeuristicOutcome::kInterceptChromeSignin,
+      IsFixGaiaIntegrationEnabled() ? 1 : 0);
+}
+
+INSTANTIATE_FEATURE_OVERRIDE_TEST_SUITE(LiveSignInGaiaIntegrationTest);
+
 #endif  // BUILDFLAG(ENABLE_DICE_SUPPORT)
 
 }  // namespace
