@@ -21,7 +21,6 @@
 #include "base/supports_user_data.h"
 #include "base/time/time.h"
 #include "build/build_config.h"
-#include "build/chromeos_buildflags.h"
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/feature_engagement/tracker_factory.h"
 #include "chrome/browser/profiles/profile.h"
@@ -49,17 +48,18 @@
 #include "components/signin/public/identity_manager/identity_manager.h"
 #include "components/signin/public/identity_manager/identity_utils.h"
 #include "components/signin/public/identity_manager/primary_account_mutator.h"
+#include "components/sync/base/features.h"
 #include "third_party/re2/src/re2/re2.h"
 #include "ui/gfx/font_list.h"
 #include "ui/gfx/text_elider.h"
 
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
 #include "chrome/browser/ash/profiles/profile_helper.h"
 #include "chrome/browser/signin/signin_ui_chromeos_util.h"
+#include "chromeos/ash/components/account_manager/account_manager_facade_factory.h"
 #include "components/account_manager_core/account_manager_facade.h"
-#include "components/account_manager_core/chromeos/account_manager_facade_factory.h"
 #include "components/user_manager/user.h"
-#endif  // BUILDFLAG(IS_CHROMEOS_ASH)
+#endif  // BUILDFLAG(IS_CHROMEOS)
 
 #if BUILDFLAG(ENABLE_DICE_SUPPORT) && !BUILDFLAG(IS_QTWEBENGINE)
 #include "chrome/browser/signin/dice_tab_helper.h"
@@ -74,6 +74,8 @@ const char kAnimatedIdentityKeyName[] = "animated_identity_user_data";
 
 constexpr base::TimeDelta kDelayForCrossWindowAnimationReplay =
     base::Seconds(5);
+std::optional<base::TimeDelta>
+    g_delay_for_cross_window_animation_replay_for_testing;
 
 // UserData attached to the user profile, keeping track of the last time the
 // animation was shown to the user.
@@ -86,8 +88,9 @@ class AvatarButtonUserData : public base::SupportsUserData::Data {
   static base::TimeTicks GetAnimatedIdentityLastShown(Profile* profile) {
     DCHECK(profile);
     AvatarButtonUserData* data = GetForProfile(profile);
-    if (!data)
+    if (!data) {
       return base::TimeTicks();
+    }
     return data->animated_identity_last_shown_;
   }
 
@@ -110,8 +113,9 @@ class AvatarButtonUserData : public base::SupportsUserData::Data {
   static AvatarButtonUserData* GetOrCreateForProfile(Profile* profile) {
     DCHECK(profile);
     AvatarButtonUserData* existing_data = GetForProfile(profile);
-    if (existing_data)
+    if (existing_data) {
       return existing_data;
+    }
 
     auto new_data = std::make_unique<AvatarButtonUserData>();
     auto* new_data_ptr = new_data.get();
@@ -127,8 +131,9 @@ class AvatarButtonUserData : public base::SupportsUserData::Data {
 SigninUiDelegate* g_signin_ui_delegate_for_testing = nullptr;
 
 SigninUiDelegate* GetSigninUiDelegate() {
-  if (g_signin_ui_delegate_for_testing)
+  if (g_signin_ui_delegate_for_testing) {
     return g_signin_ui_delegate_for_testing;
+  }
 
   static SigninUiDelegateImplDice delegate;
   return &delegate;
@@ -142,18 +147,19 @@ std::u16string GetAuthenticatedUsername(Profile* profile) {
   DCHECK(profile);
   std::string user_display_name;
   auto* identity_manager = IdentityManagerFactory::GetForProfile(profile);
-  if (identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSync)) {
+  if (identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSignin)) {
     user_display_name =
-        identity_manager->GetPrimaryAccountInfo(signin::ConsentLevel::kSync)
+        identity_manager->GetPrimaryAccountInfo(signin::ConsentLevel::kSignin)
             .email;
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
     // See https://crbug.com/994798 for details.
     user_manager::User* user =
         ash::ProfileHelper::Get()->GetUserByProfile(profile);
     // |user| may be null in tests.
-    if (user)
+    if (user) {
       user_display_name = user->GetDisplayEmail();
-#endif  // BUILDFLAG(IS_CHROMEOS_ASH)
+    }
+#endif  // BUILDFLAG(IS_CHROMEOS)
   }
 
   return base::UTF8ToUTF16(user_display_name);
@@ -185,8 +191,8 @@ void ShowReauthForPrimaryAccountWithAuthError(
 void ShowReauthForAccount(Profile* profile,
                           const std::string& email,
                           signin_metrics::AccessPoint access_point) {
-#if BUILDFLAG(IS_CHROMEOS_ASH)
-  ::GetAccountManagerFacade(profile->GetPath().value())
+#if BUILDFLAG(IS_CHROMEOS)
+  ash::GetAccountManagerFacade(profile->GetPath().value())
       ->ShowReauthAccountDialog(
           GetAccountReauthSourceFromAccessPoint(access_point), email,
           base::DoNothing());
@@ -203,12 +209,13 @@ void ShowReauthForAccount(Profile* profile,
 void ShowExtensionSigninPrompt(Profile* profile,
                                bool enable_sync,
                                const std::string& email_hint) {
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
   NOTREACHED();
 #elif BUILDFLAG(ENABLE_DICE_SUPPORT)
   // There is no sign-in flow for guest or system profile.
-  if (profile->IsGuestSession() || profile->IsSystemProfile())
+  if (profile->IsGuestSession() || profile->IsSystemProfile()) {
     return;
+  }
   // Locked profile should be unlocked with UserManager only.
   ProfileAttributesEntry* entry =
       g_browser_process->profile_manager()
@@ -234,12 +241,12 @@ void ShowExtensionSigninPrompt(Profile* profile,
       profile, email_hint, enable_sync,
       signin_metrics::AccessPoint::kExtensions,
       signin_metrics::PromoAction::PROMO_ACTION_NO_SIGNIN_PROMO);
-#endif  // BUILDFLAG(IS_CHROMEOS_ASH)
+#endif  // BUILDFLAG(IS_CHROMEOS)
 }
 
 void ShowSigninPromptFromPromo(Profile* profile,
                                signin_metrics::AccessPoint access_point) {
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if BUILDFLAG(IS_CHROMEOS)
   NOTREACHED();
 #elif BUILDFLAG(ENABLE_DICE_SUPPORT)
   CHECK_NE(signin_metrics::AccessPoint::kUnknown, access_point);
@@ -256,7 +263,7 @@ void ShowSigninPromptFromPromo(Profile* profile,
       profile, /*enable_sync=*/false, access_point,
       signin_metrics::PromoAction::
           PROMO_ACTION_NEW_ACCOUNT_NO_EXISTING_ACCOUNT);
-#endif  // BUILDFLAG(IS_CHROMEOS_ASH)
+#endif  // BUILDFLAG(IS_CHROMEOS)
 }
 
 void SignInFromSingleAccountPromo(Profile* profile,
@@ -324,6 +331,11 @@ void EnableSyncFromSingleAccountPromo(
     Profile* profile,
     const CoreAccountInfo& account,
     signin_metrics::AccessPoint access_point) {
+  // TODO(crbug.com/417950948): Delete this function when removing the Sync
+  // feature.
+  CHECK(!base::FeatureList::IsEnabled(
+      syncer::kReplaceSyncPromosWithSignInPromos));
+
   EnableSyncFromMultiAccountPromo(profile, account, access_point,
                                   /*is_default_promo_account=*/true);
 }
@@ -332,6 +344,11 @@ void EnableSyncFromMultiAccountPromo(Profile* profile,
                                      const CoreAccountInfo& account,
                                      signin_metrics::AccessPoint access_point,
                                      bool is_default_promo_account) {
+  // TODO(crbug.com/417950948): Delete this function when removing the Sync
+  // feature.
+  CHECK(!base::FeatureList::IsEnabled(
+      syncer::kReplaceSyncPromosWithSignInPromos));
+
 #if BUILDFLAG(ENABLE_DICE_SUPPORT)
   DCHECK_NE(signin_metrics::AccessPoint::kUnknown, access_point);
   DCHECK(!profile->IsOffTheRecord());
@@ -387,14 +404,10 @@ void EnableSyncFromMultiAccountPromo(Profile* profile,
   // primary account as primary, and keeps the secondary account.
   bool is_sync_promo =
       access_point ==
-      signin_metrics::AccessPoint::kAvatarBubbleSignInWithSyncPromo;
-  if (switches::IsImprovedSettingsUIOnDesktopEnabled()) {
-    is_sync_promo =
-        is_sync_promo || access_point == signin_metrics::AccessPoint::kSettings;
-  }
+          signin_metrics::AccessPoint::kAvatarBubbleSignInWithSyncPromo ||
+      access_point == signin_metrics::AccessPoint::kSettings;
   TurnSyncOnHelper::SigninAbortedMode signin_aborted_mode =
-      switches::IsExplicitBrowserSigninUIOnDesktopEnabled() &&
-              account.account_id !=
+      account.account_id !=
                   identity_manager
                       ->GetPrimaryAccountInfo(signin::ConsentLevel::kSignin)
                       .account_id &&
@@ -404,9 +417,23 @@ void EnableSyncFromMultiAccountPromo(Profile* profile,
   signin_metrics::LogSigninAccessPointStarted(access_point,
                                               existing_account_promo_action);
   signin_metrics::RecordSigninUserActionForAccessPoint(access_point);
+
+  bool user_already_signed_in =
+      identity_manager->GetPrimaryAccountId(signin::ConsentLevel::kSignin) ==
+      account.account_id;
+
+  // The Turn On Sync flow might fail before setting an account as primary. If
+  // enabling Sync is optional, do not rely on its result to sign the web-only
+  // account in the profile.
+  if (is_sync_promo &&
+      !identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSignin)) {
+    identity_manager->GetPrimaryAccountMutator()->SetPrimaryAccount(
+        account.account_id, signin::ConsentLevel::kSignin, access_point);
+  }
+
   GetSigninUiDelegate()->ShowTurnSyncOnUI(
       profile, access_point, existing_account_promo_action, account.account_id,
-      signin_aborted_mode, is_sync_promo);
+      signin_aborted_mode, is_sync_promo, user_already_signed_in);
 #else
   DUMP_WILL_BE_NOTREACHED();
 #endif  // BUILDFLAG(ENABLE_DICE_SUPPORT)
@@ -459,18 +486,19 @@ std::vector<AccountInfo> GetOrderedAccountsForDisplay(
   return accounts;
 }
 
-#if !BUILDFLAG(IS_CHROMEOS_ASH)
+#if !BUILDFLAG(IS_CHROMEOS)
 
 AccountInfo GetSingleAccountForPromos(
     const signin::IdentityManager* identity_manager) {
   std::vector<AccountInfo> accounts = GetOrderedAccountsForDisplay(
       identity_manager, /*restrict_to_accounts_eligible_for_sync=*/true);
-  if (!accounts.empty())
+  if (!accounts.empty()) {
     return accounts[0];
+  }
   return AccountInfo();
 }
 
-#endif  // !BUILDFLAG(IS_CHROMEOS_ASH)
+#endif  // !BUILDFLAG(IS_CHROMEOS)
 
 #if BUILDFLAG(ENABLE_DICE_SUPPORT)
 
@@ -503,15 +531,17 @@ std::u16string GetShortProfileIdentityToDisplay(
       identity_manager->GetPrimaryAccountInfo(signin::ConsentLevel::kSignin);
   // If there's no unconsented primary account, simply return the name of the
   // profile according to profile attributes.
-  if (core_info.IsEmpty())
+  if (core_info.IsEmpty()) {
     return profile_attributes_entry.GetName();
+  }
 
   AccountInfo extended_info =
       identity_manager->FindExtendedAccountInfoByAccountId(
           core_info.account_id);
   // If there's no given name available, return the user email.
-  if (extended_info.given_name.empty())
+  if (extended_info.given_name.empty()) {
     return base::UTF8ToUTF16(core_info.email);
+  }
 
   return base::UTF8ToUTF16(extended_info.given_name);
 }
@@ -521,54 +551,52 @@ std::string GetAllowedDomain(std::string signin_pattern) {
       signin_pattern, "@", base::KEEP_WHITESPACE, base::SPLIT_WANT_ALL);
 
   // There are more than one '@'s in the pattern.
-  if (splitted_signin_pattern.size() != 2)
+  if (splitted_signin_pattern.size() != 2) {
     return std::string();
+  }
 
   std::string domain = splitted_signin_pattern[1];
 
   // Trims tailing '$' if existed.
-  if (!domain.empty() && domain.back() == '$')
+  if (!domain.empty() && domain.back() == '$') {
     domain.pop_back();
+  }
 
   // Trims tailing '\E' if existed.
   if (domain.size() > 1 &&
-      base::EndsWith(domain, "\\E", base::CompareCase::SENSITIVE))
+      base::EndsWith(domain, "\\E", base::CompareCase::SENSITIVE)) {
     domain.erase(domain.size() - 2);
+  }
 
   // Check if there is any special character in the domain. Note that
   // jsmith@[192.168.2.1] is not supported.
-  if (!re2::RE2::FullMatch(domain, "[a-zA-Z0-9\\-.]+"))
+  if (!re2::RE2::FullMatch(domain, "[a-zA-Z0-9\\-.]+")) {
     return std::string();
+  }
 
   return domain;
 }
 
-bool ShouldShowAnimatedIdentityOnOpeningWindow(
-    const ProfileAttributesStorage& profile_attributes_storage,
-    Profile* profile) {
-  DCHECK(profile);
-  signin::IdentityManager* identity_manager =
-      IdentityManagerFactory::GetForProfile(profile);
-  DCHECK(identity_manager->AreRefreshTokensLoaded());
-
-  base::TimeTicks animation_last_shown =
-      AvatarButtonUserData::GetAnimatedIdentityLastShown(profile);
+bool ShouldShowAnimatedIdentityOnOpeningWindow(Profile& profile) {
+  const base::TimeTicks animation_last_shown =
+      AvatarButtonUserData::GetAnimatedIdentityLastShown(&profile);
   // When a new window is created, only show the animation if it was never shown
   // for this profile, or if it was shown in another window in the last few
   // seconds (because the user may have missed it).
   if (!animation_last_shown.is_null() &&
       base::TimeTicks::Now() - animation_last_shown >
-          kDelayForCrossWindowAnimationReplay) {
+          g_delay_for_cross_window_animation_replay_for_testing.value_or(
+              kDelayForCrossWindowAnimationReplay)) {
     return false;
   }
+  return true;
+}
 
-  // Show the user identity for users with multiple profiles.
-  if (profile_attributes_storage.GetNumberOfProfiles() > 1) {
-    return true;
-  }
-
-  // Show the user identity for users with multiple signed-in accounts.
-  return identity_manager->GetAccountsWithRefreshTokens().size() > 1;
+base::AutoReset<std::optional<base::TimeDelta>>
+CreateZeroOverrideDelayForCrossWindowAnimationReplayForTesting() {
+  return base::AutoReset<std::optional<base::TimeDelta>>(
+      &g_delay_for_cross_window_animation_replay_for_testing,
+      base::TimeDelta());
 }
 
 #if BUILDFLAG(ENABLE_DICE_SUPPORT)
@@ -598,16 +626,16 @@ void RecordProfileMenuViewShown(Profile* profile) {
   }
 }
 
-void RecordProfileMenuClick(Profile* profile) {
+void RecordProfileMenuClick(const Profile& profile) {
   base::RecordAction(
       base::UserMetricsAction("ProfileMenu_ActionableItemClicked"));
-  if (profile->IsRegularProfile()) {
+  if (profile.IsRegularProfile()) {
     base::RecordAction(
         base::UserMetricsAction("ProfileMenu_ActionableItemClicked_Regular"));
-  } else if (profile->IsGuestSession()) {
+  } else if (profile.IsGuestSession()) {
     base::RecordAction(
         base::UserMetricsAction("ProfileMenu_ActionableItemClicked_Guest"));
-  } else if (profile->IsIncognitoProfile()) {
+  } else if (profile.IsIncognitoProfile()) {
     base::RecordAction(
         base::UserMetricsAction("ProfileMenu_ActionableItemClicked_Incognito"));
   }
